@@ -1,8 +1,7 @@
 /**************************************************************************************************
-    date                 : Dec 06 2005
-    version              : 0.24
-    copyright            : (C) 2004-2005 by Holger Danielsson (holger.danielsson@t-online.de)
-                              2004 by Jeroen Wijnhout
+   Copyright (C) 2004-2005  Holger Danielsson <holger.danielsson@t-online.de>
+                 2004       Jeroen Wijnhout
+                 2015       Andreas Cord-Landwehr <cordlandwehr@kde.org>
  **************************************************************************************************/
 
 /***************************************************************************
@@ -15,71 +14,73 @@
  ***************************************************************************/
 
 #include "dialogs/includegraphicsdialog.h"
-
-#include <QRegExp>
-#include <QFileInfo>
-#include <QPixmap>
-
-#include <KFileDialog>
-#include <KIconLoader>
-#include <KLineEdit>
-#include <KLocale>
-#include <KMessageBox>
-#include <KProcess>
-#include <KPushButton>
-
-#include "kiledebug.h"
-#include "kileconfig.h"
-#include "kileinfo.h"
 #include "editorextension.h"
+#include "errorhandler.h"
 #include "kileactions.h"
+#include "kileconfig.h"
+#include "kiledebug.h"
+#include "kileinfo.h"
 #include "kiletool_enums.h"
 
+#include <KConfigGroup>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KProcess>
+
+#include <QDialogButtonBox>
+#include <QFileInfo>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QRegExp>
+#include <QVBoxLayout>
+
 namespace KileDialog
 {
 
-IncludeGraphics::IncludeGraphics(QWidget *parent, const QString &startdir, KileInfo *ki) :
-		KDialog(parent),
-		m_startdir(startdir),
-		m_width(0),
-		m_height(0),
-		m_ki(ki),
-		m_proc(NULL)
+IncludeGraphics::IncludeGraphics(QWidget *parent, const QString &startdir, KileInfo *ki)
+	: QDialog(parent)
+	, m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel))
+	, m_startdir(startdir)
+	, m_width(0)
+	, m_height(0)
+	, m_ki(ki)
+	, m_proc(Q_NULLPTR)
 {
-	setCaption(i18n("Include Graphics"));
+	setWindowTitle(i18n("Include Graphics"));
 	setModal(true);
-	setButtons(Ok | Cancel);
-	setDefaultButton(Ok);
-	showButtonSeparator(true);
+	QWidget *mainWidget = new QWidget(this);
+	QVBoxLayout *mainLayout = new QVBoxLayout;
+	setLayout(mainLayout);
+	mainLayout->addWidget(mainWidget);
 
 	QWidget *page = new QWidget(this);
 	m_widget.setupUi(page);
-	setMainWidget(page);
+	mainLayout->addWidget(page);
 
 	// read configuration
 	readConfig();
+	onChooseFilter();
 
-	slotChooseFilter();
-
-	#if KDE_IS_VERSION(4,2,90)
-		m_widget.edit_file->setStartDir(KUrl::fromPath(m_startdir));
-	#else
-		m_widget.edit_file->setUrl(KUrl::fromPath(m_startdir));
-	#endif
-	
 	setFocusProxy(m_widget.edit_file);
+	m_widget.edit_file->setMode(KFile::File | KFile::LocalOnly);
+	m_widget.edit_file->setStartDir(QUrl::fromLocalFile(m_startdir));
 	m_widget.edit_file->setFocus();
 
-	connect(m_widget.cb_bb, SIGNAL(toggled(bool)),
-	        this, SLOT(slotChooseFilter()));
-	connect(m_widget.edit_file, SIGNAL(urlSelected(const KUrl&)),
-	        this, SLOT(slotUrlSelected(const KUrl&)));
-	connect(m_widget.edit_file, SIGNAL(textChanged(const QString&)),
-	        this, SLOT(slotTextChanged(const QString&)));
-	connect(m_widget.cb_figure, SIGNAL(toggled(bool)),
-		this, SLOT(slotFigureSelected(bool)));
-	connect(m_widget.cb_wrapfigure, SIGNAL(toggled(bool)),
-		this, SLOT(slotWrapFigureSelected(bool)));
+	connect(m_widget.cb_bb, &QCheckBox::toggled, this, &IncludeGraphics::onChooseFilter);
+	connect(m_widget.edit_file, &KUrlRequester::urlSelected, this, &IncludeGraphics::onUrlSelected);
+	connect(m_widget.edit_file, &KUrlRequester::textChanged, this, &IncludeGraphics::onTextChanged);
+	connect(m_widget.cb_figure, &QGroupBox::toggled, this, &IncludeGraphics::onFigureSelected);
+	connect(m_widget.cb_wrapfigure, &QGroupBox::toggled, this, &IncludeGraphics::onWrapFigureSelected);
+
+	QPushButton *okButton = m_buttonBox->button(QDialogButtonBox::Ok);
+	okButton->setDefault(true);
+	okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+	okButton->setEnabled(false);
+	mainLayout->addWidget(m_buttonBox);
+
+	connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+	connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+	connect(this, &QDialog::accepted, this, &IncludeGraphics::onAccepted);
 }
 
 IncludeGraphics::~IncludeGraphics()
@@ -145,7 +146,7 @@ QString IncludeGraphics::getTemplate()
 	bool figure = m_widget.cb_figure->isChecked();
 	bool wrapfigure = m_widget.cb_wrapfigure->isChecked();
 	bool center = m_widget.cb_center->isChecked();
-	QString indent = (figure || center) ? m_ki->editorExtension()->autoIndentEnvironment() : QString::null;
+	const QString indent = (figure || center) ? m_ki->editorExtension()->autoIndentEnvironment() : QString();
 
 	// build tags for start of figure environment
 	if (figure) {
@@ -157,7 +158,7 @@ QString IncludeGraphics::getTemplate()
 		bool page 	= m_widget.cb_Page->isChecked();
 		bool force 	= m_widget.cb_Force->isChecked();
 		bool custom 	= m_widget.cb_custom->isChecked();
-	
+
 		// build position string
 		if (here||top||bottom||page||custom) { // Don't check for force -- if it is the only selection, just skip the position tag
 			p += '[';
@@ -169,7 +170,6 @@ QString IncludeGraphics::getTemplate()
 			if (custom)	p+= m_widget.edit_custom->text();
 			p += ']';
 		}
-	
 
 		// add start of figure environment
 		s += "\\begin{figure}" + p + '\n';
@@ -177,7 +177,6 @@ QString IncludeGraphics::getTemplate()
 
 	// build tags for start of wrapfigure environment
 	if (wrapfigure) {
-
 		s += "\\begin{wrapfigure}";
 
 		// number of lines in length
@@ -187,20 +186,20 @@ QString IncludeGraphics::getTemplate()
 
 		// positioning for wrapfigure environment
 		bool wrapfloat;
- 		wrapfloat = m_widget.cb_wrapfloat->isChecked();
- 		if (m_widget.cb_wrapright->isChecked()){
+		wrapfloat = m_widget.cb_wrapfloat->isChecked();
+ 		if (m_widget.cb_wrapright->isChecked()) {
 			if (wrapfloat) 	s += "{R}";
 			else		s += "{r}";
 		}
-		if (m_widget.cb_wrapleft->isChecked()){
+		if (m_widget.cb_wrapleft->isChecked()) {
 			if (wrapfloat) 	s += "{L}";
 			else		s += "{l}";
 		}
-		if (m_widget.cb_wrapinside->isChecked()){
+		if (m_widget.cb_wrapinside->isChecked()) {
 			if (wrapfloat) 	s += "{I}";
 			else		s += "{i}";
 		}
-		if (m_widget.cb_wrapoutside->isChecked()){
+		if (m_widget.cb_wrapoutside->isChecked()) {
 			if (wrapfloat) 	s += "{O}";
 			else		s += "{i}";
 		}
@@ -214,13 +213,13 @@ QString IncludeGraphics::getTemplate()
 		if (!m_widget.edit_wrapwidth->text().isEmpty()) {
 			s += '{' + m_widget.edit_wrapwidth->text() + '}';
 		}
-		
+
 		// end of wrapfigure options
 		s += '\n';
-		
+
 		// Include warning in comment if wrapfig is not loaded.
 		// Sending a warning to the log here would be good, but
-		// the log seems to get cleared before user could catch 
+		// the log seems to get cleared before user could catch
 		// the warning.
 		QStringList packagelist = m_ki->allPackages();
 		if (!packagelist.contains("wrapfig")) {
@@ -235,8 +234,7 @@ QString IncludeGraphics::getTemplate()
 	if (center) {
 		if (figure || wrapfigure) {
 			s += indent + "\\centering\n";
-		}
-		else {
+		} else {
 			s += "\\begin{center}\n";
 		}
 	}
@@ -252,9 +250,10 @@ QString IncludeGraphics::getTemplate()
 
 	// add name of picture
 	// either take the filename or try to take the relative part of the name
+	const QString relativeUrl = QDir(QFileInfo(m_ki->getCompileName()).path()).relativeFilePath(m_widget.edit_file->lineEdit()->text());
 	QString filename = (m_widget.cb_graphicspath->isChecked())
 			 ? QFileInfo(m_widget.edit_file->lineEdit()->text()).fileName()
-			 : KUrl::relativePath(QFileInfo(m_ki->getCompileName()).path(), m_widget.edit_file->lineEdit()->text());
+			 : relativeUrl;
 	s += '{' + filename + "}\n";
 
 	// add some comments (depending of given resolution, this may be wrong!)
@@ -269,8 +268,7 @@ QString IncludeGraphics::getTemplate()
 	}
 
 	// close figure environment ?
-	if (figure)
-	{
+	if (figure) {
 		QString caption = m_widget.edit_caption->text().trimmed();
 		if (!caption.isEmpty()) {
 			s +=  indent + "\\caption{" + caption + "}\n";
@@ -282,8 +280,7 @@ QString IncludeGraphics::getTemplate()
 		s += "\\end{figure}\n";
 	}
 
-	if (wrapfigure)
-	{
+	if (wrapfigure) {
 		QString caption = m_widget.edit_wrapcaption->text().trimmed();
 		if (!caption.isEmpty()) {
 			s +=  indent + "\\caption{" + caption + "}\n";
@@ -307,17 +304,17 @@ QString IncludeGraphics::getFilename()
 
 QString IncludeGraphics::getOptions()
 {
-	QString s = "";
+	QString s = QString();
 
-	if (! m_widget.edit_width->text().isEmpty()) {
+	if (!m_widget.edit_width->text().isEmpty()) {
 		s += ",width=" + m_widget.edit_width->text();
 	}
 
-	if (! m_widget.edit_height->text().isEmpty()) {
+	if (!m_widget.edit_height->text().isEmpty()) {
 		s += ",height=" + m_widget.edit_height->text();
 	}
 
-	if (! m_widget.edit_angle->text().isEmpty()) {
+	if (!m_widget.edit_angle->text().isEmpty()) {
 		s += ",angle=" + m_widget.edit_angle->text();
 	}
 
@@ -354,8 +351,7 @@ QString IncludeGraphics::getOptions()
 
 	if (s.left(1) == ",") {
 		return s.right(s.length() - 1);
-	}
-	else {
+	} else {
 		return s;
 	}
 }
@@ -364,18 +360,17 @@ QString IncludeGraphics::getOptions()
 
 QString IncludeGraphics::getInfo()
 {
-	QString wcm,hcm,dpi;
-	int wpx=0,hpx=0;
+	QString wcm, hcm, dpi;
+	int wpx = 0, hpx = 0;
 
 	bool ok = getPictureSize(wpx, hpx, dpi, wcm, hcm);
-	if (! ok)
-		return "";
-	else
-	{
+	if (!ok) {
+		return QString();
+	} else {
 		QFileInfo fi(m_widget.edit_file->lineEdit()->text());
 
 		return "% " + fi.baseName() + '.' + fi.completeSuffix()
-					 + QString(": %1x%2 pixel").arg(wpx).arg(hpx)
+					 + QString(": %1x%2 px").arg(wpx).arg(hpx)
 					 + ", " + dpi + "dpi"
 					 + ", " + wcm + 'x' + hcm + " cm"
 					 + ", bb=" + m_widget.edit_bb->text();
@@ -388,16 +383,15 @@ void IncludeGraphics::setInfo()
 	QString wcm, hcm, dpi;
 	int wpx, hpx;
 
-	if (!m_widget.edit_file->lineEdit()->text().isEmpty() && getPictureSize(wpx, hpx, dpi, wcm, hcm))
-	{
-		text = QString("%1x%2 pixel").arg(wpx).arg(hpx)
+	if (!m_widget.edit_file->lineEdit()->text().isEmpty() && getPictureSize(wpx, hpx, dpi, wcm, hcm)) {
+		text = QString("%1x%2 px").arg(wpx).arg(hpx)
 					 + " / " + wcm + 'x' + hcm + " cm"
 					 + "  (" + dpi + "dpi)";
-	}
-	else
+	} else {
 		text = "---";
+	}
 
-// insert text
+	// insert text
 	m_widget.infolabel->setText(text);
 }
 
@@ -417,15 +411,16 @@ bool IncludeGraphics::getPictureSize(int &wpx, int &hpx, QString &dpi, QString &
 	return true;
 }
 
-void IncludeGraphics::slotChooseFilter()
+void IncludeGraphics::onChooseFilter()
 {
 	QString filter = (!m_widget.cb_bb->isChecked())
-			? i18n("*.png *.jpg *.pdf|Graphics\n")              // dani  31.7.2004
+			? i18n("*.png *.jpg *.pdf *.ps *.eps|Graphics\n")
 			+ "*.png|PNG Files\n"
 			+ "*.jpg|JPG Files\n"
 			+ "*.pdf|PDF Files\n"
+			+ "*.eps *ps|Postscript Files\n"
 			+ "*|All Files"
-	: i18n("*.png *.jpg *.eps.gz *.eps|Graphics\n")     // dani  31.7.2004
+	: i18n("*.png *.jpg *.eps.gz *.eps|Graphics\n")
 			+ "*.png|PNG Files\n"
 			+ "*.jpg|JPG Files\n"
 			+ "*.eps.gz|Zipped EPS Files\n"
@@ -434,81 +429,81 @@ void IncludeGraphics::slotChooseFilter()
 	m_widget.edit_file->setFilter(filter);
 }
 
-void IncludeGraphics::slotUrlSelected(const KUrl& url)
+void IncludeGraphics::onUrlSelected(const QUrl &url)
 {
 	QFileInfo fi(url.toLocalFile());
 
 	// could we accept the picture?
-	if (!url.toLocalFile().isEmpty() && fi.exists() && fi.isReadable())
-	{
+	if (!url.toLocalFile().isEmpty() && fi.exists() && fi.isReadable()) {
 		// execute the command and filter the result:
 		// eps|eps.gz --> %%BoundingBox: 0 0 123 456
 		// bitmaps    --> w=123 h=456 dpi=789
 		QString grep = " | grep -m1 \"^%%BoundingBox:\"";
 		QString ext = fi.completeSuffix();
-		if (ext == "eps"){
+		if (ext == "eps") {
 			execute("cat " + url.toLocalFile() + grep);
 		}
-		else if (ext == "eps.gz"){
+		else if (ext == "eps.gz") {
 				execute("gunzip -c " + url.toLocalFile() + grep);
 		}
-		else{
-			execute("identify -format \"w=%w h=%h dpi=%x\" \"" + url.toLocalFile() + "\"");
+		else {
+			execute("identify -format \"w=%w h=%h dpi=%x %U\" \"" + url.toLocalFile() + "\"");
 		}
+		m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
 	} else {
-		KILE_DEBUG() << "=== IncludeGraphics::error ====================";
-		KILE_DEBUG() << "   filename: '" << url.toLocalFile() << "'";
+		KILE_DEBUG_MAIN << "=== IncludeGraphics::error ====================";
+		KILE_DEBUG_MAIN << "   filename: '" << url.toLocalFile() << "'";
 
 		m_widget.infolabel->setText("---");
 		m_widget.edit_bb->setText("");
+		m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
 	}
 }
 
-void IncludeGraphics::slotTextChanged(const QString& string)
+void IncludeGraphics::onTextChanged(const QString &string)
 {
-	slotUrlSelected(KUrl(string));
+	onUrlSelected(QUrl::fromLocalFile(string.trimmed()));
 }
 
 void IncludeGraphics::execute(const QString &command)
 {
-	if (!m_boundingbox || (!m_imagemagick && command.left(8) == "identify"))
+	if (!m_boundingbox || (!m_imagemagick && command.left(8) == "identify")) {
 		return;
+	}
 
-	if (m_proc)
+	if (m_proc) {
 		delete m_proc;
+	}
 
 	m_proc = new KProcess(this);
 	m_proc->setShellCommand(command);
 	m_proc->setOutputChannelMode(KProcess::MergedChannels);
 	m_proc->setReadChannel(QProcess::StandardOutput);
 
-	connect(m_proc, SIGNAL(readyReadStandardOutput()),
-					this, SLOT(slotProcessOutput()));
-	connect(m_proc, SIGNAL(readyReadStandardError()),
-					this, SLOT(slotProcessOutput()));
-	connect(m_proc, SIGNAL(finished(int, QProcess::ExitStatus)),
-					this, SLOT(slotProcessExited(int, QProcess::ExitStatus)));
+	connect(m_proc, &KProcess::readyReadStandardOutput, this, &IncludeGraphics::onProcessOutput);
+	connect(m_proc, &KProcess::readyReadStandardError, this, &IncludeGraphics::onProcessOutput);
+	connect(m_proc, static_cast<void (KProcess::*)(int, QProcess::ExitStatus)>(&KProcess::finished), this, &IncludeGraphics::onProcessExited);
 
-	m_output = "";
-	KILE_DEBUG() << "=== IncludeGraphics::execute ====================";
-	KILE_DEBUG() << "   execute '" << command << "'";
+	m_output = QString();
+	KILE_DEBUG_MAIN << "=== IncludeGraphics::execute ====================";
+	KILE_DEBUG_MAIN << "   execute '" << command << "'";
 
 	m_proc->start();
 }
 
 // get all output of identify
 
-void IncludeGraphics::slotProcessOutput()
+void IncludeGraphics::onProcessOutput()
 {
 	m_output += m_proc->readAll();
 }
 
 // identify was called
 
-void IncludeGraphics::slotProcessExited(int /* exitCode */, QProcess::ExitStatus exitStatus)
+void IncludeGraphics::onProcessExited(int /* exitCode */, QProcess::ExitStatus exitStatus)
 {
 	if (exitStatus == QProcess::NormalExit) {
-		KILE_DEBUG() << "   result: " << m_output;
+		KILE_DEBUG_MAIN << "   result: " << m_output;
 
 		// set the default resolution
 		m_resolution = m_defaultresolution;
@@ -517,6 +512,38 @@ void IncludeGraphics::slotProcessExited(int /* exitCode */, QProcess::ExitStatus
 		if (m_output.left(14) == "%%BoundingBox:") {
 			m_widget.edit_bb->setText(m_output.trimmed().mid(15, m_output.length() - 15));
 
+			// this regexp will extract width and height from the bounding box
+			QRegExp reg("(\\d+) (\\d+) (\\d+) (\\d+)");
+			if(reg.indexIn(m_output) == -1) {
+				return;
+			}
+
+			// determine lower-left-x (llx), lower-left-y (lly), upper-right-x (urx) and upper-right-y (ury)
+			bool ok;
+			int llx = (int)reg.cap(1).toInt(&ok);
+			if (!ok) {
+				return;
+			}
+
+			int lly = (int)reg.cap(2).toInt(&ok);
+			if (!ok) {
+				return;
+			}
+
+			int urx = (int)reg.cap(3).toInt(&ok);
+			if (!ok) {
+				return;
+			}
+
+			int ury = (int)reg.cap(4).toInt(&ok);
+			if (!ok) {
+				return;
+			}
+
+			// calculate width and height from 72 dpi of eps graphics to the default resolution
+			m_width = ((urx-llx)*m_resolution) / 72;
+			m_height = ((ury-lly)*m_resolution) / 72;
+
 			// show information
 			setInfo();
 		}
@@ -537,22 +564,27 @@ void IncludeGraphics::slotProcessExited(int /* exitCode */, QProcess::ExitStatus
 				// get bounding box and resolution
 				bool ok;
 				m_width = (int)reg.cap(1).toInt(&ok);
-				if (!ok)
+				if (!ok) {
 					return;
+				}
 
 				m_height = (int)reg.cap(2).toInt(&ok);
-				if (!ok)
+				if (!ok) {
 					return;
+				}
 
 				float res = (float)reg.cap(3).toFloat(&ok);
-				if (!ok)
+				if (!ok) {
 					return;
-				if (res > 0.0)
+				}
+				if (res > 0.0) {
 					m_resolution = res;
+				}
 
 				// look, if resolution is in PixelsPerCentimeter
-				if (reg.cap(4).trimmed() == "PixelsPerCentimeter")
+				if (reg.cap(4).trimmed() == "PixelsPerCentimeter") {
 					m_resolution *= 2.54;
+				}
 
 				// calc the bounding box
 				int bbw = (int)((float)m_width * 72.0 / m_resolution + 0.5);
@@ -560,9 +592,8 @@ void IncludeGraphics::slotProcessExited(int /* exitCode */, QProcess::ExitStatus
 
 				// take width and height as parameters for the bounding box
 				m_widget.edit_bb->setText(QString("0 0 ") + QString::number(bbw)
-																	+ ' '
-																	+ QString::number(bbh)
-																 );
+									  + ' '
+									  + QString::number(bbh));
 
 				// show information
 				setInfo();
@@ -572,59 +603,25 @@ void IncludeGraphics::slotProcessExited(int /* exitCode */, QProcess::ExitStatus
 	}
 }
 
-void IncludeGraphics::slotButtonClicked(int button)
+void IncludeGraphics::onAccepted()
 {
-	if(button == KDialog::Ok){
-		if(checkParameter()){
-			writeConfig();
-			accept();
-		}
-	}
-	else{
-		KDialog::slotButtonClicked(button);
-	}
+	writeConfig();
 }
 
-void IncludeGraphics::slotWrapFigureSelected(bool state) {
+void IncludeGraphics::onWrapFigureSelected(bool state) {
 	if (m_widget.cb_figure->isChecked() && state) {
 		m_widget.cb_figure->setChecked(false);
 	}
 	// Adds warning to log if wrapfig isn't in the preamble
 	QStringList packagelist = m_ki->allPackages();
 	if (!packagelist.contains("wrapfig")) {
-		m_ki->logWidget()->printMessage(KileTool::Error, i18n("You must include the wrapfig package to use the text wrapping options"), i18n("Missing Package"));
+		m_ki->errorHandler()->printMessage(KileTool::Error, i18n("You must include the wrapfig package to use the text wrapping options"), i18n("Missing Package"));
 	}
 }
 
-void IncludeGraphics::slotFigureSelected(bool state) {
+void IncludeGraphics::onFigureSelected(bool state) {
 	if (m_widget.cb_wrapfigure->isChecked() && state) {
 		m_widget.cb_wrapfigure->setChecked(false);
 	}
 }
-
-bool IncludeGraphics::checkParameter()
-{
-	QString filename = m_widget.edit_file->lineEdit()->text().trimmed();
-	m_widget.edit_file->lineEdit()->setText(filename);
-
-	if (filename.isEmpty())
-	{
-		if (KMessageBox::warningYesNo(this, i18n("No graphics file was given. Proceed any way?")) == KMessageBox::No)
-			return false;
-	}
-	else
-	{
-		QFileInfo fi(filename);
-		if (! fi.exists())
-		{
-			if (KMessageBox::warningYesNo(this, i18n("The graphics file does not exist. Proceed any way?")) == KMessageBox::No)
-				return false;
-		}
-	}
-
-	return true;
 }
-
-}
-
-#include "includegraphicsdialog.moc"
