@@ -1,8 +1,7 @@
 /*********************************************************************************************
-    begin                : Sun Jul 20 2003
-    copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                           (C) 2005-2007 by Holger Danielsson (holger.danielsson@versanet.de)
-                           (C) 2006-2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+    Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
+              (C) 2005-2007 by Holger Danielsson (holger.danielsson@versanet.de)
+              (C) 2006-2017 by Michel Ludwig (michel.ludwig@kdemail.net)
  *********************************************************************************************/
 
 /***************************************************************************
@@ -21,7 +20,7 @@
 //  - add some new types of elements (and levels) for the structure view
 //  - new commands, which are passed to the structure listview:
 //       \includegraphics, \caption
-//  - all user defined commands for labels are recognized
+//  - all user-defined commands for labels are recognized
 //  - changed folder name of KileStruct::BibItem to "bibs", so that "refs"
 //    is still unused and can be used for references (if wanted)
 //  - \begin, \end to gather all environments. But only figure and table
@@ -62,17 +61,18 @@
 
 #include "documentinfo.h"
 
+#include <config.h>
+
 #include <QDateTime>
 #include <QFileInfo>
+#include <QInputDialog>
 #include <QRegExp>
 
-#include <KApplication>
 #include <KConfig>
-#include <KGlobal>
 #include <KIconLoader>
-#include <KInputDialog>
-#include <KIO/NetAccess>
-#include <KLocale>
+#include <KJobWidgets>
+#include <KIO/StatJob>
+#include <KLocalizedString>
 #include <KMessageBox>
 
 #include "abbreviationmanager.h"
@@ -83,77 +83,93 @@
 #include "kileconfig.h"
 #include "kiledebug.h"
 #include "kileviewmanager.h"
+#include "parser/bibtexparser.h"
+#include "parser/latexparser.h"
+#include "parser/parsermanager.h"
+#include "livepreview.h"
+#include "utilities.h"
 
 namespace KileDocument
 {
 
-bool Info::containsInvalidCharacters(const KUrl& url)
+bool Info::containsInvalidCharacters(const QUrl &url)
 {
 	QString filename = url.fileName();
 	return filename.contains(" ") || filename.contains("~") || filename.contains("$") || filename.contains("#");
 }
 
-KUrl Info::repairInvalidCharacters(const KUrl& url, QWidget* mainWidget, bool checkForFileExistence /* = true */)
+QUrl Info::repairInvalidCharacters(const QUrl &url, QWidget* mainWidget, bool checkForFileExistence /* = true */)
 {
-	KUrl ret(url);
+	QUrl ret(url);
 	do {
 		bool isOK;
-		QString newURL = KInputDialog::getText(
+		QString newURL = QInputDialog::getText(
+			mainWidget,
 			i18n("Invalid Characters"),
 			i18n("The filename contains invalid characters ($~ #).<br>Please provide "
 			     "another one, or click \"Cancel\" to save anyway."),
-			ret.fileName(),
-			&isOK);
-		if(!isOK)
-			break;
-		ret.setFileName(newURL);
-	} while(containsInvalidCharacters(ret));
-
-	return (checkForFileExistence ? renameIfExist(ret, mainWidget) : ret);
-}
-
-KUrl Info::renameIfExist(const KUrl& url, QWidget* mainWidget)
-{
-	KUrl ret(url);
-	while(KIO::NetAccess::exists(url, true, mainWidget)) { // check for writing possibility
-		bool isOK;
-		QString newURL = KInputDialog::getText(
-			i18n("File Already Exists"),
-			i18n("A file with filename '%1' already exists.<br>Please provide "
-			     "another one, or click \"Cancel\" to overwrite it.", ret.fileName()),
+			QLineEdit::Normal,
 			ret.fileName(),
 			&isOK);
 		if(!isOK) {
 			break;
 		}
-		ret.setFileName(newURL);
+		ret = ret.adjusted(QUrl::RemoveFilename);
+		ret.setPath(ret.path() + newURL);
+	} while(containsInvalidCharacters(ret));
+
+	return (checkForFileExistence ? renameIfExist(ret, mainWidget) : ret);
+}
+
+QUrl Info::renameIfExist(const QUrl &url, QWidget* mainWidget)
+{
+	QUrl ret(url);
+
+	auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, 0);
+	KJobWidgets::setWindow(statJob, mainWidget);
+	while (statJob->exec()) { // check for writing possibility
+		bool isOK;
+		QString newURL = QInputDialog::getText(
+			mainWidget,
+			i18n("File Already Exists"),
+			i18n("A file with filename '%1' already exists.<br>Please provide "
+			     "another one, or click \"Cancel\" to overwrite it.", ret.fileName()),
+			QLineEdit::Normal,
+			ret.fileName(),
+			&isOK);
+		if (!isOK) {
+			break;
+		}
+		ret = ret.adjusted(QUrl::RemoveFilename);
+		ret.setPath(ret.path() + newURL);
 	}
 	return ret;
 }
 
-KUrl Info::repairExtension(const KUrl& url, QWidget *mainWidget, bool checkForFileExistence /* = true */)
+QUrl Info::repairExtension(const QUrl &url, QWidget *mainWidget, bool checkForFileExistence /* = true */)
 {
-	KUrl ret(url);
+	QUrl ret(url);
 
 	QString filename = url.fileName();
 	if(filename.contains(".") && filename[0] != '.') // There already is an extension
 		return ret;
 
-	if(KMessageBox::Yes == KMessageBox::questionYesNo(NULL,
+	if(KMessageBox::Yes == KMessageBox::questionYesNo(Q_NULLPTR,
 		i18n("The given filename has no extension; do you want one to be automatically added?"),
 		i18n("Missing Extension"),
 		KStandardGuiItem::yes(),
 		KStandardGuiItem::no(),
 		"AutomaticallyAddExtension"))
 	{
-		ret.setFileName(filename + ".tex");
+		ret = ret.adjusted(QUrl::RemoveFilename);
+		ret.setPath(ret.path() + filename + ".tex");
 	}
 	return (checkForFileExistence ? renameIfExist(ret, mainWidget) : ret);
 }
 
-KUrl Info::makeValidTeXURL(const KUrl& url, QWidget *mainWidget, bool istexfile, bool checkForFileExistence)
+QUrl Info::makeValidTeXURL(const QUrl &url, QWidget *mainWidget, bool istexfile, bool checkForFileExistence)
 {
-	KUrl newURL(url);
+	QUrl newURL(url);
 
 	//add a .tex extension
 	if(!istexfile) {
@@ -171,7 +187,7 @@ KUrl Info::makeValidTeXURL(const KUrl& url, QWidget *mainWidget, bool istexfile,
 Info::Info() :
  m_bIsRoot(false),
  m_dirty(false),
- m_config(KGlobal::config().data()),
+ m_config(KSharedConfig::openConfig().data()),
  documentTypePromotionAllowed(true)
 {
 	updateStructLevelInfo();
@@ -179,12 +195,12 @@ Info::Info() :
 
 Info::~Info(void)
 {
-	KILE_DEBUG() << "DELETING DOCINFO" << this;
+	KILE_DEBUG_MAIN << "DELETING DOCINFO" << this;
 }
 
 void Info::updateStructLevelInfo()
 {
-	KILE_DEBUG() << "===void Info::updateStructLevelInfo()===";
+	KILE_DEBUG_MAIN << "===void Info::updateStructLevelInfo()===";
 	// read config for structureview items
 	m_showStructureLabels = KileConfig::svShowLabels();
 	m_showStructureReferences = KileConfig::svShowReferences();
@@ -200,13 +216,13 @@ void Info::updateStructLevelInfo()
 	m_openStructureTodo = KileConfig::svOpenTodo();
 }
 
-void Info::setBaseDirectory(const KUrl& url)
+void Info::setBaseDirectory(const QUrl &url)
 {
-	KILE_DEBUG() << "===void Info::setBaseDirectory(const KUrl&" << url << ")===";
+	KILE_DEBUG_MAIN << "===void Info::setBaseDirectory(const QUrl&" << url << ")===";
 	m_baseDirectory = url;
 }
 
-const KUrl& Info::getBaseDirectory() const
+const QUrl &Info::getBaseDirectory() const
 {
 	return m_baseDirectory;
 }
@@ -221,9 +237,9 @@ Type Info::getType()
 	return Undefined;
 }
 
-QString Info::getFileFilter() const
+QLinkedList<Extensions::ExtensionType> Info::getFileFilter() const
 {
-	return QString();
+	return {};
 }
 
 bool Info::isDocumentTypePromotionAllowed()
@@ -243,13 +259,17 @@ bool Info::isDirty() const
 
 void Info::setDirty(bool b)
 {
-KILE_DEBUG() << b;
 	m_dirty = b;
 }
 
-KUrl Info::url()
+void Info::installParserOutput(KileParser::ParserOutput *parserOutput)
 {
-	return KUrl();
+	Q_UNUSED(parserOutput);
+}
+
+QUrl Info::url()
+{
+	return QUrl();
 }
 
 void Info::count(const QString& line, long *stat)
@@ -291,7 +311,7 @@ void Info::count(const QString& line, long *stat)
 					}
 				}
 			break;
-	
+
 			case stControlSequence :
 				if(c.isLetter()) {
 				// "\begin{[a-zA-z]+}" is an environment, and you can't define a command like \begin
@@ -318,7 +338,7 @@ void Info::count(const QString& line, long *stat)
 					state = stStandard;
 				}
 			break;
-	
+
 			case stCommand :
 				if(c.isLetter()) {
 					++stat[1];
@@ -335,7 +355,7 @@ void Info::count(const QString& line, long *stat)
 					state = stStandard;
 				}
 			break;
-	
+
 			case stEnvironment :
 				if(c == TEX_CAT2) { // until we find a closing } we have an environment
 					++stat[1];
@@ -348,7 +368,7 @@ void Info::count(const QString& line, long *stat)
 					++stat[1];
 				}
 			break;
-	
+
 			case stComment : // if we get a selection the line possibly contains \n and so the comment is only valid till \n and not necessarily till line.length()
 				if(c == '\n') {
 					++stat[2]; // \n was counted as punctuation in the old implementation
@@ -356,48 +376,16 @@ void Info::count(const QString& line, long *stat)
 					word = false;
 				}
 			break;
-	
+
 			default :
-				kWarning() << "Unhandled state in getStatistics " << state;
+				qWarning() << "Unhandled state in getStatistics " << state;
 			break;
 		}
 	}
 }
 
-QString Info::lastModifiedFile(const QStringList& list)
-{
-	KILE_DEBUG() << "==QString Info::lastModifiedFile()=====";
-	QFileInfo fileinfo(url().toLocalFile());
-	QString basepath = fileinfo.absolutePath(), last = fileinfo.absoluteFilePath();
-	QDateTime time(fileinfo.lastModified());
-
-	KILE_DEBUG() << "\t" << fileinfo.absoluteFilePath() << " : " << time.toString();
-	for(int i = 0; i < list.count(); ++i) {
-		fileinfo.setFile(basepath + '/' + list[i]);
-		KILE_DEBUG() << "\t" << fileinfo.absoluteFilePath() << " : " << fileinfo.lastModified().toString();
-		if(fileinfo.lastModified() >  time) {
-			time = fileinfo.lastModified();
-			last = fileinfo.absoluteFilePath();
-			KILE_DEBUG() << "\t\tlater";
-		}
-	}
-
-	KILE_DEBUG() << "\treturning " << fileinfo.absoluteFilePath();
-	return last;
-}
-
 void Info::updateStruct()
 {
-	KILE_DEBUG() << "==Info::updateStruct()=======";
-	m_labels.clear();
-	m_bibItems.clear();
-	m_deps.clear();
-	m_bibliography.clear();
-	m_packages.clear();
-	m_newCommands.clear();
-	m_asyFigures.clear();
-	m_bIsRoot = false;
-	m_preamble.clear();
 }
 
 void Info::updateBibItems()
@@ -410,21 +398,16 @@ void Info::slotCompleted()
 	emit completed(this);
 }
 
-
-TextInfo::TextInfo(KTextEditor::Document *doc,
-                   Extensions *extensions,
-                   KileAbbreviation::Manager *abbreviationManager,
+TextInfo::TextInfo(Extensions* extensions,
+                   KileAbbreviation::Manager* abbreviationManager,
+                   KileParser::Manager* parserManager,
                    const QString& defaultMode)
-: m_doc(NULL),
+: m_doc(Q_NULLPTR),
   m_defaultMode(defaultMode),
-  m_abbreviationManager(abbreviationManager)
+  m_abbreviationManager(abbreviationManager),
+  m_parserManager(parserManager)
 {
-	setDoc(doc);
-	if(m_doc) {
-		KILE_DEBUG() << "TextInfo created for " << m_doc->url();
-	}
-
- 	m_arStatistics = new long[SIZE_STAT_ARRAY];
+	m_arStatistics = new long[SIZE_STAT_ARRAY];
 
 	m_extensions = extensions;
 	m_abbreviationCodeCompletionModel = new KileCodeCompletion::AbbreviationCompletionModel(this, m_abbreviationManager);
@@ -432,6 +415,7 @@ TextInfo::TextInfo(KTextEditor::Document *doc,
 
 TextInfo::~TextInfo()
 {
+	emit(aboutToBeDestroyed(this));
 	detach();
 	delete [] m_arStatistics;
 }
@@ -464,7 +448,7 @@ void TextInfo::setDoc(KTextEditor::Document *doc)
 
 void TextInfo::setDocument(KTextEditor::Document *doc)
 {
-	KILE_DEBUG() << "===void TextInfo::setDoc(KTextEditor::Document *doc)===";
+	KILE_DEBUG_MAIN << "===void TextInfo::setDoc(KTextEditor::Document *doc)===";
 
 	if(m_doc == doc) {
 		return;
@@ -473,6 +457,7 @@ void TextInfo::setDocument(KTextEditor::Document *doc)
 	detach();
 	if(doc) {
 		m_doc = doc;
+		m_documentContents.clear();
 		connect(m_doc, SIGNAL(documentNameChanged(KTextEditor::Document*)), this, SLOT(slotFileNameChanged()));
 		connect(m_doc, SIGNAL(documentUrlChanged(KTextEditor::Document*)), this, SLOT(slotFileNameChanged()));
 		connect(m_doc, SIGNAL(completed()), this, SLOT(slotCompleted()));
@@ -494,7 +479,7 @@ void TextInfo::detach()
 		unregisterCodeCompletionModels();
 		emit(documentDetached(m_doc));
 	}
-	m_doc = NULL;
+	m_doc = Q_NULLPTR;
 }
 
 void TextInfo::makeDirtyIfModified()
@@ -514,13 +499,13 @@ const long* TextInfo::getStatistics(KTextEditor::View *view)
 
 	if(view && view->selection()) {
 		line = view->selectionText();
-		KILE_DEBUG() << "line: " << line;
+		KILE_DEBUG_MAIN << "line: " << line;
 		count(line, m_arStatistics);
 	}
 	else if(m_doc) {
 		for(int l = 0; l < m_doc->lines(); ++l) {
 			line = m_doc->line(l);
-			KILE_DEBUG() << "line : " << line;
+			KILE_DEBUG_MAIN << "line : " << line;
 			count(line, m_arStatistics);
 		}
 	}
@@ -528,13 +513,13 @@ const long* TextInfo::getStatistics(KTextEditor::View *view)
 	return m_arStatistics;
 }
 
-KUrl TextInfo::url()
+QUrl TextInfo::url()
 {
 	if(m_doc) {
 		return m_doc->url();
 	}
 	else {
-		return KUrl();
+		return QUrl();
 	}
 }
 
@@ -550,7 +535,7 @@ bool TextInfo::isTextDocument()
 
 void TextInfo::setMode(const QString &mode)
 {
-	KILE_DEBUG() << "==Kile::setMode(" << m_doc->url() << "," << mode << " )==================";
+	KILE_DEBUG_MAIN << "==Kile::setMode(" << m_doc->url() << "," << mode << " )==================";
 
 	if (m_doc && !mode.isEmpty()) {
 		m_doc->setMode(mode);
@@ -559,7 +544,7 @@ void TextInfo::setMode(const QString &mode)
 
 void TextInfo::setHighlightingMode(const QString& highlight)
 {
-	KILE_DEBUG() << "==Kile::setHighlightingMode(" << m_doc->url() << "," << highlight << " )==================";
+	KILE_DEBUG_MAIN << "==Kile::setHighlightingMode(" << m_doc->url() << "," << highlight << " )==================";
 
 	if (m_doc && !highlight.isEmpty()) {
 		m_doc->setHighlightingMode(highlight);
@@ -660,12 +645,13 @@ void TextInfo::searchTodoComment(const QString &s, uint startpos, TodoResult &to
 KTextEditor::View* TextInfo::createView(QWidget *parent, const char* /* name */)
 {
 	if(!m_doc) {
-		return NULL;
+		return Q_NULLPTR;
 	}
 	KTextEditor::View *view = m_doc->createView(parent);
 	installEventFilters(view);
 	installSignalConnections(view);
 	registerCodeCompletionModels(view);
+	view->setStatusBarEnabled(false);
 	connect(view, SIGNAL(destroyed(QObject*)), this, SLOT(slotViewDestroyed(QObject*)));
 	return view;
 }
@@ -834,25 +820,44 @@ void TextInfo::slotViewDestroyed(QObject *object)
 
 void TextInfo::activateDefaultMode()
 {
-	KILE_DEBUG() << "m_defaultMode = " <<  m_defaultMode << endl;
+	KILE_DEBUG_MAIN << "m_defaultMode = " <<  m_defaultMode << endl;
 
 	if(m_doc && !m_defaultMode.isEmpty()) {
 		m_doc->setMode(m_defaultMode);
 	}
 }
 
-LaTeXInfo::LaTeXInfo(KTextEditor::Document *doc,
-                     Extensions *extensions,
-                     KileAbbreviation::Manager *abbreviationManager,
-                     LatexCommands *commands,
-                     KileDocument::EditorExtension *editorExtension,
+const QStringList TextInfo::documentContents() const
+{
+	if (m_doc) {
+		return m_doc->textLines(m_doc->documentRange());
+	}
+	else {
+		return m_documentContents;
+	}
+}
+
+void TextInfo::setDocumentContents(const QStringList& contents)
+{
+	m_documentContents = contents;
+}
+
+LaTeXInfo::LaTeXInfo(Extensions* extensions,
+                     KileAbbreviation::Manager* abbreviationManager,
+                     LatexCommands* commands,
+                     EditorExtension* editorExtension,
                      KileConfiguration::Manager* manager,
-                     KileCodeCompletion::Manager *codeCompletionManager)
-: TextInfo(doc, extensions, abbreviationManager, "LaTeX"),
+                     KileCodeCompletion::Manager* codeCompletionManager,
+                     KileTool::LivePreviewManager* livePreviewManager,
+                     KileView::Manager *viewManager,
+                     KileParser::Manager* parserManager)
+: TextInfo(extensions, abbreviationManager, parserManager, "LaTeX"),
   m_commands(commands),
   m_editorExtension(editorExtension),
   m_configurationManager(manager),
-  m_eventFilter(NULL)
+  m_eventFilter(Q_NULLPTR),
+  m_livePreviewManager(livePreviewManager),
+  m_viewManager(viewManager)
 {
 	documentTypePromotionAllowed = false;
 	updateStructLevelInfo();
@@ -870,9 +875,9 @@ Type LaTeXInfo::getType()
 	return LaTeX;
 }
 
-QString LaTeXInfo::getFileFilter() const
+QLinkedList<Extensions::ExtensionType> LaTeXInfo::getFileFilter() const
 {
-	return m_extensions->latexDocumentFileFilter() + '\n' + m_extensions->latexPackageFileFilter();
+	return {Extensions::TEX, Extensions::PACKAGES};
 }
 
 void LaTeXInfo::startLaTeXCompletion(KTextEditor::View *view)
@@ -890,7 +895,7 @@ void LaTeXInfo::startLaTeXCompletion(KTextEditor::View *view)
 
 void LaTeXInfo::updateStructLevelInfo() {
 
-	KILE_DEBUG() << "===void LaTeXInfo::updateStructLevelInfo()===";
+	KILE_DEBUG_MAIN << "===void LaTeXInfo::updateStructLevelInfo()===";
 
 	// read config stuff
 	Info::updateStructLevelInfo();
@@ -908,7 +913,6 @@ void LaTeXInfo::updateStructLevelInfo() {
 	m_dictStructLevel["\\subsubsection"] = KileStructData(5, KileStruct::Sect, "subsubsection");
 	m_dictStructLevel["\\paragraph"] = KileStructData(6, KileStruct::Sect, "subsubsection");
 	m_dictStructLevel["\\subparagraph"] = KileStructData(7, KileStruct::Sect, "subsubsection");
-	m_dictStructLevel["\\bibliography"] = KileStructData(0,KileStruct::Bibliography, "viewbib");
 
 	// hidden commands
 	m_dictStructLevel["\\usepackage"] = KileStructData(KileStruct::Hidden, KileStruct::Package);
@@ -935,10 +939,10 @@ void LaTeXInfo::updateStructLevelInfo() {
 		m_dictStructLevel["\\end"] = KileStructData(KileStruct::Hidden,KileStruct::EndEnv);
 
 		// some entries, which could never be found (but they are set manually)
-		m_dictStructLevel["\\begin{figure}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "image-x-generic");
-		m_dictStructLevel["\\begin{figure*}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "image-x-generic");
-		m_dictStructLevel["\\begin{table}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "tabular");
-		m_dictStructLevel["\\begin{table*}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "tabular");
+		m_dictStructLevel["\\begin{figure}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "figure-env");
+		m_dictStructLevel["\\begin{figure*}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "figure-env");
+		m_dictStructLevel["\\begin{table}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "table-env");
+		m_dictStructLevel["\\begin{table*}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "table-env");
 		m_dictStructLevel["\\begin{asy}"]=KileStructData(KileStruct::Object,KileStruct::BeginFloat, "image-x-generic");
 		m_dictStructLevel["\\end{float}"]=KileStructData(KileStruct::Hidden,KileStruct::EndFloat);
 	}
@@ -950,7 +954,7 @@ void LaTeXInfo::updateStructLevelInfo() {
 	m_dictStructLevel["\\end{frame}"] = KileStructData(KileStruct::Hidden, KileStruct::BeamerEndFrame);
 	m_dictStructLevel["\\begin{block}"] = KileStructData(KileStruct::Object, KileStruct::BeamerBeginBlock, "beamerblock");
 
-	// add user defined commands
+	// add user-defined commands
 
 	QStringList list;
 	QStringList::ConstIterator it;
@@ -965,7 +969,7 @@ void LaTeXInfo::updateStructLevelInfo() {
 	if(m_showStructureInputFiles) {
 		m_commands->commandList(list, KileDocument::CmdAttrIncludes, false);
 		for(it = list.constBegin(); it != list.constEnd(); ++it) {
-			m_dictStructLevel[*it] = KileStructData(KileStruct::File, KileStruct::Input, "include");
+			m_dictStructLevel[*it] = KileStructData(KileStruct::File, KileStruct::Input, "input-file");
 		}
 	}
 
@@ -976,6 +980,12 @@ void LaTeXInfo::updateStructLevelInfo() {
 			m_dictStructLevel[*it] = KileStructData(KileStruct::Hidden, KileStruct::Reference);
 		}
 	}
+
+	//bibliography commands
+	m_commands->commandList(list,KileDocument::CmdAttrBibliographies, false);
+	for(it=list.constBegin(); it != list.constEnd(); ++it) {
+		m_dictStructLevel[*it] = KileStructData(0, KileStruct::Bibliography, "viewbib");
+	}
 }
 
 QList<QObject*> LaTeXInfo::createEventFilters(KTextEditor::View *view)
@@ -987,14 +997,24 @@ QList<QObject*> LaTeXInfo::createEventFilters(KTextEditor::View *view)
 	return toReturn;
 }
 
-void LaTeXInfo::installSignalConnections(KTextEditor::View * /* view */)
+void LaTeXInfo::installSignalConnections(KTextEditor::View *view)
 {
-
+	connect(view, &KTextEditor::View::cursorPositionChanged,
+	        m_viewManager, &KileView::Manager::handleCursorPositionChanged);
+	connect(view->document(), &KTextEditor::Document::textChanged,
+	        m_livePreviewManager, &KileTool::LivePreviewManager::handleTextChanged, Qt::UniqueConnection);
+	connect(view->document(), &KTextEditor::Document::documentSavedOrUploaded,
+	        m_livePreviewManager, &KileTool::LivePreviewManager::handleDocumentSavedOrUploaded, Qt::UniqueConnection);
 }
 
-void LaTeXInfo::removeSignalConnections(KTextEditor::View * /* view */)
+void LaTeXInfo::removeSignalConnections(KTextEditor::View *view)
 {
-
+	disconnect(view, &KTextEditor::View::cursorPositionChanged,
+	        m_viewManager, &KileView::Manager::handleCursorPositionChanged);
+	disconnect(view->document(), &KTextEditor::Document::textChanged,
+	           m_livePreviewManager, &KileTool::LivePreviewManager::handleTextChanged);
+	disconnect(view->document(), &KTextEditor::Document::documentSavedOrUploaded,
+	           m_livePreviewManager, &KileTool::LivePreviewManager::handleDocumentSavedOrUploaded);
 }
 
 void LaTeXInfo::registerCodeCompletionModels(KTextEditor::View *view)
@@ -1047,339 +1067,53 @@ BracketResult LaTeXInfo::matchBracket(int &l, int &pos)
 	return result;
 }
 
-//FIXME refactor, clean this mess up
 void LaTeXInfo::updateStruct()
 {
-	KILE_DEBUG() << "==void TeXInfo::updateStruct: (" << url() << ")=========";
+	KILE_DEBUG_MAIN << "==void TeXInfo::updateStruct: (" << url() << ")=========";
 
-	if(!getDoc()) {
-		return;
-	}
-
-	Info::updateStruct();
-
-	QMap<QString,KileStructData>::const_iterator it;
-	static QRegExp reCommand("(\\\\[a-zA-Z]+)\\s*\\*?\\s*(\\{|\\[)");
-	static QRegExp reRoot("\\\\documentclass|\\\\documentstyle");
-	static QRegExp reBD("\\\\begin\\s*\\{\\s*document\\s*\\}");
-	static QRegExp reReNewCommand("\\\\renewcommand.*$");
-	static QRegExp reNumOfParams("\\s*\\[([1-9]+)\\]");
-	static QRegExp reNumOfOptParams("\\s*\\[([1-9]+)\\]\\s*\\[([^\\{]*)\\]"); // the quantifier * isn't used by mistake, because also emtpy optional brackets are correct.
-
-	int teller=0, tagStart, bd = 0;
-	int tagEnd, tagLine = 0, tagCol = 0;
-	int tagStartLine = 0, tagStartCol = 0;
-	BracketResult result;
-	QString m, s, shorthand;
-	bool foundBD = false; // found \begin { document }
-	bool fire = true; //whether or not we should emit a foundItem signal
-	bool fireSuspended; // found an item, but it should not be fired (this time)
-	TodoResult todo;
-
-	emit(parsingStarted(m_doc->lines()));
-	for(int i = 0; i < m_doc->lines(); ++i) {
-		emit(parsingUpdate(i));
-		if (teller > 100) {
-			teller = 0;
-			kapp->processEvents(QEventLoop::ExcludeUserInputEvents);
-		}
-		else {
-			++teller;
-		}
-
-		tagStart = tagEnd = 0;
-		fire = true;
-		s = getTextline(i,todo);
-		if(todo.type!=-1 && m_showStructureTodo) {
-			QString folder = (todo.type == KileStruct::ToDo) ? "todo" : "fixme";
-			emit( foundItem(todo.comment, i+1, todo.colComment, todo.type, KileStruct::Object, i+1, todo.colTag, QString(), folder) );
-		}
-
-
-		if(s.isEmpty()) {
-			continue;
-		}
-
-		//ignore renewcommands
-		s.remove(reReNewCommand);
-
-		//find all commands in this line
-		while(tagStart != -1) {
-			if((!foundBD) && ((bd = s.indexOf(reBD, tagEnd)) != -1)) {
-				KILE_DEBUG() << "\tfound \\begin{document}";
-				foundBD = true;
-				if(bd == 0) {
-					m_preamble = m_doc->text(KTextEditor::Range(0, 0, i - 1, m_doc->line(i - 1).length()));
-				}
-				else {
-					m_preamble = m_doc->text(KTextEditor::Range(0, 0, i, bd));
-				}
-			}
-
-			if((!foundBD) && (s.indexOf(reRoot, tagEnd) != -1)) {
-				KILE_DEBUG() << "\tsetting m_bIsRoot to true";
-				tagEnd += reRoot.cap(0).length();
-				m_bIsRoot = true;
-			}
-
-			tagStart = reCommand.indexIn(s, tagEnd);
-			m.clear();
-			shorthand.clear();
-
-			if(tagStart != -1) {
-				tagEnd = tagStart + reCommand.cap(0).length()-1;
-
-				//look up the command in the dictionary
-				it = m_dictStructLevel.constFind(reCommand.cap(1));
-
-				//if it is was a structure element, find the title (or label)
-				if(it != m_dictStructLevel.constEnd()) {
-					tagLine = i+1;
-					tagCol = tagEnd+1;
-					tagStartLine = tagLine;
-					tagStartCol = tagStart+1;
-					if(reCommand.cap(1) != "\\frame") {
-						result = matchBracket(i, tagEnd);
-						m = result.value.trimmed();
-						shorthand = result.option.trimmed();
-						if(i >= tagLine) { //matching brackets spanned multiple lines
-							s = m_doc->line(i);
-						}
-						if(result.line > 0 || result.col > 0) {
-							tagLine = result.line + 1;
-							tagCol = result.col + 1;
-						}
-					//KILE_DEBUG() << "\tgrabbed: " << reCommand.cap(1) << "[" << shorthand << "]{" << m << "}";
-					}
-					else {
-						m = i18n("Frame");
-					}
-				}
-
-				//title (or label) found, add the element to the listview
-				if(!m.isNull()) {
-					// no problems so far ...
-					fireSuspended = false;
-
-					// remove trailing ./
-					if((*it).type & (KileStruct::Input | KileStruct::Graphics)) {
-						if(m.left(2) == "./") {
-							m = m.mid(2, m.length() - 2);
-						}
-					}
-					// update parameter for environments, because only
-					// floating environments and beamer frames are passed
-					if ( (*it).type == KileStruct::BeginEnv )
-					{
-						if ( m=="figure" || m=="figure*" || m=="table" || m=="table*" )
-						{
-							it = m_dictStructLevel.constFind("\\begin{" + m +'}');
-						}
-						else if(m == "asy") {
-							it = m_dictStructLevel.constFind("\\begin{" + m +'}');
-							m_asyFigures.append(m);
-						}
-						else if(m == "frame") {
-							it = m_dictStructLevel.constFind("\\begin{frame}");
-							m = i18n("Frame");
-						}
-						else if(m=="block" || m=="exampleblock" || m=="alertblock") {
-							const QString untitledBlockDisplayName = i18n("Untitled Block");
-							it = m_dictStructLevel.constFind("\\begin{block}");
-							if(tagEnd+1 < s.size() && s.at(tagEnd+1) == '{') {
-								tagEnd++;
-								result = matchBracket(i, tagEnd);
-								m = result.value.trimmed();
-								if(m.isEmpty()) {
-									m = untitledBlockDisplayName;
-								}
-							}
-							else {
-								m = untitledBlockDisplayName;
-							}
-						}
-						else {
-							fireSuspended = true;    // only floats and beamer frames, no other environments
-						}
-					}
-
-					// tell structure view that a floating environment or a beamer frame must be closed
-					else if ( (*it).type == KileStruct::EndEnv )
-					{
-						if ( m=="figure" || m== "figure*" || m=="table" || m=="table*" || m=="asy")
-						{
-							it = m_dictStructLevel.constFind("\\end{float}");
-						}
-						else if(m == "frame") {
-							it = m_dictStructLevel.constFind("\\end{frame}");
-						}
-						else {
-							fireSuspended = true;          // only floats, no other environments
-						}
-					}
-					// sectioning commands
-					else if((*it).type == KileStruct::Sect) {
-						if(!shorthand.isEmpty()) {
-							m = shorthand;
-						}
-					}
-
-					// update the label list
-					else if((*it).type == KileStruct::Label) {
-						m_labels.append(m);
-						// label entry as child of sectioning
-						if(m_showSectioningLabels) {
-							emit(foundItem(m, tagLine, tagCol, KileStruct::Label, KileStruct::Object, tagStartLine, tagStartCol, "label", "root") );
-							fireSuspended = true;
-						}
-					}
-
-					// update the references list
-					else if((*it).type == KileStruct::Reference) {
-						// m_references.append(m);
-						//fireSuspended = true;          // don't emit references
-					}
-
-					// update the dependencies
-					else if((*it).type == KileStruct::Input) {
-						// \input- or \include-commands can be used without extension. So we check
-						// if an extension exists. If not the default extension is added
-						// ( LaTeX reference says that this is '.tex'). This assures that
-						// all files, which are listed in the structure view, have an extension.
-						QString ext = QFileInfo(m).completeSuffix();
-						if(ext.isEmpty()) {
-							m += m_extensions->latexDocumentDefault();
-						}
-						m_deps.append(m);
-					}
-
-					// update the referenced Bib files
-					else  if((*it).type == KileStruct::Bibliography) {
-						KILE_DEBUG() << "===TeXInfo::updateStruct()===appending Bibiliograph file(s) " << m;
-
-						QStringList bibs = m.split(',');
-						QString biblio;
-
-						// assure that all files have an extension
-						QString bibext = m_extensions->bibtexDefault();
-						int bibextlen = bibext.length();
-
-						uint cumlen = 0;
-						int nextbib = 0; // length to add to jump to the next bibliography
-						for(int b = 0; b < bibs.count(); ++b) {
-							nextbib = 0;
-							biblio=bibs[b];
-							m_bibliography.append(biblio);
-							if(biblio.left(2) == "./") {
-								nextbib += 2;
-								biblio = biblio.mid(2, biblio.length() - 2);
-							}
-							if(biblio.right(bibextlen) != bibext) {
-								biblio += bibext;
-								nextbib -= bibextlen;
-							}
-							m_deps.append(biblio);
-							emit( foundItem(biblio, tagLine, tagCol+cumlen, (*it).type, (*it).level, tagStartLine, tagStartCol, (*it).pix, (*it).folder) );
-							cumlen += biblio.length() + 1 + nextbib;
-						}
-						fire = false;
-					}
-
-					// update the bibitem list
-					else if((*it).type == KileStruct::BibItem) {
-						//KILE_DEBUG() << "\tappending bibitem " << m;
-						m_bibItems.append(m);
-					}
-
-					// update the package list
-					else if((*it).type == KileStruct::Package) {
-						QStringList pckgs = m.split(',');
-						uint cumlen = 0;
-						for(int p = 0; p < pckgs.count(); ++p) {
-							QString package = pckgs[p].trimmed();
-							if(!package.isEmpty()) {
-								m_packages.append(package);
-								// hidden, so emit is useless
-								// emit( foundItem(package, tagLine, tagCol+cumlen, (*it).type, (*it).level, tagStartLine, tagStartCol, (*it).pix, (*it).folder) );
-								cumlen += package.length() + 1;
-							}
-						}
-						fire = false;
-					}
-
-					// newcommand found, add it to the newCommands list
-					else if((*it).type & (KileStruct::NewCommand | KileStruct::NewEnvironment)) {
-						QString optArg, mandArgs;
-
-						//find how many parameters this command takes
-						if(s.indexOf(reNumOfParams, tagEnd + 1) != -1) {
-							bool ok;
-							int noo = reNumOfParams.cap(1).toInt(&ok);
-
-							if(ok) {
-								if(s.indexOf(reNumOfOptParams, tagEnd + 1) != -1) {
-									KILE_DEBUG() << "Opt param is " << reNumOfOptParams.cap(2) << "%EOL";
-									noo--; // if we have an opt argument, we have one mandatory argument less, and noo=0 can't occur because then latex complains (and we don't macht them with reNumOfParams either)
-									optArg = '[' + reNumOfOptParams.cap(2) + ']';
-								}
-
-								for(int noo_index = 0; noo_index < noo; ++noo_index) {
-									mandArgs +=  '{' + s_bullet + '}';
-								}
-
-							}
-							if(!optArg.isEmpty()) {
-								if((*it).type == KileStruct::NewEnvironment) {
-									m_newCommands.append(QString("\\begin{%1}%2%3").arg(m).arg(optArg).arg(mandArgs));
-								}
-								else {
-									m_newCommands.append(m + optArg + mandArgs);
-								}
-							}
-						}
-						if((*it).type == KileStruct::NewEnvironment) {
-							m_newCommands.append(QString("\\begin{%1}%3").arg(m).arg(mandArgs));
-							m_newCommands.append(QString("\\end{%1}").arg(m));
-						}
-						else {
-							m_newCommands.append(m + mandArgs);
-						}
-						//FIXME  set tagEnd to the end of the command definition
-						break;
-					}
-					// and some other commands, which don't need special actions:
-					// \caption, ...
-
-					// KILE_DEBUG() << "\t\temitting: " << m;
-					if(fire && !fireSuspended) {
-						emit( foundItem(m, tagLine, tagCol, (*it).type, (*it).level, tagStartLine, tagStartCol, (*it).pix, (*it).folder) );
-					}
-				} //if m
-			} // if tagStart
-		} // while tagStart
-	} //for
-
-	checkChangedDeps();
-	emit(doneUpdating());
-	emit(isrootChanged(isLaTeXRoot()));
-	emit(parsingCompleted());
-	setDirty(false);
+	m_parserManager->parseDocument(this);
 }
 
 void LaTeXInfo::checkChangedDeps()
 {
 	if(m_depsPrev != m_deps) {
-		KILE_DEBUG() << "===void LaTeXInfo::checkChangedDeps()===, deps have changed"<< endl;
+		KILE_DEBUG_MAIN << "===void LaTeXInfo::checkChangedDeps()===, deps have changed"<< endl;
 		emit(depChanged());
 		m_depsPrev = m_deps;
 	}
 }
 
-BibInfo::BibInfo (KTextEditor::Document *doc,
-                  Extensions *extensions,
-                  KileAbbreviation::Manager *abbreviationManager,
-                  LatexCommands* /* commands */)
-: TextInfo(doc, extensions, abbreviationManager, "BibTeX")
+void LaTeXInfo::installParserOutput(KileParser::ParserOutput *parserOutput)
+{
+	KILE_DEBUG_MAIN;
+	KileParser::LaTeXParserOutput *latexParserOutput = dynamic_cast<KileParser::LaTeXParserOutput*>(parserOutput);
+	Q_ASSERT(latexParserOutput);
+	if(!latexParserOutput) {
+		KILE_DEBUG_MAIN << "wrong type given";
+		return;
+	}
+
+	m_labels = latexParserOutput->labels;
+	m_bibItems = latexParserOutput->bibItems;
+	m_deps = latexParserOutput->deps;
+	m_bibliography = latexParserOutput->bibliography;
+	m_packages = latexParserOutput->packages;
+	m_newCommands = latexParserOutput->newCommands;
+	m_asyFigures = latexParserOutput->asyFigures;
+	m_preamble = latexParserOutput->preamble;
+	m_bIsRoot = latexParserOutput->bIsRoot;
+
+	checkChangedDeps();
+	emit(isrootChanged(isLaTeXRoot()));
+	setDirty(false);
+	emit(parsingComplete());
+}
+
+BibInfo::BibInfo(Extensions* extensions,
+                 KileAbbreviation::Manager* abbreviationManager,
+                 KileParser::Manager* parserManager,
+                 LatexCommands* /* commands */)
+: TextInfo(extensions, abbreviationManager, parserManager, "BibTeX")
 {
 	documentTypePromotionAllowed = false;
 }
@@ -1395,86 +1129,23 @@ bool BibInfo::isLaTeXRoot()
 
 void BibInfo::updateStruct()
 {
-	if(!getDoc()) {
+	m_parserManager->parseDocument(this);
+}
+
+void BibInfo::installParserOutput(KileParser::ParserOutput *parserOutput)
+{
+	KILE_DEBUG_MAIN;
+	KileParser::BibTeXParserOutput *bibtexParserOutput = dynamic_cast<KileParser::BibTeXParserOutput*>(parserOutput);
+	Q_ASSERT(bibtexParserOutput);
+	if(!bibtexParserOutput) {
+		KILE_DEBUG_MAIN << "wrong type given";
 		return;
 	}
 
-	Info::updateStruct();
+	m_bibItems = bibtexParserOutput->bibItems;
 
-	KILE_DEBUG() << "==void BibInfo::updateStruct()========";
-
-	static QRegExp reItem("^(\\s*)@([a-zA-Z]+)");
-	static QRegExp reSpecial("string|preamble|comment");
-
-	QString s, key;
-	int col = 0, startcol, startline = 0;
-	int teller = 0;
-
-	emit(parsingStarted(m_doc->lines()));
-	for(int i = 0; i < m_doc->lines(); ++i) {
-		emit(parsingUpdate(i));
-		if (teller > 200) {
-			teller = 0;
-			kapp->processEvents(QEventLoop::ExcludeUserInputEvents);
-		}
-		else {
-			++teller;
-		}
-		s = m_doc->line(i);
-		if((s.indexOf(reItem) != -1) && !reSpecial.exactMatch(reItem.cap(2).toLower())) {
-			KILE_DEBUG() << "found: " << reItem.cap(2);
-			//start looking for key
-			key = "";
-			bool keystarted = false;
-			int state = 0;
-			startcol = reItem.cap(1).length();
-			col  = startcol + reItem.cap(2).length();
-
-			while(col < static_cast<int>(s.length())) {
-				++col;
-				if(col == static_cast<int>(s.length())) {
-					do {
-						++i;
-						s = m_doc->line(i);
-					}
-					while((s.length() == 0) && (i < m_doc->lines()));
-
-					if(i == m_doc->lines()) {
-						break;
-					}
-					col = 0;
-				}
-
-				if(state == 0) {
-					if(s[col] == '{') {
-						state = 1;
-					}
-					else if(!s[col].isSpace()) {
-						break;
-					}
-				}
-				else if(state == 1) {
-					if(s[col] == ',') {
-						key = key.trimmed();
-						KILE_DEBUG() << "found: " << key;
-						m_bibItems.append(key);
-						emit(foundItem(key, startline+1, startcol, KileStruct::BibItem, 0, startline+1, startcol, "viewbib", reItem.cap(2).toLower()) );
-						break;
-					}
-					else {
-						key += s[col];
-						if(!keystarted) {
-							startcol = col; startline = i;
-						}
-						keystarted=true;
-					}
-				}
-			}
-		}
-	}
-	emit(parsingCompleted());
-	emit(doneUpdating());
 	setDirty(false);
+	emit(parsingComplete());
 }
 
 Type BibInfo::getType()
@@ -1482,15 +1153,15 @@ Type BibInfo::getType()
 	return BibTeX;
 }
 
-QString BibInfo::getFileFilter() const
+QLinkedList<Extensions::ExtensionType> BibInfo::getFileFilter() const
 {
-	return m_extensions->bibtexFileFilter();
+	return {Extensions::BIB};
 }
 
-ScriptInfo::ScriptInfo(KTextEditor::Document *doc,
-                       Extensions *extensions,
-                       KileAbbreviation::Manager *abbreviationManager)
-: TextInfo(doc, extensions, abbreviationManager, "JavaScript")
+ScriptInfo::ScriptInfo(Extensions* extensions,
+                       KileAbbreviation::Manager* abbreviationManager,
+                       KileParser::Manager* parserManager)
+: TextInfo(extensions, abbreviationManager, parserManager, "JavaScript")
 {
 	documentTypePromotionAllowed = false;
 }
@@ -1509,11 +1180,10 @@ Type ScriptInfo::getType()
 	return Script;
 }
 
-QString ScriptInfo::getFileFilter() const
+QLinkedList<Extensions::ExtensionType> ScriptInfo::getFileFilter() const
 {
-	return m_extensions->scriptFileFilter();
+	return {Extensions::JS};
 }
 
 }
 
-#include "documentinfo.moc"
