@@ -22,22 +22,17 @@
 #include <QMouseEvent>
 #include <QKeyEvent>
 
+#include <KModifierKeyInfo>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
-#if KDE_IS_VERSION(4,3,0)
-#include <KModifierKeyInfo>
-#endif
-
 #include "kiledebug.h"
 #include "editorextension.h"
 #include "kileconfig.h"
 
 LaTeXEventFilter::LaTeXEventFilter(KTextEditor::View *view, KileDocument::EditorExtension *edit) : QObject(view), m_view(view), m_edit(edit)
 {
-#if KDE_IS_VERSION(4,3,0)
 	m_modifierKeyInfo = new KModifierKeyInfo(this);
-#endif
 	readConfig();
 }
 
@@ -49,12 +44,8 @@ void LaTeXEventFilter::readConfig()
 // querying the caps lock state directly is currrently not supported by Qt
 bool LaTeXEventFilter::isCapsLockEnabled()
 {
-#if KDE_IS_VERSION(4,3,0)
 	return m_modifierKeyInfo->isKeyLatched(Qt::Key_CapsLock)
 	       || m_modifierKeyInfo->isKeyLocked(Qt::Key_CapsLock);
-#else
-	return false;
-#endif
 }
 
 //FIXME: there should be one central place to convert unicode chars to LaTeX;
@@ -70,7 +61,7 @@ bool LaTeXEventFilter::eventFilter(QObject* /* o */, QEvent *e)
 		if (ime->commitString().size() == 1) {
 			// Extract unicode representation:
 			unsigned short rep = ime->commitString().at(0).unicode();
-			KILE_DEBUG() << "string= "<< ime->commitString().at(0) << " dec= "<< rep;
+			KILE_DEBUG_MAIN << "string= "<< ime->commitString().at(0) << " dec= "<< rep;
 			return m_edit->insertLatexFromUnicode(rep, m_view);
 		}
 	}
@@ -262,4 +253,3 @@ bool LaTeXEventFilter::eventFilter(QObject* /* o */, QEvent *e)
 }
 
 
-#include "eventfilter.moc"
