@@ -27,24 +27,19 @@
 #include <QWidget>
 #include <QSignalMapper>
 
-#include <kdeversion.h>
 #include <KTextEditor/View>
 #include <KTextEditor/Document>
-#include <kparts/mainwindow.h>
-#include <kparts/partmanager.h>
-#include <kparts/part.h>
 #include <ktogglefullscreenaction.h>
 #include <KXmlGuiWindow>
 
-#include "docpart.h"
 #include "widgets/filebrowserwidget.h"
 #include "kileinfo.h"
 #include "kileactions.h"
+#include "kileversion.h"
 #include "widgets/symbolview.h"
 #include "widgets/commandview.h"
 
 #include "outputinfo.h"
-#include "latexoutputfilter.h"
 
 #include "codecompletion.h"        // code completion (dani)
 #include "editorextension.h"              // advanced editor (dani)
@@ -52,36 +47,38 @@
 #include "quickpreview.h"
 #include "widgets/abbreviationview.h"
 
-#define ID_HINTTEXT         301
-#define ID_LINE_COLUMN      302
-#define ID_VIEW_MODE        303
-#define ID_SELECTION_MODE   304
-
-#define KILERC_VERSION 7
-
 class QFileInfo;
 class QTimer;
 class QSignalMapper;
 
 class KToolBar;
-class KAction;
+class QAction;
 class KActionMenu;
 class KRecentFilesAction;
 class KToggleFullScreenAction;
 class KToggleToolBarAction;
 class KMultiTabBar;
 
+namespace KParts { class MainWindow; }
+
 class KileLyxServer;
 class KileProject;
 class KileProjectItem;
 class TemplateItem;
 class KileAutoSaveJob;
-class KileErrorHandler;
 
 namespace KileAction { class TagData; }
 namespace KileDocument { class Info; class TextInfo; class Extensions; }
 namespace KileTool { class Manager; class Factory; }
-namespace KileWidget { class LogWidget; class Output; class Konsole; class StructureWidget; class SideBar; class BottomBar; }
+namespace KileWidget {
+	class LogWidget;
+	class Output;
+	class Konsole;
+	class StructureWidget;
+	class SideBar;
+	class BottomBar;
+	class StatusBar;
+}
 
 //TODO remove once we stop supporting pre 1.7 user tools
 struct userItem
@@ -90,28 +87,24 @@ struct userItem
 };
 
 /**
- * The Kile main class. It acts as information manager and DBUS interface. It also manages the main window.
+ * The Kile main class. It acts as information manager and DBUS interface.
  **/
 class Kile : public KParts::MainWindow, public KileInfo
 {
 	Q_OBJECT
 
 public:
-	explicit Kile(bool allowRestore = true, QWidget *parent = 0, const char *name = 0);
+	explicit Kile(bool allowRestore = true, QWidget *parent = Q_NULLPTR);
 	~Kile();
 
 	int lineNumber();
+	KileWidget::StatusBar * statusBar();
 
 public Q_SLOTS:
-	void setCursor(const KUrl &, int, int);
+	void setCursor(const QUrl &, int, int);
 
-	int run(const QString &);
-	int runWith(const QString &, const QString &);
 	void runArchiveTool();
-	void runArchiveTool(const KUrl&);
-	void showTip();
-
-	void prepareForPart(const QString &);
+	void runArchiveTool(const QUrl&);
 
 	void updateModeStatus();
 	void newCaption();
@@ -119,6 +112,9 @@ public Q_SLOTS:
 
 	void rebuildBibliographyMenu();
 
+	void openDocument(const QUrl &url);
+	void openProject(const QUrl &url);
+
 	// D-Bus Interface
 	void openDocument(const QString & url);
 	void closeDocument();
@@ -128,12 +124,15 @@ public Q_SLOTS:
 	 **/
 	void setLine(const QString &line);
 	void openProject(const QString& proj);
-	int runTool(const QString& tool);
-	int runToolWithConfig(const QString &tool, const QString &config);
+	void runTool(const QString& tool);
+	void runToolWithConfig(const QString &tool, const QString &config);
 	void insertText(const QString &text);
+	void insertTag(const KileAction::TagData& td);
+
+Q_SIGNALS:
+	void masterDocumentChanged();
 
 protected:
-	virtual bool queryExit();
 	virtual bool queryClose();
 
 private:
@@ -145,9 +144,9 @@ private:
 	ToolbarSelectAction			*m_compilerActions, *m_viewActions, *m_convertActions, *m_quickActions;
 	QList<KileAction::TagData>		m_listUserTags;
 	QList<userItem>				m_listUserTools;
-	QList<QAction*> 			m_listUserTagsActions, m_listQuickActions, m_listCompilerActions, m_listConverterActions, m_listViewerActions, m_listOtherActions;
+	QList<QAction*> 			m_listQuickActions, m_listCompilerActions, m_listConverterActions, m_listViewerActions, m_listOtherActions;
 	KActionMenu 				*m_bibTagActionMenu;
-	KAction 				*m_paStop, *m_paPrint;
+	QAction *m_paStop, *m_paPrint;
 	KToggleAction 				*ModeAction, *WatchFileAction;
 	KToggleAction 				*m_actionMessageView;
 	KRecentFilesAction			*m_actRecentFiles;
@@ -164,31 +163,20 @@ private:
 	KileWidget::SymbolView		*m_symbolViewMFUS, *m_symbolViewRelation, *m_symbolViewArrows, *m_symbolViewMiscMath, *m_symbolViewMiscText, *m_symbolViewOperators, *m_symbolViewUser, *m_symbolViewDelimiters, *m_symbolViewGreek, *m_symbolViewSpecial, *m_symbolViewCyrillic;
 	KileWidget::CommandView *m_commandView;
 	KToolBar			*m_latexOutputErrorToolBar;
-    QMenu               *m_buildMenuTopLevel, *m_buildMenuCompile, *m_buildMenuConvert, *m_buildMenuViewer, *m_buildMenuOther, *m_buildMenuQuickPreview, *m_userTagMenu;
+	QMenu  *m_buildMenuTopLevel, *m_buildMenuCompile, *m_buildMenuConvert, *m_buildMenuViewer, *m_buildMenuOther, *m_buildMenuQuickPreview;
 
-	//parts
-	KParts::PartManager 		*m_partManager;
-	QString 			m_wantState, m_currentState;
 	QSignalMapper			*m_signalMapper;
 
 	/* config */
 	KSharedConfigPtr	m_config;
-	int 			m_horSplitRight, m_horSplitLeft, m_verSplitTop, m_verSplitBottom;
 	QStringList 		m_recentFilesList, m_listDocsOpenOnStart, m_listEncodingsOfDocsOpenOnStart, m_listProjectsOpenOnStart;
 
 	KRecentFilesAction *m_actRecentProjects;
 
-	QTimer *m_AutosaveTimer;
-
 	KileLyxServer		*m_lyxserver;
-	KileErrorHandler 	*m_errorHandler;
-
-	QProgressBar		*m_parserProgressBar;
-	QTimer			*m_parserProgressBarShowTimer;
 
 	/* actions */
 	void initSelectActions();
-	void setupStatusBar();
 	void setupSideBar();
 	void setupProjectView();
 	void setupStructureView();
@@ -210,40 +198,34 @@ private:
 	void restoreLastSelectedAction();
 	void saveLastSelectedAction();
 
-	void createUserTagActions();
-	void updateUserTagMenu();
-	void readUserTagActions();
-	void writeUserTagActions();
+	void transformOldUserTags();
 
 	void initMenu();
 	void setMenuItems(QStringList &list, QMap<QString,bool> &dict);
 	void updateMenu();
 	bool updateMenuActivationStatus(QMenu *menu);
+	bool updateMenuActivationStatus(QMenu *menu, const QSet<QMenu*>& visited);
+	void updateLatexenuActivationStatus(QMenu *menu, bool state);
+	void updateUserMenuStatus(bool state);
 
-	void setViewerToolBars();
+	QAction * createAction(const QString &text, const QString &name, const QObject *receiver = Q_NULLPTR, const char *member = Q_NULLPTR);
+	QAction * createAction(const QString &text, const QString &name, const QString& iconName, const QObject *receiver = Q_NULLPTR, const char *member = Q_NULLPTR);
+	QAction * createAction(const QString &text, const QString &name, const QKeySequence& shortcut, const QObject *receiver = Q_NULLPTR, const char *member = Q_NULLPTR);
+	QAction * createAction(const QString &text, const QString &name, const QString& iconName, const QKeySequence& shortcut = QKeySequence(), const QObject *receiver = Q_NULLPTR, const char *member = Q_NULLPTR);
+	QAction * createAction(KStandardAction::StandardAction actionType, const QString &name, const QObject *receiver = Q_NULLPTR, const char *member = Q_NULLPTR);
 
-	KAction* createAction(const QString &text, const QString &name, const QObject *receiver = NULL, const char *member = NULL);
-	KAction* createAction(const QString &text, const QString &name, const QString& iconName, const QObject *receiver = NULL, const char *member = NULL);
-	KAction* createAction(const QString &text, const QString &name, const KShortcut& shortcut, const QObject *receiver = NULL, const char *member = NULL);
-	KAction* createAction(const QString &text, const QString &name, const QString& iconName, const KShortcut& shortcut = KShortcut(), const QObject *receiver = NULL, const char *member = NULL);
-	KAction* createAction(KStandardAction::StandardAction actionType, const QString &name, const QObject *receiver = NULL, const char *member = NULL);
-
-	QString getMasterDocument() const;
-	void setMasterDocument(const QString& fileName);
+	void setMasterDocumentFileName(const QString& fileName);
 	void clearMasterDocument();
 
 private Q_SLOTS:
 	void toggleMasterDocumentMode();
 	void toggleWatchFile();
-	void showEditorWidget();
 	void refreshStructure();
 
 	void helpLaTex();
 
 	bool resetPart();
-	void activePartGUI(KParts::Part *);
-	void updateGUI(const QString &wantingState);
-	void enableKileGUI(bool);
+	void enableGUI(bool);
 	void slotToggleFullScreen();
 
 	void restoreFilesAndProjects(bool allowRestore);
@@ -275,24 +257,17 @@ private Q_SLOTS:
 
 	void sideOrBottomBarChanged(bool visible);
 
-	void showDocInfo(KTextEditor::View *view = NULL);
-	void convertToASCII(KTextEditor::Document *doc = 0);
-	void convertToEnc(KTextEditor::Document *doc = 0);
+	void showDocInfo(KTextEditor::View *view = Q_NULLPTR);
+	void convertToASCII(KTextEditor::Document *doc = Q_NULLPTR);
+	void convertToEnc(KTextEditor::Document *doc = Q_NULLPTR);
 
-	void cleanAll(KileDocument::TextInfo *docinfo = 0);
+	void cleanAll(KileDocument::TextInfo *docinfo = Q_NULLPTR);
 	void cleanBib();
 
 	void findInFiles();
 	void findInProjects();
 	void grepItemSelected(const QString &abs_filename, int line);
 
-	/* insert tags */
-	/**
-	 * @param td Inserts the TagData td into the current editor.
-	 *
-	 * It can wrap a tag around selected text.
-	 **/
-	void insertTag(const KileAction::TagData& td);
 	/**
 	* @param td Inserts the TagData td into the current editor
 	* @param pkgs list of packages needed for this command
@@ -318,16 +293,14 @@ private Q_SLOTS:
 	void quickFloat();
 	void quickMathenv();
 	void quickPostscript();
+	void quickPdf();
 	void quickTabulardialog(bool tabularenv);
 
-	void editUserMenu();
+	void quickUserMenuDialog();
+	void slotUpdateUserMenuStatus();
 
 	void includeGraphics();
 
-	/* autosave */
-	void autoSaveAll();
-	void enableAutosave(bool);
-
 	// QuickPreview
 	void slotQuickPreview(int type);
 
@@ -336,19 +309,18 @@ private Q_SLOTS:
 	void quickPreviewSubdocument() { slotQuickPreview(KileTool::qpSubdocument); }
 	void quickPreviewMathgroup()   { slotQuickPreview(KileTool::qpMathgroup);   }
 
-	void addRecentFile(const KUrl& url);
-	void removeRecentFile(const KUrl& url);
-	void addRecentProject(const KUrl& url);
-	void removeRecentProject(const KUrl& url);
+	void addRecentFile(const QUrl &url);
+	void removeRecentFile(const QUrl &url);
+	void addRecentProject(const QUrl &url);
+	void removeRecentProject(const QUrl &url);
 
 	void updateStatusBarCursorPosition(KTextEditor::View *view, const KTextEditor::Cursor &newPosition);
 	void updateStatusBarViewMode(KTextEditor::View *view);
 	void updateStatusBarInformationMessage(KTextEditor::View *view, const QString &message);
 	void updateStatusBarSelection(KTextEditor::View *view);
 
-	void connectDocumentInfoWithParserProgressBar(KileDocument::Info *info);
-	void parsingStarted(int maxValue);
-	void parsingCompleted();
+	void handleDocumentParsingStarted();
+	void handleDocumentParsingComplete();
 };
 
 #endif
