@@ -1,6 +1,6 @@
 /**************************************************************************
 *   Copyright (C) 2004 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)   *
-*             (C) 2006-2012 by Michel Ludwig (michel.ludwig@kdemail.net)  *
+*             (C) 2006-2013 by Michel Ludwig (michel.ludwig@kdemail.net)  *
 ***************************************************************************/
 
 /***************************************************************************
@@ -27,26 +27,36 @@
 #include "kileproject.h"
 #include "widgets/progressdialog.h"
 
-class KUrl;
+class QUrl;
 class KFileItem;
-class KProgressDialog;
+class QProgressDialog;
 namespace KTextEditor {class Document; class View;}
 
 class TemplateItem;
 class KileInfo;
 class KileProjectItem;
 
+namespace KileParser { class ParserOutput; }
+
 namespace KileDocument
 {
 
 class Info;
 class TextInfo;
 
+/**
+ * The design of the document manager is based on the following invariants:
+ * - Several projects can be open simultaneously
+ * - For every URL there can only be at most one associated KileDocument::Info* object, but
+ *   there can be several KileProject* items (each one belonging to a different project)
+ * - It is guaranteed that every project item that represents textual data contains a TextInfo* object
+ **/
+
 class Manager : public QObject
 {
 	Q_OBJECT
 public:
-	explicit Manager(KileInfo *info, QObject *parent = NULL, const char *name = NULL);
+	explicit Manager(KileInfo *info, QObject *parent = Q_NULLPTR, const char *name = Q_NULLPTR);
 	~Manager();
 
 	void readConfig();
@@ -62,28 +72,32 @@ public Q_SLOTS:
 	/**
 	 * Creates a new file on disk.
 	 **/
-	void fileNew(const KUrl&);
+	void fileNew(const QUrl&);
 	void fileNewScript();
 	void fileNew(KileDocument::Type type = LaTeX);
 
-	void fileSelected(const KUrl&);
+	void fileSelected(const QUrl&);
 	void fileSelected(const KileProjectItem *item);
 	void fileSelected(const KFileItem& file);
 
 	void fileOpen();
-	void fileOpen(const KUrl& url, const QString& encoding = QString(), int index = -1);
+	inline TextInfo* fileOpen(const QString& localFile, const QString& encoding = QString(), int index = -1)
+	{
+		return fileOpen(QUrl::fromLocalFile(localFile), encoding, index);
+	}
+	TextInfo* fileOpen(const QUrl &url, const QString& encoding = QString(), int index = -1);
 
-	bool fileSave(KTextEditor::View* = NULL);
-	bool fileSaveAs(KTextEditor::View* = NULL);
+	bool fileSave(KTextEditor::View* = Q_NULLPTR);
+	bool fileSaveAs(KTextEditor::View* = Q_NULLPTR);
 	void fileSaveCopyAs();
 
-	void saveURL(const KUrl&);
-	bool fileSaveAll(bool amAutoSaving = false, bool disUntitled = false);
+	void saveURL(const QUrl&);
+	bool fileSaveAll(bool disUntitled = false);
 
-	bool fileCloseAllOthers(KTextEditor::View *view = NULL);
+	bool fileCloseAllOthers(KTextEditor::View *view = Q_NULLPTR);
 	bool fileCloseAll();
-	bool fileClose(const KUrl& url);
-	bool fileClose(KTextEditor::View *view = NULL);
+	bool fileClose(const QUrl &url);
+	bool fileClose(KTextEditor::View *view = Q_NULLPTR);
 	bool fileClose(KTextEditor::Document *doc, bool closingproject = false);
 
 //templates
@@ -94,30 +108,25 @@ public Q_SLOTS:
 
 //projects
 	void projectNew();
-	KileProject* projectOpen();
+	void projectOpen();
 
 	/**
 	 * @param openProjectItemViews Opens project files in the editor iff openProjectItemViews is set to 'true'.
 	 **/
-	KileProject* projectOpen(const KUrl&, int = 0, int = 1, bool openProjectItemViews = true);
-
-	/**
-	 * @param openProjectItemViews Opens project files in the editor iff openProjectItemViews is set to 'true'.
-	 **/
-	void projectOpenItem(KileProjectItem *item, bool openProjectItemViews = true);
+	void projectOpen(const QUrl&, int step = 0, int max = 1, bool openProjectItemViews = true);
 
 	/**
 	 * Saves the state of the project, if @param project is zero, the active project is saved.
 	 **/
-	void projectSave(KileProject* project = NULL);
-	void projectAddFiles(const KUrl&);
-	void projectAddFiles(KileProject* project = NULL,const KUrl & url = KUrl());
+	void projectSave(KileProject* project = Q_NULLPTR);
+	void projectAddFiles(const QUrl&);
+	void projectAddFiles(KileProject* project = Q_NULLPTR,const QUrl &url = QUrl());
 	void toggleArchive(KileProjectItem *);
-	void buildProjectTree(KileProject *project = NULL);
-	void buildProjectTree(const KUrl&);
-	void projectOptions(const KUrl&);
-	void projectOptions(KileProject *project = NULL);
-	bool projectClose(const KUrl& url = KUrl());
+	void buildProjectTree(KileProject *project = Q_NULLPTR);
+	void buildProjectTree(const QUrl&);
+	void projectOptions(const QUrl&);
+	void projectOptions(KileProject *project = Q_NULLPTR);
+	bool projectClose(const QUrl &url = QUrl());
 	bool projectCloseAll();
 
 	void projectShow();
@@ -125,22 +134,24 @@ public Q_SLOTS:
 	void projectShowFiles();
 	void projectAddFile(QString filename, bool graphics=false);
 	void projectOpenAllFiles();
-	void projectOpenAllFiles(const KUrl&);
+	void projectOpenAllFiles(const QUrl&);
 
 	KileProject* selectProject(const QString&);
 
 	void addProject(KileProject *project);
-	void addToProject(const KUrl&);
-	void addToProject(KileProject*, const KUrl&);
+	void addToProject(const QUrl&);
+	void addToProject(KileProject*, const QUrl&);
 	void removeFromProject(KileProjectItem *item);
 	void storeProjectItem(KileProjectItem *item, KTextEditor::Document *doc);
 
-	void cleanUpTempFiles(const KUrl &url, bool silent = false);
+	void cleanUpTempFiles(const QUrl &url, bool silent = false);
 
 	void openDroppedURLs(QDropEvent *e);
 
 	void reloadXMLOnAllDocumentsAndViews();
 
+	void handleParsingComplete(const QUrl &url, KileParser::ParserOutput* output);
+
 Q_SIGNALS:
 	void projectTreeChanged(const KileProject*);
 	void closingDocument(KileDocument::Info*);
@@ -153,46 +164,52 @@ Q_SIGNALS:
 	void documentModificationStatusChanged(KTextEditor::Document*, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason);
 	void documentUrlChanged(KTextEditor::Document*);
 	void documentNameChanged(KTextEditor::Document*);
+	void documentReadWriteStateChanged(KTextEditor::Document*);
 
-	void addToRecentFiles(const KUrl&);
-	void addToRecentProjects(const KUrl&);
-	void removeFromRecentProjects(const KUrl&);
+	void addToRecentFiles(const QUrl&);
+	void addToRecentProjects(const QUrl&);
+	void removeFromRecentProjects(const QUrl&);
 
 	void startWizard();
 
-	void removeFromProjectView(const KUrl&);
+	void removeFromProjectView(const QUrl&);
 	void removeFromProjectView(const KileProject*);
 	void removeItemFromProjectView(const KileProjectItem*, bool);
-	void addToProjectView(const KUrl&);
+	void addToProjectView(const QUrl&);
 	void addToProjectView(KileProjectItem *item);
 	void addToProjectView(const KileProject*);
 
+	void documentSavedAs(KTextEditor::View*, KileDocument::TextInfo*);
+
+	void projectOpened(KileProject *project);
+	void documentOpened(KileDocument::TextInfo *textInfo);
+
 public:
-	/**
-	 * Autosave is not allowed whenever the documents are opened, closed, etc.
-	 * Note that even though the autosave functionality is not executed in a separate
-	 * thread, it would be possible that autosave is executed during the manipulation
-	 * of documents as a separate event handling loop can be started (for example, for
-	 * a progress dialog).
-	 **/
-	bool isAutoSaveAllowed();
+	bool isOpeningFile();
 
 	KTextEditor::Editor* getEditor();
 
 	QList<KileProject*> projects() { return m_projects; }
 	QList<TextInfo*> textDocumentInfos() { return m_textInfoList; }
 
-	KTextEditor::Document* docFor(const KUrl &url);
+	KTextEditor::Document* docFor(const QUrl &url);
 
-	Info* getInfo() const;
-	// FIXME: "path" should be changed to a URL, i.e. only the next but one function
-	//        should be used
-	TextInfo* textInfoFor(const QString &path) const;
-	TextInfo* textInfoForURL(const KUrl& url);
+	TextInfo* getInfo() const;
+
+	inline TextInfo* textInfoFor(const QString& localFile)
+	{
+		return textInfoFor(QUrl::fromLocalFile(localFile));
+	}
+
+	TextInfo* textInfoFor(const QUrl &url);
 	TextInfo* textInfoFor(KTextEditor::Document* doc) const;
+
+	QUrl urlFor(TextInfo* textInfo);
+
 	void updateInfos();
 
-	KileProject* projectFor(const KUrl &projecturl);
+	KileProject* projectForMember(const QUrl &memberUrl);
+	KileProject* projectFor(const QUrl &projecturl);
 	KileProject* projectFor(const QString & name);
 	KileProject* activeProject();
 	bool isProjectOpen();
@@ -204,44 +221,53 @@ public:
 	 * Finds the project item for the file with URL @param url.
 	 * @returns a pointer to the project item, 0 if this file does not belong to a project
 	 **/
-	KileProjectItem* itemFor(const KUrl &url, KileProject *project = NULL) const;
-	KileProjectItem* itemFor(Info *docinfo, KileProject *project = NULL) const;
+	KileProjectItem* itemFor(const QUrl &url, KileProject *project = Q_NULLPTR) const;
+	KileProjectItem* itemFor(TextInfo *docinfo, KileProject *project = Q_NULLPTR) const;
 	KileProjectItem* selectProjectFileItem(const QString &label);
 	QList<KileProjectItem*> selectProjectFileItems(const QString &label);
 
+	/**
+	 * The next method returns a list as several projects can be open simultaneously, i.e.
+	 * one URL can be associated with several project item belonging to different projects.
+	 **/
 	QList<KileProjectItem*> itemsFor(Info *docinfo) const;
-	QList<KileProjectItem*> itemsFor(const KUrl& url) const;
+	QList<KileProjectItem*> itemsFor(const QUrl &url) const;
 
-	static const KUrl symlinkFreeURL(const KUrl& url);
+	static const QUrl symlinkFreeURL(const QUrl &url);
 
 protected:
-	void mapItem(TextInfo *docinfo, KileProjectItem *item);
+	/**
+	 * @param openProjectItemViews Opens project files in the editor iff openProjectItemViews is set to 'true'.
+	 **/
+	void projectOpenItem(KileProjectItem *item, bool openProjectItemViews = true);
+	void createTextInfoForProjectItem(KileProjectItem *item);
 
-	void trashDoc(TextInfo *docinfo, KTextEditor::Document *doc = NULL);
+	void trashDoc(TextInfo *docinfo, KTextEditor::Document *doc = Q_NULLPTR);
 
-	TextInfo* createTextDocumentInfo(KileDocument::Type type, const KUrl &url, const KUrl& baseDirectory = KUrl());
+	TextInfo* createTextDocumentInfo(KileDocument::Type type, const QUrl &url, const QUrl& baseDirectory = QUrl());
 	void recreateTextDocumentInfo(TextInfo *oldinfo);
 
 	/**
 	 * Tries to remove and delete a TextInfo object. The TextInfo object will only be deleted if it isn't referenced
-	 * by any project item or if is is only referenced by a project that should be closed.
+	 * by any project item or if it is only referenced by a project that should be closed.
 	 * @param closingproject Indicates whether the TextInfo object should be removed as part of a project close
 	 *                       operation.
 	 * @warning This method does not close or delete any Kate documents that are associated with the TextInfo object !
 	 **/
 	bool removeTextDocumentInfo(TextInfo *docinfo, bool closingproject = false);
-	KTextEditor::Document* createDocument(const KUrl& url, TextInfo *docinfo, const QString& encoding, const QString& mode, const QString& highlight);
+	KTextEditor::Document* createDocument(const QUrl &url, TextInfo *docinfo, const QString& encoding, const QString& mode, const QString& highlight);
 
 	/**
 	 *  Creates a document with the specified text.
 	 *
 	 *  @param extension The extension of the file that should be created without leading "."
 	 **/
-	KTextEditor::View* createDocumentWithText(const QString& text, KileDocument::Type type = KileDocument::Text, const QString& extension = QString(), const KUrl& baseDirectory = KUrl());
+	KTextEditor::View* createDocumentWithText(const QString& text, KileDocument::Type type = KileDocument::Text, const QString& extension = QString(), const QUrl &baseDirectory = QUrl());
 
-	KTextEditor::View* loadText(KileDocument::Type type, const KUrl& url, const QString& encoding = QString(), bool create = true, const QString& mode = QString(), const QString& highlight = QString(), const QString &text = QString(), int index = -1, const KUrl& baseDirectory = KUrl());
+	KTextEditor::View* loadText(KileDocument::Type type, const QUrl &url, const QString& encoding = QString(), bool create = true, const QString& mode = QString(), const QString& highlight = QString(), const QString &text = QString(), int index = -1, const QUrl& baseDirectory = QUrl());
 	KTextEditor::View* loadItem(KileDocument::Type type, KileProjectItem *item, const QString& text = QString(), bool openProjectItemViews = true);
 
+	QStringList loadTextURLContents(const QUrl &url, const QString& encoding);
 private:
 	KTextEditor::Editor			*m_editor;
 	QList<TextInfo*>			m_textInfoList;
@@ -249,21 +275,22 @@ private:
 	QList<KileProject*>			m_projects;
 	QPointer<KileWidget::ProgressDialog>	m_progressDialog;
 	unsigned int				m_autoSaveLock;
-	bool					m_currentlySavingAll;
+	bool					m_currentlySavingAll, m_currentlyOpeningFile;
 
 	void dontOpenWarning(KileProjectItem *item, const QString &action, const QString &filetype);
 	void cleanupDocumentInfoForProjectItems(KileDocument::Info *info);
+
 	void createProgressDialog();
 
 	QStringList autosaveWarnings;
 
-	void loadDocumentAndViewSettings(KTextEditor::Document *doc);
-	void saveDocumentAndViewSettings(KTextEditor::Document *doc);
+	void loadDocumentAndViewSettings(KileDocument::TextInfo *textInfo);
+	void saveDocumentAndViewSettings(KileDocument::TextInfo *textInfo);
 	KConfigGroup configGroupForDocumentSettings(KTextEditor::Document *doc) const;
-	QString configGroupNameForDocumentSettings(const KUrl& url) const;
+	QString configGroupNameForDocumentSettings(const QUrl &url) const;
 	KConfigGroup configGroupForViewSettings(KTextEditor::Document *doc, int viewIndex) const;
-	QString configGroupNameForViewSettings(const KUrl& url, int viewIndex) const;
-	void deleteDocumentAndViewSettingsGroups(const KUrl& url);
+	QString configGroupNameForViewSettings(const QUrl &url, int viewIndex) const;
+	void deleteDocumentAndViewSettingsGroups(const QUrl &url);
 };
 
 }
