@@ -1,7 +1,7 @@
 /*************************************************************************************
     begin                : Thu Jul 17 2003
     copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                               2007-2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2011 by Michel Ludwig (michel.ludwig@kdemail.net)
  *************************************************************************************/
 
 /***************************************************************************
@@ -24,9 +24,10 @@
 
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
+#include "parser/parsermanager.h"
 #include "widgets/structurewidget.h"
 #include "configurationmanager.h"
 #include "editorcommands.h"
@@ -38,8 +39,9 @@
 #include "abbreviationmanager.h"
 #include "editorkeysequencemanager.h"
 #include "templates.h"
+#include "utilities.h"
+#include "usermenu/usermenu.h"
 
-#include <kstandarddirs.h>
 #include <QStringList>
 #include <QString>
 
@@ -47,25 +49,23 @@
  * Class KileInfo.
  */
 
-KileInfo::KileInfo(KParts::MainWindow *parent) :
-	m_mainWindow(parent),
-	m_manager(NULL),
-	m_jScriptManager(NULL),
-	m_toolFactory(NULL),
-	m_texKonsole(NULL),
-	m_edit(NULL)
+KileInfo::KileInfo(KParts::MainWindow *parent)
+	: m_mainWindow(parent)
+	, m_viewManager(Q_NULLPTR)
+	, m_manager(Q_NULLPTR)
+	, m_jScriptManager(Q_NULLPTR)
+	, m_toolFactory(Q_NULLPTR)
+	, m_texKonsole(Q_NULLPTR)
+	, m_errorHandler(Q_NULLPTR)
+	, m_edit(Q_NULLPTR)
+	, m_userMenu(Q_NULLPTR)
 {
 	m_configurationManager = new KileConfiguration::Manager(this, parent, "KileConfiguration::Manager");
 	m_docManager = new KileDocument::Manager(this, parent, "KileDocument::Manager");
-	m_viewManager= new KileView::Manager(this, parent, "KileView::Manager");
 	m_templateManager = new KileTemplate::Manager(this, parent, "KileTemplate::Manager");
 	m_editorKeySequenceManager = new KileEditorKeySequence::Manager(this, parent, "KileEditorKeySequence::Manager");
-	QObject::connect(m_docManager,
-	                 SIGNAL(documentModificationStatusChanged(KTextEditor::Document*, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)),
-	                 m_viewManager,
-	                 SLOT(reflectDocumentModificationStatus(KTextEditor::Document*, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason)));
 	m_abbreviationManager = new KileAbbreviation::Manager(this, parent);
-
+	m_parserManager = new KileParser::Manager(this, parent);
 	m_editorCommands = new EditorCommands(this);
 }
 
@@ -78,72 +78,101 @@ KileInfo::~KileInfo()
 KTextEditor::Document * KileInfo::activeTextDocument() const
 {
 	KTextEditor::View *view = viewManager()->currentTextView();
-	if (view) return view->document(); else return NULL;
+	if (view) return view->document(); else return Q_NULLPTR;
 }
 
-QString KileInfo::getName(KTextEditor::Document *doc, bool shrt)
+QString KileInfo::getName(KTextEditor::Document *doc, bool shrt) const
 {
-	KILE_DEBUG() << "===KileInfo::getName(KTextEditor::Document *doc, bool " << shrt << ")===" << endl;
+	KILE_DEBUG_MAIN << "===KileInfo::getName(KTextEditor::Document *doc, bool " << shrt << ")===" << endl;
 	QString title;
 
 	if (!doc) {
 		doc = activeTextDocument();
 	}
 	if (doc) {
-		KILE_DEBUG() << "url " << doc->url().toLocalFile() << endl;
-		title = shrt ? doc->url().fileName() : doc->url().toLocalFile();
+		QUrl url = doc->url();
+		KILE_DEBUG_MAIN << "url " << url << endl;
+		if(url.isLocalFile()) {
+			title = shrt ? doc->url().fileName() : doc->url().toLocalFile();
+		}
+		else {
+			title = url.toDisplayString();
+		}
 	}
 
 	return title;
 }
 
-QString KileInfo::getCompileName(bool shrt /* = false */)
+LaTeXOutputHandler* KileInfo::findCurrentLaTeXOutputHandler() const
+{
+	LaTeXOutputHandler *h = Q_NULLPTR;
+
+	getCompileName(false, &h);
+	return h;
+}
+
+QString KileInfo::getCompileName(bool shrt /* = false */, LaTeXOutputHandler** h /* = Q_NULLPTR */) const
 {
 	KileProject *project = docManager()->activeProject();
 
 	if (m_singlemode) {
 		if (project) {
-			if (!project->masterDocument().isEmpty()) {
-				KUrl master(project->masterDocument());
-				if(shrt) {
-					return master.fileName();
-				}
-				else {
-					return master.toLocalFile();
-				}
-			}
-			else {
-				KileProjectItem *item = project->rootItem(docManager()->activeProjectItem());
-				if (item) {
-					KUrl url = item->url();
-					if(shrt) {
-						return url.fileName();
-					}
-					else {
-						return url.toLocalFile();
-					}
-				}
-				else {
-					return QString();
-				}
+			if(h) {
+				*h = project;
 			}
+			return getCompileNameForProject(project, shrt);
 		}
 		else {
-			return getName(activeTextDocument(), shrt);
+			KTextEditor::Document *doc = activeTextDocument();
+			if(h) {
+				*h = dynamic_cast<KileDocument::LaTeXInfo*>(m_docManager->textInfoFor(doc));
+			}
+			return getName(doc, shrt);
 		}
 	}
 	else {
-		QFileInfo fi(m_masterName);
+		QFileInfo fi(m_masterDocumentFileName);
+		if(h) {
+			*h = dynamic_cast<KileDocument::LaTeXInfo*>(m_docManager->textInfoFor(m_masterDocumentFileName));
+		}
 		if(shrt) {
 			return fi.fileName();
 		}
 		else {
-			return m_masterName;
+			return m_masterDocumentFileName;
 		}
 	}
 }
 
-QString KileInfo::getFullFromPrettyName(const QString& name)
+QString KileInfo::getCompileNameForProject(KileProject *project, bool shrt) const
+{
+	if (!project->masterDocument().isEmpty()) {
+		QUrl master(project->masterDocument());
+		if(shrt) {
+			return master.fileName();
+		}
+		else {
+			return master.toLocalFile();
+		}
+	}
+	else {
+		KileProjectItem *item = project->rootItem(docManager()->activeProjectItem());
+		if (item) {
+			QUrl url = item->url();
+			if(shrt) {
+				return url.fileName();
+			}
+			else {
+				return url.toLocalFile();
+			}
+		}
+		else {
+			return QString();
+		}
+	}
+}
+
+QString KileInfo::getFullFromPrettyName(const OutputInfo& info, const QString& name) const
 {
 	if(name.isEmpty()) {
 		return name;
@@ -152,11 +181,11 @@ QString KileInfo::getFullFromPrettyName(const QString& name)
 	QString file = name;
 
 	if(file.left(2) == "./") {
-		file = QFileInfo(outputFilter()->source()).absolutePath() + '/' + file.mid(2);
+		file = QFileInfo(info.mainSourceFile()).absolutePath() + '/' + file.mid(2);
 	}
 
 	if(QDir::isRelativePath(file)) {
-		file = QFileInfo(outputFilter()->source()).absolutePath() + '/' + file;
+		file = QFileInfo(info.mainSourceFile()).absolutePath() + '/' + file;
 	}
 
 	QFileInfo fi(file);
@@ -186,10 +215,10 @@ QString KileInfo::getFullFromPrettyName(const QString& name)
 	return file;
 }
 
-KUrl::List KileInfo::getParentsFor(KileDocument::Info *info)
+QList<QUrl> KileInfo::getParentsFor(KileDocument::Info *info)
 {
 	QList<KileProjectItem*> items = docManager()->itemsFor(info);
-	KUrl::List list;
+	QList<QUrl> list;
 	for(QList<KileProjectItem*>::iterator it = items.begin(); it != items.end(); ++it) {
 		if((*it)->parent()) {
 			list.append((*it)->parent()->url());
@@ -198,19 +227,19 @@ KUrl::List KileInfo::getParentsFor(KileDocument::Info *info)
 	return list;
 }
 
-QStringList KileInfo::retrieveList(QStringList (KileDocument::Info::*getit)() const, KileDocument::Info *docinfo)
+QStringList KileInfo::retrieveList(QStringList (KileDocument::Info::*getit)() const, KileDocument::TextInfo *docinfo)
 {
 	if(!docinfo) {
 		docinfo = docManager()->getInfo();
 	}
 	KileProjectItem *item = docManager()->itemFor(docinfo, docManager()->activeProject());
 
-	KILE_DEBUG() << "Kile::retrieveList()";
+	KILE_DEBUG_MAIN << "Kile::retrieveList()";
 	if (item) {
 		KileProject *project = item->project();
 		KileProjectItem *root = project->rootItem(item);
 		if (root) {
-			KILE_DEBUG() << "\tusing root item " << root->url().fileName();
+			KILE_DEBUG_MAIN << "\tusing root item " << root->url().fileName();
 
 			QList<KileProjectItem*> children;
 			children.append(root);
@@ -218,9 +247,13 @@ QStringList KileInfo::retrieveList(QStringList (KileDocument::Info::*getit)() co
 
 			QStringList toReturn;
 			for(QList<KileProjectItem*>::iterator it = children.begin(); it != children.end(); ++it) {
-				KILE_DEBUG() << "\t" << (*it)->url().fileName();
+				const KileProjectItem *item = *it;
+				KileDocument::TextInfo *textInfo = item->getInfo();
+				KILE_DEBUG_MAIN << "\t" << item->url();
 
-				toReturn << ((*it)->getInfo()->*getit)();
+				if(textInfo) {
+					toReturn << (textInfo->*getit)();
+				}
 			}
 			return toReturn;
 		}
@@ -236,55 +269,58 @@ QStringList KileInfo::retrieveList(QStringList (KileDocument::Info::*getit)() co
 	}
 }
 
-QStringList KileInfo::allLabels(KileDocument::Info *info)
+QStringList KileInfo::allLabels(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::allLabels()" << endl;
+	KILE_DEBUG_MAIN << "Kile::allLabels()" << endl;
 	return retrieveList(&KileDocument::Info::labels, info);
 }
 
-QStringList KileInfo::allBibItems(KileDocument::Info *info)
+QStringList KileInfo::allBibItems(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::allBibItems()" << endl;
+	KILE_DEBUG_MAIN << "Kile::allBibItems()" << endl;
 	return retrieveList(&KileDocument::Info::bibItems, info);
 }
 
-QStringList KileInfo::allBibliographies(KileDocument::Info *info)
+QStringList KileInfo::allBibliographies(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::bibliographies()" << endl;
+	KILE_DEBUG_MAIN << "Kile::bibliographies()" << endl;
 	return retrieveList(&KileDocument::Info::bibliographies, info);
 }
 
-QStringList KileInfo::allDependencies(KileDocument::Info *info)
+QStringList KileInfo::allDependencies(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::dependencies()" << endl;
+	KILE_DEBUG_MAIN << "Kile::dependencies()" << endl;
 	return retrieveList(&KileDocument::Info::dependencies, info);
 }
 
-QStringList KileInfo::allNewCommands(KileDocument::Info *info)
+QStringList KileInfo::allNewCommands(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::newCommands()" << endl;
+	KILE_DEBUG_MAIN << "Kile::newCommands()" << endl;
 	return retrieveList(&KileDocument::Info::newCommands, info);
 }
 
-QStringList KileInfo::allAsyFigures(KileDocument::Info *info)
+QStringList KileInfo::allAsyFigures(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::asyFigures()" << endl;
+	KILE_DEBUG_MAIN << "Kile::asyFigures()" << endl;
 	return retrieveList(&KileDocument::Info::asyFigures, info);
 }
 
-QStringList KileInfo::allPackages(KileDocument::Info *info)
+QStringList KileInfo::allPackages(KileDocument::TextInfo *info)
 {
-	KILE_DEBUG() << "Kile::allPackages()" << endl;
+	KILE_DEBUG_MAIN << "Kile::allPackages()" << endl;
 	return retrieveList(&KileDocument::Info::packages, info);
 }
 
-QString KileInfo::lastModifiedFile(KileDocument::Info *info)
+QString KileInfo::lastModifiedFile(KileDocument::TextInfo* info)
 {
 	if(!info) {
 		info = docManager()->getInfo();
 	}
 	QStringList list = allDependencies(info);
-	return info->lastModifiedFile(list);
+	QFileInfo fileinfo(info->url().toLocalFile());
+	list.append(fileinfo.fileName());
+
+	return KileUtilities::lastModifiedFile(list, fileinfo.absolutePath());
 }
 
 QString KileInfo::documentTypeToString(KileDocument::Type type)
@@ -304,7 +340,7 @@ QString KileInfo::documentTypeToString(KileDocument::Type type)
 	return QString();
 }
 
-bool KileInfo::similarOrEqualURL(const KUrl &validurl, const KUrl &testurl)
+bool KileInfo::similarOrEqualURL(const QUrl &validurl, const QUrl &testurl)
 {
 	if ( testurl.isEmpty() || testurl.path().isEmpty() ) return false;
 
@@ -316,9 +352,9 @@ bool KileInfo::similarOrEqualURL(const KUrl &validurl, const KUrl &testurl)
 		   );
 }
 
-bool KileInfo::isOpen(const KUrl & url)
+bool KileInfo::isOpen(const QUrl &url)
 {
-	KILE_DEBUG() << "==bool KileInfo::isOpen(const KUrl & url)=============" << endl;
+	KILE_DEBUG_MAIN << "==bool KileInfo::isOpen(const QUrl &url)=============" << endl;
 
 	for (int i = 0; i < viewManager()->textViewCount(); ++i) {
 		KTextEditor::View *view = viewManager()->textView(i);
@@ -330,7 +366,7 @@ bool KileInfo::isOpen(const KUrl & url)
 	return false;
 }
 
-bool KileInfo::projectIsOpen(const KUrl & url)
+bool KileInfo::projectIsOpen(const QUrl &url)
 {
 	KileProject *project = docManager()->projectFor(url);
 
@@ -371,7 +407,7 @@ QString KileInfo::expandEnvironmentVars(const QString &str)
 
 QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int type)
 {
-	KILE_DEBUG() << "QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int type)" << endl;
+	KILE_DEBUG_MAIN << "QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int type)" << endl;
 	QStringList inputpaths;
 	QString configpaths;
 	QFileInfo info;
@@ -379,29 +415,29 @@ QString KileInfo::checkOtherPaths(const QString &path,const QString &file, int t
 	switch(type)
 	{
 		case bibinputs:
-			configpaths = KileConfig::bibInputPaths() + ":$BIBINPUTS";
+			configpaths = KileConfig::bibInputPaths() + PATH_SEPARATOR + "$BIBINPUTS";
 			break;
 		case texinputs:
-			configpaths = KileConfig::teXPaths() + ":$TEXINPUTS";
+			configpaths = KileConfig::teXPaths() + PATH_SEPARATOR + "$TEXINPUTS";
 			break;
 		case bstinputs:
-			configpaths = KileConfig::bstInputPaths() + ":$BSTINPUTS";
+			configpaths = KileConfig::bstInputPaths() + PATH_SEPARATOR + "$BSTINPUTS";
 			break;
 		default:
-			KILE_DEBUG() << "Unknown type in checkOtherPaths" << endl;
+			KILE_DEBUG_MAIN << "Unknown type in checkOtherPaths" << endl;
 			return QString();
 			break;
 	}
 
-	inputpaths = expandEnvironmentVars(configpaths).split(':');
+	inputpaths = expandEnvironmentVars(configpaths).split(PATH_SEPARATOR);
 	inputpaths.prepend(path);
 
 		// the first match is supposed to be the correct one
 	foreach(const QString &string, inputpaths){
-		KILE_DEBUG() << "path is " << string << "and file is " << file << endl;
+		KILE_DEBUG_MAIN << "path is " << string << "and file is " << file << endl;
 		info.setFile(string + '/' + file);
 		if(info.exists()) {
-			KILE_DEBUG() << "filepath after correction is: " << info.path() << endl;
+			KILE_DEBUG_MAIN << "filepath after correction is: " << info.path() << endl;
 			return info.absoluteFilePath();
 		}
 	}
