@@ -1,7 +1,7 @@
 /**************************************************************************************
     begin                : Thu Jul 17 2003
     copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                               2007 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2011 by Michel Ludwig (michel.ludwig@kdemail.net)
  **************************************************************************************/
 
 /***************************************************************************
@@ -20,7 +20,7 @@
 #include <QMap>
 
 #include "kiledebug.h"
-#include <kurl.h>
+#include <QUrl>
 
 #include <KParts/MainWindow>
 
@@ -28,14 +28,15 @@
 #include "kileextensions.h"
 #include "kiletoolmanager.h"
 #include "kilestdtools.h"
-#include "latexoutputfilter.h"
 #include "outputinfo.h"
 #include "latexcmd.h"
 #include "kileconfig.h"
 
 class QWidget;
 
-namespace KileDocument { class Info; }
+namespace KileDocument { class Info; class TextInfo; }
+
+class KileErrorHandler;
 class KileProject;
 class KileProjectItem;
 class KileProjectItemList;
@@ -46,29 +47,36 @@ namespace KileConfiguration{ class Manager; }
 namespace KileDocument { class Extensions; class Manager; class EditorExtension; }
 namespace KileView { class Manager; }
 namespace KileWidget { class StructureWidget; class Konsole; class ScriptsManagement; class PreviewWidget; class ExtendedScrollArea; class FileBrowserWidget; class OutputView; class BottomBar; }
-namespace KileTool { class QuickPreview; }
+namespace KileTool { class QuickPreview; class LivePreviewManager; }
 namespace KileHelp { class Help; }
 namespace KileScript { class Manager; }
 namespace KileEditorKeySequence { class Manager; }
 namespace KileTemplate { class Manager; }
 namespace KileCodeCompletion { class Manager; }
 namespace KileAbbreviation { class Manager; }
+namespace KileParser { class Manager; }
+
+namespace KileMenu { class UserMenu; }
 
 class EditorCommands;
 
 class KileInfo
 {
+	friend class KileMainWindow;
+
 public:
 	KileInfo(KParts::MainWindow *mainWindow);
 	virtual ~KileInfo();
 
 public:
 	enum {bibinputs = 0,bstinputs, texinputs};
-	QString getName(KTextEditor::Document *doc = NULL, bool shrt = false);
-	QString getShortName(KTextEditor::Document *doc = NULL) { return getName(doc, true); }
-	QString getCompileName(bool shrt = false);
-	QString getFullFromPrettyName(const QString & name);
-	KUrl::List getParentsFor(KileDocument::Info *);
+	QString getName(KTextEditor::Document *doc = Q_NULLPTR, bool shrt = false) const;
+	QString getShortName(KTextEditor::Document *doc = Q_NULLPTR) const { return getName(doc, true); }
+	LaTeXOutputHandler* findCurrentLaTeXOutputHandler() const;
+	QString getCompileNameForProject(KileProject *project, bool shrt = false) const;
+	QString getCompileName(bool shrt = false, LaTeXOutputHandler** h = Q_NULLPTR) const;
+	QString getFullFromPrettyName(const OutputInfo& info, const QString& name) const;
+	QList<QUrl> getParentsFor(KileDocument::Info *);
 	bool getSinglemode() { return m_singlemode; }
 
 	QString getCurrentTarget() const { return m_currentTarget; }
@@ -79,15 +87,15 @@ public:
 	QString getSelection() const;
 	void clearSelection() const;
 
-	virtual QStringList allLabels(KileDocument::Info *info = NULL);
-	virtual QStringList allBibItems(KileDocument::Info *info = NULL);
-	virtual QStringList allBibliographies(KileDocument::Info *info = NULL);
-	virtual QStringList allDependencies(KileDocument::Info *info = NULL);
-	virtual QStringList allNewCommands(KileDocument::Info *info = NULL);
-	virtual QStringList allAsyFigures(KileDocument::Info *info = NULL);
-	virtual QStringList allPackages(KileDocument::Info *info = NULL);
+	virtual QStringList allLabels(KileDocument::TextInfo *info = Q_NULLPTR);
+	virtual QStringList allBibItems(KileDocument::TextInfo *info = Q_NULLPTR);
+	virtual QStringList allBibliographies(KileDocument::TextInfo *info = Q_NULLPTR);
+	virtual QStringList allDependencies(KileDocument::TextInfo *info = Q_NULLPTR);
+	virtual QStringList allNewCommands(KileDocument::TextInfo *info = Q_NULLPTR);
+	virtual QStringList allAsyFigures(KileDocument::TextInfo *info = Q_NULLPTR);
+	virtual QStringList allPackages(KileDocument::TextInfo *info = Q_NULLPTR);
 
-	QString lastModifiedFile(KileDocument::Info * info = NULL);
+	QString lastModifiedFile(KileDocument::TextInfo *info = Q_NULLPTR);
 
 	static QString documentTypeToString(KileDocument::Type type);
 
@@ -97,24 +105,19 @@ public:
 	virtual void focusEditor() = 0;
 	virtual void focusPreview() = 0;
 
-protected:
-	virtual bool queryExit() = 0;
-	virtual bool queryClose() = 0;
-
 private:
-	QStringList retrieveList(QStringList (KileDocument::Info::*getit)() const, KileDocument::Info *docinfo = NULL);
+	QStringList retrieveList(QStringList (KileDocument::Info::*getit)() const, KileDocument::TextInfo *docinfo = Q_NULLPTR);
 
 public:
-	bool similarOrEqualURL(const KUrl &validurl, const KUrl &testurl);
-	bool isOpen(const KUrl & url);
-	bool projectIsOpen(const KUrl & );
+	bool similarOrEqualURL(const QUrl &validurl, const QUrl &testurl);
+	bool isOpen(const QUrl &url);
+	inline bool isOpen(const QString& localFile)
+	{
+		return isOpen(QUrl::fromLocalFile(localFile));
+	}
+	bool projectIsOpen(const QUrl & );
 
 	bool watchFile() { return m_bWatchFile; }
-	bool logPresent() { return m_logPresent; }
-	void setLogPresent(bool pr) { m_logPresent = pr; }
-
-	LatexOutputFilter * outputFilter() { return m_outputFilter; }
-	LatexOutputInfoArray * outputInfo() { return m_outputInfo; }
 
 	virtual int lineNumber() = 0;
 
@@ -122,7 +125,6 @@ public:
 	KileWidget::Konsole *texKonsole() { return m_texKonsole; }
 	KileWidget::OutputView *outputWidget() { return m_outputWidget; }
 	KileWidget::BottomBar *outputView() { return m_bottomBar; }
-	KileWidget::LogWidget *logWidget() { return m_logWidget; }
 	KileWidget::PreviewWidget *previewWidget () { return m_previewWidget; }
 
 	KileConfiguration::Manager* configurationManager() const { return m_configurationManager; }
@@ -136,10 +138,14 @@ public:
 	KileDocument::LatexCommands *latexCommands() const { return m_latexCommands; }
 	KileHelp::Help *help() const { return m_help; }
 	KileTool::QuickPreview *quickPreview() const { return m_quickPreview; }
+	KileTool::LivePreviewManager *livePreviewManager() const { return m_livePreviewManager; }
 	KileDocument::Extensions *extensions() const { return m_extensions; }
 	KileTemplate::Manager *templateManager() const { return m_templateManager; }
 	KileCodeCompletion::Manager *codeCompletionManager() const { return m_codeCompletionManager; }
 	KileAbbreviation::Manager* abbreviationManager() const { return m_abbreviationManager; }
+	KileParser::Manager* parserManager() const { return m_parserManager; }
+	KileErrorHandler* errorHandler() const { return m_errorHandler; }
+	KileMenu::UserMenu *userMenu() const { return m_userMenu; }
 
 	//FIXME:refactor
 	KileWidget::FileBrowserWidget* fileSelector() const { return m_fileBrowserWidget; }
@@ -148,7 +154,11 @@ public:
 
 	static QString expandEnvironmentVars(const QString &variable);
 	static QString checkOtherPaths(const QString &path,const QString &file, int type);
-	static QString checkOtherPaths(const KUrl &url,const QString &file, int type){ return checkOtherPaths(url.toLocalFile(),file, type); }
+	static QString checkOtherPaths(const QUrl &url,const QString &file, int type){ return checkOtherPaths(url.toLocalFile(),file, type); }
+
+	virtual void setLine(const QString &line) = 0;
+
+	QString getMasterDocumentFileName() const { return m_masterDocumentFileName; }
 
 protected:
 	KileConfiguration::Manager	*m_configurationManager;
@@ -162,13 +172,14 @@ protected:
 	KileTool::Factory		*m_toolFactory;
 	KileWidget::Konsole		*m_texKonsole;
 	KileWidget::OutputView		*m_outputWidget;
-	KileWidget::LogWidget		*m_logWidget;
 	KileWidget::ScriptsManagement	*m_scriptsManagementWidget;
 	KileWidget::BottomBar		*m_bottomBar;
 	KileWidget::PreviewWidget	*m_previewWidget;
 	KileWidget::ExtendedScrollArea	*m_previewScrollArea;
 	KileCodeCompletion::Manager	*m_codeCompletionManager;
 	KileAbbreviation::Manager	*m_abbreviationManager;
+	KileParser::Manager		*m_parserManager;
+	KileErrorHandler 		*m_errorHandler;
 
 	EditorCommands				*m_editorCommands;
 
@@ -177,16 +188,15 @@ protected:
 	KileDocument::LatexCommands *m_latexCommands;
 	KileDocument::Extensions *m_extensions;
 	KileTool::QuickPreview *m_quickPreview;
+	KileMenu::UserMenu *m_userMenu;
+	KileTool::LivePreviewManager *m_livePreviewManager;
 
 	bool 		m_singlemode;
-	QString	m_masterName;
+	QString		m_masterDocumentFileName;
 
 	QString	m_currentTarget;
 
-	bool m_bWatchFile, m_logPresent;
-
-	LatexOutputFilter		*m_outputFilter;
-	LatexOutputInfoArray	*m_outputInfo;
+	bool m_bWatchFile;
 
 	KileWidget::StructureWidget	*m_kwStructure;
 	KileWidget::FileBrowserWidget 			*m_fileBrowserWidget;
