@@ -1,7 +1,6 @@
 /****************************************************************************************
-    begin                : mon 3-11 20:40:00 CEST 2003
-    copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                               2008-2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+    Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
+                  2008-2017 by Michel Ludwig (michel.ludwig@kdemail.net)
  ****************************************************************************************/
 
 /***************************************************************************
@@ -15,12 +14,16 @@
 
 #include "kilelauncher.h"
 
+#include <config.h>
+
+#include "docpart.h"
+#include "kileconfig.h"
 #include "kileinfo.h"
 #include "kiletool.h"
 #include "kiletoolmanager.h"
 #include "kiletool_enums.h"
-#include "docpart.h"
-#include "kileconfig.h"
+#include "kileviewmanager.h"
+#include "livepreview.h"
 
 #include <QStackedWidget>
 #include <QFileInfo>
@@ -28,42 +31,30 @@
 #include "kiledebug.h"
 #include <KRun>
 #include <KProcess>
-#include <KLocale>
+#include <KLocalizedString>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <KShell>
-#include <KStandardDirs>
-#include <KParts/ComponentFactory>
-#include <KParts/Part>
-#include <KParts/Factory>
-#include <KParts/PartManager>
 
-static QVariantList toVariantList(const QStringList& list)
-{
-	QVariantList toReturn;
-	for(QStringList::const_iterator i = list.begin(); i != list.end(); ++i) {
-		toReturn.push_back(QVariant(*i));
-	}
-	return toReturn;
-}
+#include <KParts/Part>
+#include <KParts/PartManager>
 
 namespace KileTool {
 
 	Launcher::Launcher() :
-		m_tool(NULL)
+		m_tool(Q_NULLPTR)
 	{
 	}
-	
+
 	Launcher::~ Launcher()
 	{
-		KILE_DEBUG() << "DELETING launcher";
+		KILE_DEBUG_MAIN << "DELETING launcher";
 	}
 
 	ProcessLauncher::ProcessLauncher() :
-		m_texinputs(KileConfig::teXPaths()),
-		m_bibinputs(KileConfig::bibInputPaths()),
- 		m_bstinputs(KileConfig::bstInputPaths()),
 		m_changeTo(true)
 	{
-		KILE_DEBUG() << "==KileTool::ProcessLauncher::ProcessLauncher()==============";
+		KILE_DEBUG_MAIN << "==KileTool::ProcessLauncher::ProcessLauncher()==============";
 
 		m_proc = new KProcess(this);
 
@@ -77,12 +68,12 @@ namespace KileTool {
 
 	ProcessLauncher::~ProcessLauncher()
 	{
-		KILE_DEBUG() << "DELETING ProcessLauncher";
+		KILE_DEBUG_MAIN << "DELETING ProcessLauncher";
 
 		if(m_proc) {
 			// we don't want it to emit any signals as we are being deleted
 			m_proc->disconnect();
-			kill();
+			kill(false);
 			delete m_proc;
 		}
 	}
@@ -96,7 +87,7 @@ namespace KileTool {
 	{
 		m_changeTo = change;
 	}
-	
+
 	void ProcessLauncher::setCommand(const QString& cmd)
 	{
 		m_cmd = cmd;
@@ -109,12 +100,12 @@ namespace KileTool {
 
 	bool ProcessLauncher::launch()
 	{
-		if(tool() == NULL){
-		  kWarning() << "tool() is NULL which is a BUG";
+		if(tool() == Q_NULLPTR){
+		  qWarning() << "tool() is Q_NULLPTR which is a BUG";
 		  return false;
 		}
-		if(m_proc == NULL){
-		  kWarning() << "m_proc is NULL which is a BUG";
+		if(m_proc == Q_NULLPTR){
+		  qWarning() << "m_proc is Q_NULLPTR which is a BUG";
 		  return false;
 		}
 
@@ -123,25 +114,25 @@ namespace KileTool {
 
 		if(m_cmd.isEmpty()) {
 			m_cmd = tool()->readEntry("command");
-			KILE_DEBUG() << "readEntry('command'): " << m_cmd;
+			KILE_DEBUG_MAIN << "readEntry('command'): " << m_cmd;
 		}
 
 		if(m_options.isEmpty()) {
 			m_options = tool()->readEntry("options");
-			KILE_DEBUG() << "readEntry('option'):" << m_options;
+			KILE_DEBUG_MAIN << "readEntry('option'):" << m_options;
 		}
 
 		if(m_changeTo && (!m_wd.isEmpty())) {
 			m_proc->setWorkingDirectory(m_wd);
-			KILE_DEBUG() << "changed to " << m_wd;
+			KILE_DEBUG_MAIN << "changed to " << m_wd;
 			out += QString("*****     cd \"") + m_wd + QString("\"\n");
 		}
 
 		QString str;
 		tool()->translate(m_cmd);
-		tool()->translate(m_options);
-
-		KILE_DEBUG() << "after translate: m_cmd=" << m_cmd << ", m_options=" << m_options;
+		tool()->translate(m_options, true); // quote the substituted strings using 'KShell::quoteArg'
+		                                    // (see bug 314109)
+		KILE_DEBUG_MAIN << "after translate: m_cmd=" << m_cmd << ", m_options=" << m_options;
 
 		if(m_cmd.isEmpty()) {
 			return false;
@@ -159,8 +150,8 @@ namespace KileTool {
 		// want to use that directory)
 		// BUG: 204397
 		m_proc->setProgram(m_cmd, arguments);
-		
-		KILE_DEBUG() << "sent " << m_cmd << ' ' << arguments;
+
+		KILE_DEBUG_MAIN << "sent " << m_cmd << ' ' << arguments;
 
 		out += QString("*****     ") + m_cmd + ' ' + arguments.join(" ") + '\n';
 
@@ -177,53 +168,62 @@ namespace KileTool {
 
 		emit(message(Info, msg));
 
+		QString teXInputPaths = tool()->teXInputPaths();
+		QString bibInputPaths = tool()->bibInputPaths();
+		QString bstInputPaths = tool()->bstInputPaths();
+
 		// QuickView tools need a special TEXINPUTS environment variable
 		if(tool()->isQuickie()) {
-			m_texinputs = KileConfig::previewTeXPaths();
+			teXInputPaths = KileConfig::previewTeXPaths();
+			bibInputPaths = KileConfig::previewBibInputPaths();
 		}
 
-		KILE_DEBUG() << "$PATH=" << tool()->manager()->info()->expandEnvironmentVars("$PATH");
-		KILE_DEBUG() << "$TEXINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(m_texinputs + ":$TEXINPUTS");
-		KILE_DEBUG() << "$BIBINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(m_bibinputs + ":$BIBINPUTS");
-		KILE_DEBUG() << "$BSTINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(m_bstinputs + ":$BSTINPUTS");
-		KILE_DEBUG() << "Tool name is "<< tool()->name();
+		KILE_DEBUG_MAIN << "$PATH=" << tool()->manager()->info()->expandEnvironmentVars("$PATH");
+		KILE_DEBUG_MAIN << "$TEXINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(teXInputPaths + PATH_SEPARATOR + "$TEXINPUTS");
+		KILE_DEBUG_MAIN << "$BIBINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(bibInputPaths + PATH_SEPARATOR + "$BIBINPUTS");
+		KILE_DEBUG_MAIN << "$BSTINPUTS=" << tool()->manager()->info()->expandEnvironmentVars(bstInputPaths + PATH_SEPARATOR + "$BSTINPUTS");
+		KILE_DEBUG_MAIN << "Tool name is "<< tool()->name();
 
 		m_proc->setEnv("PATH", tool()->manager()->info()->expandEnvironmentVars("$PATH"));
 
-		if(!m_texinputs.isEmpty()) {
-			m_proc->setEnv("TEXINPUTS", tool()->manager()->info()->expandEnvironmentVars(m_texinputs + ":$TEXINPUTS"));
+		if(!teXInputPaths.isEmpty()) {
+			m_proc->setEnv("TEXINPUTS", tool()->manager()->info()->expandEnvironmentVars(teXInputPaths + PATH_SEPARATOR + "$TEXINPUTS"));
 		}
-		if(!m_bibinputs.isEmpty()) {
-			m_proc->setEnv("BIBINPUTS", tool()->manager()->info()->expandEnvironmentVars(m_bibinputs + ":$BIBINPUTS"));
+		if(!bibInputPaths.isEmpty()) {
+			m_proc->setEnv("BIBINPUTS", tool()->manager()->info()->expandEnvironmentVars(bibInputPaths + PATH_SEPARATOR + "$BIBINPUTS"));
 		}
-		if(!m_bstinputs.isEmpty()) {
-			m_proc->setEnv("BSTINPUTS", tool()->manager()->info()->expandEnvironmentVars(m_bstinputs + ":$BSTINPUTS"));
+		if(!bstInputPaths.isEmpty()) {
+			m_proc->setEnv("BSTINPUTS", tool()->manager()->info()->expandEnvironmentVars(bstInputPaths + PATH_SEPARATOR + "$BSTINPUTS"));
 		}
 
 		out += "*****\n";
 		emit(output(out));
 
 		if(tool()->manager()->shouldBlock()) {
-			KILE_DEBUG() << "About to execute: " << m_proc->program();
+			KILE_DEBUG_MAIN << "About to execute: " << m_proc->program();
 			m_proc->execute();
 		}
 		else {
-			KILE_DEBUG() << "About to start: " << m_proc->program();
+			KILE_DEBUG_MAIN << "About to start: " << m_proc->program();
 			m_proc->start();
 		}
 		return true;
 	}
 
-	void ProcessLauncher::kill()
+	void ProcessLauncher::kill(bool emitSignals)
 	{
-		KILE_DEBUG() << "==KileTool::ProcessLauncher::kill()==============";
+		KILE_DEBUG_MAIN << "==KileTool::ProcessLauncher::kill()==============";
 		if(m_proc && m_proc->state() == QProcess::Running) {
-			KILE_DEBUG() << "\tkilling";
+			KILE_DEBUG_MAIN << "\tkilling";
 			m_proc->kill();
 			m_proc->waitForFinished(-1);
 		}
 		else {
-			KILE_DEBUG() << "\tno process or process not running";
+			KILE_DEBUG_MAIN << "\tno process or process not running";
+			if(emitSignals) {
+				emit(message(Error, i18n("terminated")));
+				emit(done(AbnormalExit));
+			}
 		}
 	}
 
@@ -242,10 +242,10 @@ namespace KileTool {
 			emit(message(Error, i18n("Shell meta characters that cannot be handled are present in the options given to the tool.")));
 			return false;
 		}
-		
+
 
 		QString exe = KRun::binaryName(tool()->readEntry("command"), false);
-		QString path = KGlobal::dirs()->findExe(exe, QString(), KStandardDirs::IgnoreExecBit);
+		QString path = QStandardPaths::findExecutable(exe);
 
 		if(path.isEmpty()) {
 			emit(message(Error, i18n("There is no executable named \"%1\" in your path.", exe)));
@@ -271,12 +271,12 @@ namespace KileTool {
 
 	void ProcessLauncher::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
 	{
-		KILE_DEBUG() << "==KileTool::ProcessLauncher::slotProcessExited=============";
-		KILE_DEBUG() << "\t" << tool()->name();
+		KILE_DEBUG_MAIN << "==KileTool::ProcessLauncher::slotProcessExited=============";
+		KILE_DEBUG_MAIN << "\t" << tool()->name();
 
 		if(m_proc) {
 			if(exitStatus == QProcess::NormalExit) {
-				KILE_DEBUG() << "\tnormal exit";
+				KILE_DEBUG_MAIN << "\tnormal exit";
 				int type = Info;
 				if(exitCode != 0) {
 					type = Error;
@@ -291,20 +291,20 @@ namespace KileTool {
 				}
 			}
 			else {
-				KILE_DEBUG() << "\tabnormal exit";
+				KILE_DEBUG_MAIN << "\tabnormal exit";
 				emit(message(Error, i18n("finished abruptly")));
 				emit(done(AbnormalExit));
 			}
 		}
 		else {
-			kWarning() << "\tNO PROCESS, emitting done";
+			qWarning() << "\tNO PROCESS, emitting done";
 			emit(done(Success));
 		}
 	}
 
 	void ProcessLauncher::slotProcessError(QProcess::ProcessError error)
 	{
-		KILE_DEBUG() << "error =" << error << "tool = " << tool()->name();
+		KILE_DEBUG_MAIN << "error =" << error << "tool = " << tool()->name();
 		QString errorString;
 		switch(error) {
 			case QProcess::FailedToStart:
@@ -331,168 +331,54 @@ namespace KileTool {
 		QString noclose = (tool()->readEntry("close") == "no") ? "--noclose" : "";
 		setCommand("konsole");
 		setOptions(noclose + " -e " + cmd + ' ' + tool()->readEntry("options"));
-		if(KGlobal::dirs()->findExe(KRun::binaryName(cmd, false)).isEmpty()) {
+		if(QStandardPaths::findExecutable(KRun::binaryName(cmd, false)).isEmpty()) {
 			return false;
 		}
 
 		return ProcessLauncher::launch();
 	}
 
-	PartLauncher::PartLauncher() :
-		m_part(NULL),
-		m_state("Viewer")
+	DocumentViewerLauncher::DocumentViewerLauncher()
 	{
 	}
 
-	PartLauncher::~PartLauncher()
+	DocumentViewerLauncher::~DocumentViewerLauncher()
 	{
-		// the created part will be deleted in 'Kile::resetPart' 
-		KILE_DEBUG () << "DELETING PartLauncher";
+		KILE_DEBUG_MAIN << "DELETING DocumentViewerLauncher";
 	}
 
-	void PartLauncher::setLibrary(const QString& lib)
-	{
-		m_libName = lib;
-	}
-
-	void PartLauncher::setClass(const QString& clas)
-	{
-		m_className = clas;
-	}
-
-	void PartLauncher::setOptions(const QString& options)
-	{
-		m_options = options;
-	}
-
-	bool PartLauncher::selfCheck()
+	bool DocumentViewerLauncher::selfCheck()
 	{
 		return true;  //no additional self-checks, all of them are done in launch()
 	}
 
-	bool PartLauncher::launch()
+	bool DocumentViewerLauncher::launch()
 	{
-		m_libName = tool()->readEntry("libName");
-		m_className = tool()->readEntry("className");
-		m_options = tool()->readEntry("libOptions");
-		m_state = tool()->readEntry("state");
-
-		QString msg, out = "*****\n*****     " + tool()->name() + i18n(" output: \n");
-		
-		QString name, shrt;
-
-		// FIXME: this should be made user configurable
-		// allow support for embedding ForwardPDF (with Okular) as part (bug 245483)
-		if(tool()->paramDict().contains("%absolute_target")) {
-			shrt = "%absolute_target";
-			tool()->translate(shrt);
-			name = shrt;
-		}
-		else {
-			shrt = "%target";
-			tool()->translate(shrt);
-			QString dir  = "%dir_target";
-			tool()->translate(dir);
-
-			name = shrt;
-			if(!QDir::isRelativePath(dir)) {
-				name = dir + '/' + shrt;
-			}
-		}
-
-		KPluginLoader pluginLoader(m_libName);
-		KPluginFactory *factory = pluginLoader.factory();
-		if (!factory) {
-			emit(message(Error, i18n("Could not find the %1 library.", m_libName)));
+		if(!tool()->manager()->viewManager()->viewerPart()) {
+			emit(message(Error, i18n("The document viewer is not available")));
 			return false;
 		}
-
-		QStackedWidget *stack = tool()->manager()->widgetStack();
-		KParts::PartManager *pm = tool()->manager()->partManager();
-
-		m_part = factory->create<KParts::ReadOnlyPart>(stack, toVariantList(KShell::splitArgs(m_options, KShell::AbortOnMeta)));
-
-		if(!m_part) {
-			emit(message(Error, i18n("Could not create component %1 from the library %2.", m_className, m_libName)));
-			emit(done(Failed));
+		if(tool()->manager()->livePreviewManager() && tool()->manager()->livePreviewManager()->isLivePreviewActive()) {
+			emit(message(Error, i18n("Please disable the live preview before launching this tool")));
 			return false;
 		}
-		else {
-			QString cmd = QString(m_libName) + "->" + QString(m_className) + ' ' + m_options + ' ' + name;
-			out += "*****     " + cmd + '\n';
-
-			msg = shrt+ " (" + tool()->readEntry("libName") + ')';
-			emit(message(Info,msg));
+		const QString fileName = tool()->paramDict()["%dir_target"] + '/' + tool()->paramDict()["%target"];
+		tool()->manager()->viewManager()->openInDocumentViewer(QUrl::fromLocalFile(fileName));
+		if(tool()->paramDict().contains("%sourceFileName")
+		    && tool()->paramDict().contains("%sourceLine")) {
+			const QString sourceFileName = tool()->paramDict()["%sourceFileName"];
+			const QString lineString = tool()->paramDict()["%sourceLine"];
+			tool()->manager()->viewManager()->showSourceLocationInDocumentViewer(sourceFileName, lineString.toInt(), 0);
 		}
-
-		out += "*****\n";
-		emit(output(out));
-
-		tool()->manager()->wantGUIState(m_state);
-
-		stack->insertWidget(1, m_part->widget());
-		stack->setCurrentIndex(1);
-
-		m_part->openUrl(KUrl(name));
-		pm->addPart(m_part, true);
-		pm->setActivePart(m_part);
-
 		emit(done(Success));
 
 		return true;
 	}
 
-	void PartLauncher::kill()
+	void DocumentViewerLauncher::kill(bool emitSignals)
 	{
-	}
-
-	KParts::ReadOnlyPart* PartLauncher::part()
-	{
-		return m_part;
-	}
-
-	DocPartLauncher::DocPartLauncher() : PartLauncher()
-	{
-	}
-
-	bool DocPartLauncher::launch()
-	{
-		m_state=tool()->readEntry("state");
-
-		QString shrt = "%target";
-		tool()->translate(shrt);
-		QString name="%dir_target/%target";
-		tool()->translate(name);
-
-		QString out = "*****\n*****     " + tool()->name() + i18n(" output: \n") + "*****     KHTML " + name + "\n*****\n";
-		QString msg =  shrt+ " (KHTML)";
-		emit(message(Info, msg));
-		emit(output(out));
-
-		QStackedWidget *stack = tool()->manager()->widgetStack();
-		KParts::PartManager *pm = tool()->manager()->partManager();
-
-		DocumentationViewer *htmlpart = new DocumentationViewer(stack);
-		htmlpart->setObjectName("help");
-		m_part = static_cast<KParts::ReadOnlyPart*>(htmlpart);
-
-		connect(htmlpart, SIGNAL(updateStatus(bool, bool)), tool(), SIGNAL(updateStatus(bool, bool)));
-
-		tool()->manager()->wantGUIState(m_state);
-
-		htmlpart->openUrl(KUrl(name));
-		htmlpart->addToHistory(name);
-		stack->insertWidget(1, htmlpart->widget());
-		stack->setCurrentIndex(1);
-
-		pm->addPart(htmlpart, true);
-		pm->setActivePart( htmlpart);
-
-		emit(done(Success));
-		
-		return true;
+		Q_UNUSED(emitSignals);
 	}
 
 }
 
-#include "kilelauncher.moc"
