@@ -2,7 +2,7 @@
     begin                : Fri Aug 1 2003
     copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
                            (C) 2007 by Holger Danielsson (holger.danielsson@versanet.de)
-                           (C) 2009-2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+                           (C) 2009-2016 by Michel Ludwig (michel.ludwig@kdemail.net)
 *********************************************************************************************/
 
 /***************************************************************************
@@ -19,22 +19,15 @@
 //  - allowed extensions are always defined as list, f.e.: .tex .ltx .latex
 
 #include "kileproject.h"
-#include "kileversion.h"
 
 #include <QStringList>
 #include <QFileInfo>
 #include <QDir>
 
-#include <kdeversion.h>
-#include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
-#include <KTextEditor/SessionConfigInterface>
-#if KDE_IS_VERSION(4,3,75)
-#include <KTextEditor/ParameterizedSessionConfigInterface>
-#endif
-#include <KUrl>
+#include <KShell>
+#include <QUrl>
 
 #include "documentinfo.h"
 #include "kiledebug.h"
@@ -42,26 +35,27 @@
 #include "kiletoolmanager.h"
 #include "kileinfo.h"
 #include "kileextensions.h"
+#include "livepreview.h"
 
-/*
- 01/24/06 tbraun
-	Added the logic to get versioned kilepr files
-	We also warn if the user wants to open a project file with a different kileprversion
-*/
+/**
+ * Since project file version 3, project files 'consist' of two files: one file named '<name>.kilepr' and
+ * one file named '<name>.kilepr.gui' located in the '.kile' subdirectory of the project directory.
+ * The former files contains the static structure of the project, and the later contains the current gui display settings
+ * (like which file is open or on which line and column the cursors are).
+ */
 
 
 /*
  * KileProjectItem
  */
-KileProjectItem::KileProjectItem(KileProject *project, const KUrl & url, int type) :
+KileProjectItem::KileProjectItem(KileProject *project, const QUrl &url, int type) :
 	m_project(project),
 	m_url(url),
 	m_type(type),
-	m_docinfo(NULL),
-	m_parent(NULL),
-	m_child(NULL),
-	m_sibling(NULL),
-	m_nLine(0),
+	m_docinfo(Q_NULLPTR),
+	m_parent(Q_NULLPTR),
+	m_child(Q_NULLPTR),
+	m_sibling(Q_NULLPTR),
 	m_order(-1)
 {
 	m_bOpen = m_archive = true;
@@ -103,28 +97,30 @@ void KileProjectItem::setParent(KileProjectItem * item)
 
 void KileProjectItem::load()
 {
-	KConfigGroup configGroup = m_project->configGroupForItem(this);
-	setOpenState(configGroup.readEntry("open", true));
-	setEncoding(configGroup.readEntry("encoding", QString()));
-	setMode(configGroup.readEntry("mode", QString()));
-	setHighlight(configGroup.readEntry("highlight", QString()));
-	setArchive(configGroup.readEntry("archive", true));
-	setLineNumber(configGroup.readEntry("line", 0));
-	setColumnNumber(configGroup.readEntry("column", 0));
-	setOrder(configGroup.readEntry("order", -1));
+	KConfigGroup projectConfigGroup = m_project->configGroupForItem(this, KileProject::ProjectFile);
+	KConfigGroup guiConfigGroup = m_project->configGroupForItem(this, KileProject::GUIFile);
+	// project: archive, highlight, mode
+	// gui: column, encoding, line, open, order
+	setEncoding(projectConfigGroup.readEntry("encoding", QString()));
+	setMode(projectConfigGroup.readEntry("mode", QString()));
+	setHighlight(projectConfigGroup.readEntry("highlight", QString()));
+	setArchive(projectConfigGroup.readEntry("archive", true));
+	setOpenState(guiConfigGroup.readEntry("open", true));
+	setOrder(guiConfigGroup.readEntry("order", -1));
 }
 
 void KileProjectItem::save()
 {
-	KConfigGroup configGroup = m_project->configGroupForItem(this);
-	configGroup.writeEntry("open", isOpen());
-	configGroup.writeEntry("encoding", encoding());
-	configGroup.writeEntry("mode", mode());
-	configGroup.writeEntry("highlight", highlight());
-	configGroup.writeEntry("archive", archive());
-	configGroup.writeEntry("line", lineNumber());
-	configGroup.writeEntry("column", columnNumber());
-	configGroup.writeEntry("order", order());
+	KConfigGroup projectConfigGroup = m_project->configGroupForItem(this, KileProject::ProjectFile);
+	KConfigGroup guiConfigGroup = m_project->configGroupForItem(this, KileProject::GUIFile);
+	// project: archive, highlight, mode
+	// gui: encoding, open, order
+	projectConfigGroup.writeEntry("encoding", encoding());
+	projectConfigGroup.writeEntry("mode", mode());
+	projectConfigGroup.writeEntry("highlight", highlight());
+	projectConfigGroup.writeEntry("archive", archive());
+	guiConfigGroup.writeEntry("open", isOpen());
+	guiConfigGroup.writeEntry("order", order());
 }
 
 void KileProjectItem::loadDocumentAndViewSettings()
@@ -165,55 +161,36 @@ void KileProjectItem::saveDocumentAndViewSettings()
 
 void KileProjectItem::loadViewSettings(KTextEditor::View *view, int viewIndex)
 {
-	KTextEditor::SessionConfigInterface *interface = qobject_cast<KTextEditor::SessionConfigInterface*>(view);
-	if(!interface) {
-		return;
-	}
-	interface->readSessionConfig(m_project->configGroupForItemViewSettings(this, viewIndex));
+	KConfigGroup configGroup = m_project->configGroupForItemViewSettings(this, viewIndex);
+	view->readSessionConfig(configGroup);
 }
 
 void KileProjectItem::saveViewSettings(KTextEditor::View *view, int viewIndex)
 {
-	KTextEditor::SessionConfigInterface *interface = qobject_cast<KTextEditor::SessionConfigInterface*>(view);
-	if(!interface) {
-		return;
-	}
 	KConfigGroup configGroup = m_project->configGroupForItemViewSettings(this, viewIndex);
-	interface->writeSessionConfig(configGroup);
+	view->writeSessionConfig(configGroup);
 }
 
 void KileProjectItem::loadDocumentSettings(KTextEditor::Document *document)
 {
-#if KDE_IS_VERSION(4,3,75)
-	KTextEditor::ParameterizedSessionConfigInterface *interface = qobject_cast<KTextEditor::ParameterizedSessionConfigInterface*>(document);
-	if(!interface) {
-		return;
-	}
 	KConfigGroup configGroup = m_project->configGroupForItemDocumentSettings(this);
 	if(!configGroup.exists()) {
 		return;
 	}
-	interface->readParameterizedSessionConfig(configGroup, KTextEditor::ParameterizedSessionConfigInterface::SkipUrl);
-#endif
+	document->readSessionConfig(configGroup, QSet<QString>() << "SkipUrl");
 }
 
 void KileProjectItem::saveDocumentSettings(KTextEditor::Document *document)
 {
-#if KDE_IS_VERSION(4,3,75)
-	KTextEditor::ParameterizedSessionConfigInterface *interface = qobject_cast<KTextEditor::ParameterizedSessionConfigInterface*>(document);
-	if(!interface) {
-		return;
-	}
 	KConfigGroup configGroup = m_project->configGroupForItemDocumentSettings(this);
-	interface->writeParameterizedSessionConfig(configGroup, KTextEditor::ParameterizedSessionConfigInterface::SkipUrl);
-#endif
+	document->writeSessionConfig(configGroup, QSet<QString>() << "SkipUrl");
 }
 
 void KileProjectItem::print(int level)
 {
 	QString str;
 	str.fill('\t', level);
-	KILE_DEBUG() << str << "+" << url().fileName();
+	KILE_DEBUG_MAIN << str << "+" << url().fileName();
 
 	if (firstChild()) {
 		firstChild()->print(++level);
@@ -228,10 +205,10 @@ void KileProjectItem::allChildren(QList<KileProjectItem*> *list) const
 {
 	KileProjectItem *item = firstChild();
 
-// 	KILE_DEBUG() << "\tKileProjectItem::allChildren(" << list->count() << ")";
-	while(item != NULL) {
+// 	KILE_DEBUG_MAIN << "\tKileProjectItem::allChildren(" << list->count() << ")";
+	while(item != Q_NULLPTR) {
 		list->append(item);
-// 		KILE_DEBUG() << "\t\tappending " << item->url().fileName();
+// 		KILE_DEBUG_MAIN << "\t\tappending " << item->url().fileName();
 		item->allChildren(list);
 		item = item->sibling();
 	}
@@ -242,12 +219,12 @@ void KileProjectItem::setInfo(KileDocument::TextInfo *docinfo)
 	m_docinfo = docinfo;
 	if(docinfo)
 	{
-	connect(docinfo,SIGNAL(urlChanged(KileDocument::Info*, const KUrl &)), this, SLOT(slotChangeURL(KileDocument::Info*, const KUrl &)));
+	connect(docinfo,SIGNAL(urlChanged(KileDocument::Info*, const QUrl &)), this, SLOT(slotChangeURL(KileDocument::Info*, const QUrl &)));
 	connect(docinfo,SIGNAL(depChanged()), m_project, SLOT(buildProjectTree()));
 	}
 }
 
-void KileProjectItem::changeURL(const KUrl &url)
+void KileProjectItem::changeURL(const QUrl &url)
 {
 	// don't allow empty URLs
 	if(!url.isEmpty() && m_url != url)
@@ -257,7 +234,7 @@ void KileProjectItem::changeURL(const KUrl &url)
 	}
 }
 
-void KileProjectItem::slotChangeURL(KileDocument::Info*, const KUrl &url)
+void KileProjectItem::slotChangeURL(KileDocument::Info*, const QUrl &url)
 {
 	changeURL(url);
 }
@@ -265,21 +242,37 @@ void KileProjectItem::slotChangeURL(KileDocument::Info*, const KUrl &url)
 /*
  * KileProject
  */
-KileProject::KileProject(const QString& name, const KUrl& url, KileDocument::Extensions *extensions) : QObject(NULL), m_invalid(false), m_masterDocument(QString()), m_useMakeIndexOptions(false)
+
+// for creating an empty project
+KileProject::KileProject(const QString& name, const QUrl &url, KileDocument::Extensions *extensions)
+: QObject(Q_NULLPTR), m_invalid(false), m_masterDocument(QString()), m_useMakeIndexOptions(false),
+  m_config(Q_NULLPTR), m_guiConfig(Q_NULLPTR), m_extmanager(extensions)
 {
-	setObjectName(name);
-	init(name, url, extensions);
+	m_name = name;
+	init(url);
+
+	//create the project file
+	KConfigGroup configGroup = m_config->group("General");
+	configGroup.writeEntry("name", m_name);
+	configGroup.writeEntry("kileprversion", KILE_PROJECTFILE_VERSION);
+	configGroup.writeEntry("kileversion", kileFullVersion);
+
+	load();
 }
 
-KileProject::KileProject(const KUrl& url, KileDocument::Extensions *extensions) : QObject(NULL), m_invalid(false), m_masterDocument(QString()), m_useMakeIndexOptions(false)
+// for opening an existing project, 'load()' still has to be called separately!
+KileProject::KileProject(const QUrl &url, KileDocument::Extensions *extensions)
+: QObject(Q_NULLPTR), m_invalid(false), m_masterDocument(QString()), m_useMakeIndexOptions(false),
+  m_config(Q_NULLPTR), m_guiConfig(Q_NULLPTR), m_extmanager(extensions)
 {
-	setObjectName(url.fileName());
-	init(url.fileName(), url, extensions);
+	init(url);
 }
 
 KileProject::~KileProject()
 {
-	KILE_DEBUG() << "DELETING KILEPROJECT " <<  m_projecturl.url();
+	KILE_DEBUG_MAIN << "DELETING KILEPROJECT " <<  m_projecturl.url();
+	emit(aboutToBeDestroyed(this));
+	delete m_guiConfig;
 	delete m_config;
 
 	for(QList<KileProjectItem*>::iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
@@ -287,43 +280,29 @@ KileProject::~KileProject()
 	}
 }
 
-void KileProject::init(const QString& name, const KUrl& url, KileDocument::Extensions *extensions)
+void KileProject::init(const QUrl &url)
 {
-	m_name = name;
-	m_projecturl = KileDocument::Manager::symlinkFreeURL( url);;
+	m_projecturl = KileDocument::Manager::symlinkFreeURL(url);
+
+	m_baseurl = m_projecturl.adjusted(QUrl::RemoveFilename);
+
+	KILE_DEBUG_MAIN << "KileProject m_baseurl = " << m_baseurl.toLocalFile();
 
 	m_config = new KConfig(m_projecturl.toLocalFile(), KConfig::SimpleConfig);
-	m_extmanager = extensions;
-
-	m_baseurl = m_projecturl.directory();
-	m_baseurl.cleanPath(KUrl::SimplifyDirSeparators);
-
-	KILE_DEBUG() << "KileProject m_baseurl = " << m_baseurl.toLocalFile();
-
-	if(QFileInfo(url.toLocalFile()).exists()) {
-		load();
-	}
-	else {
-		//create the project file
-		KConfigGroup configGroup = m_config->group("General");
-		configGroup.writeEntry("name", m_name);
-		configGroup.writeEntry("kileprversion", kilePrVersion);
-		configGroup.writeEntry("kileversion", kileFullVersion);
-		configGroup.sync();
-	}
 }
 
-void KileProject::setLastDocument(const KUrl &url)
+void KileProject::setLastDocument(const QUrl &url)
 {
-    if ( item(url) != 0 )
+    if (item(url) != 0) {
         m_lastDocument = KileDocument::Manager::symlinkFreeURL(url);
+    }
 }
 
 void KileProject::setExtensions(KileProjectItem::Type type, const QString & ext)
 {
-	if (type<KileProjectItem::Source || type>KileProjectItem::Image)
+	if (type == KileProjectItem::ProjectFile || type >= KileProjectItem::Other)
 	{
-		kWarning() << "ERROR: TYPE<1 or TYPE>3";
+		qWarning() << "ERROR: invalid project item type:" << type;
 		return;
 	}
 
@@ -335,11 +314,14 @@ void KileProject::setExtensions(KileProjectItem::Type type, const QString & ext)
 	else if(type == KileProjectItem::Package) {
 		standardExtList = (m_extmanager->latexPackages()).split(' ');
 	}
-	else { // if ( type == KileProjectItem::Image )
+	else if(type == KileProjectItem::Image) {
 		standardExtList = (m_extmanager->images()).split(' ');
 	}
+	else if(type == KileProjectItem::Bibliography) {
+		standardExtList = (m_extmanager->bibtex()).split(' ');
+	}
 
-	// now we scan user defined list and accept all extension,
+	// now we scan user-defined list and accept all extension,
 	// except standard extensions of course
 	QString userExt;
 	if(!ext.isEmpty()) {
@@ -360,12 +342,18 @@ void KileProject::setExtensions(KileProjectItem::Type type, const QString & ext)
 					userExtList << (*it);
 				}
 			}
-			else { // if ( type == KileProjectItem::Image )
+			else if(type == KileProjectItem::Image) {
 				if(!m_extmanager->isImage(*it)) {
 					standardExtList << (*it);
 					userExtList << (*it);
 				}
 			}
+			else if(type == KileProjectItem::Bibliography) {
+				if(!m_extmanager->isBibFile(*it)) {
+					standardExtList << (*it);
+					userExtList << (*it);
+				}
+			}
 		}
 		if(userExtList.count() > 0) {
 			userExt = userExtList.join(" ");
@@ -381,7 +369,7 @@ void KileProject::setExtensions(KileProjectItem::Type type, const QString & ext)
 	// and save it
 	m_reExtensions[type-1].setPattern(pattern);
 
-	// if the list of user defined extensions has changed
+	// if the list of user-defined extensions has changed
 	// we save the new value and (re)build the project tree
 	if (m_extensions[type-1] != userExt) {
 		m_extensions[type-1] = userExt;
@@ -423,7 +411,7 @@ void KileProject::readMakeIndexOptions()
 	QString grp = KileTool::groupFor("MakeIndex", m_config);
 
 	//get the default value
-	KSharedConfig::Ptr cfg = KGlobal::config();
+	KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
 	KConfigGroup configGroup = cfg->group(KileTool::groupFor("MakeIndex", KileTool::configName("MakeIndex", cfg.data())));
 	QString deflt = configGroup.readEntry("options", "'%S'.idx");
 
@@ -448,16 +436,16 @@ void KileProject::writeUseMakeIndexOptions()
 
 QString KileProject::addBaseURL(const QString &path)
 {
-	KILE_DEBUG() << "===addBaseURL(const QString & " << path << " )";
+	KILE_DEBUG_MAIN << "===addBaseURL(const QString & " << path << " )";
 	if(path.isEmpty()) {
 		return path;
 	}
 
 	else if(QDir::isAbsolutePath(path)) {
-		return KileDocument::Manager::symlinkFreeURL(KUrl(path)).toLocalFile();
+		return KileDocument::Manager::symlinkFreeURL(QUrl::fromLocalFile(path)).toLocalFile();
 	}
 	else {
-		return  KileDocument::Manager::symlinkFreeURL(KUrl(m_baseurl.toLocalFile(KUrl::AddTrailingSlash) +path)).toLocalFile();
+		return  KileDocument::Manager::symlinkFreeURL(QUrl::fromLocalFile(m_baseurl.adjusted(QUrl::StripTrailingSlash).toLocalFile() + '/' + path)).toLocalFile();
 	}
 }
 
@@ -466,7 +454,7 @@ QString KileProject::removeBaseURL(const QString &path)
 	if(QDir::isAbsolutePath(path)) {
 		QFileInfo info(path);
 		QString relPath = findRelativePath(path);
-		KILE_DEBUG() << "removeBaseURL path is" << path << " , relPath is " << relPath;
+		KILE_DEBUG_MAIN << "removeBaseURL path is" << path << " , relPath is " << relPath;
 		return relPath;
 	}
 	else {
@@ -474,37 +462,50 @@ QString KileProject::removeBaseURL(const QString &path)
 	}
 }
 
+bool KileProject::appearsToBeValidProjectFile()
+{
+	if(!m_config->hasGroup("General")) {
+		return false;
+	}
+
+	KConfigGroup generalGroup = m_config->group("General");
+	return generalGroup.hasKey("name") && generalGroup.hasKey("kileprversion") && generalGroup.hasKey("kileversion");
+}
+
+int KileProject::getProjectFileVersion()
+{
+	KConfigGroup generalGroup = m_config->group("General");
+
+	return generalGroup.readEntry("kileprversion", 0);
+}
+
+// WARNING: before calling this method, the project file must be of the current 'kileprversion'!
+//          also assumes that 'm_name' has been set correctly already if this is a fresh (empty) project!
 bool KileProject::load()
 {
-	KILE_DEBUG() << "KileProject: loading..." <<endl;
+	KILE_DEBUG_MAIN << "KileProject: loading..." << endl;
+
+	if(!ensurePrivateKileDirectoryExists(m_projecturl)) {
+	    return false;
+	}
+
+	delete m_guiConfig;
+	m_guiConfig = new KConfig(getPathForGUISettingsProjectFile(m_projecturl), KConfig::SimpleConfig);
 
 	//load general settings/options
 	KConfigGroup generalGroup = m_config->group("General");
-	m_name = generalGroup.readEntry("name", i18n("Project"));
-	m_kileversion = generalGroup.readEntry("kileversion", QString());
-	m_kileprversion = generalGroup.readEntry("kileprversion",QString());
+	m_name = generalGroup.readEntry("name", m_name);
 
 	m_defGraphicExt = generalGroup.readEntry("def_graphic_ext", QString());
 
-	if(!m_kileprversion.isNull() && m_kileprversion.toInt() > kilePrVersion.toInt())
-	{
-		if(KMessageBox::warningYesNo(NULL, i18n("The project file of %1 was created by a newer version of kile. "
-				"Opening it can lead to unexpected results.\n"
-				"Do you really want to continue (not recommended)?", m_name),
-				 QString(), KStandardGuiItem::yes(), KStandardGuiItem::no(), QString(), KMessageBox::Dangerous) == KMessageBox::No)
-		{
-			m_invalid=true;
-			return false;
-		}
-	}
-
 	QString master = addBaseURL(generalGroup.readEntry("masterDocument", QString()));
-	KILE_DEBUG() << "masterDoc == " << master;
+	KILE_DEBUG_MAIN << "masterDoc == " << master;
 	setMasterDocument(master);
 
 	setExtensions(KileProjectItem::Source, generalGroup.readEntry("src_extensions",m_extmanager->latexDocuments()));
 	setExtensions(KileProjectItem::Package, generalGroup.readEntry("pkg_extensions",m_extmanager->latexPackages()));
 	setExtensions(KileProjectItem::Image, generalGroup.readEntry("img_extensions",m_extmanager->images()));
+	setExtensions(KileProjectItem::Bibliography, generalGroup.readEntry("bib_extensions", m_extmanager->bibtex()));
 
 	setQuickBuildConfig(KileTool::configName("QuickBuild", m_config));
 
@@ -517,36 +518,44 @@ bool KileProject::load()
 
 	readMakeIndexOptions();
 
-	KUrl url;
+	QUrl url;
 	KileProjectItem *item;
-	QStringList groups = m_config->groupList();
+	const QStringList groups = m_config->groupList();
 
 	//retrieve all the project files and create and initialize project items for them
-	for (int i = 0; i < groups.count(); ++i) {
-		if (groups[i].left(5) == "item:") {
-			QString path = groups[i].mid(5);
+	for (auto group : groups) {
+		if(!m_config->hasGroup(group)) { // 'group' might have been deleted
+			continue;                // work around bug 384039
+		}
+		if (group.left(5) == "item:") {
+			QString path = group.mid(5);
 			if (QDir::isAbsolutePath(path)) {
-				url = KUrl(path);
+				url = QUrl::fromLocalFile(path);
 			}
 			else {
-				url = m_baseurl;
-				url.addPath(path);
-				url.cleanPath(KUrl::SimplifyDirSeparators);
+				url = m_baseurl.adjusted(QUrl::StripTrailingSlash);
+				url.setPath(url.path() + '/' + path);
 			}
 			item = new KileProjectItem(this, KileDocument::Manager::symlinkFreeURL(url));
 			setType(item);
 
-			KConfigGroup configGroup = m_config->group(groups[i]);
+			KConfigGroup configGroup = m_config->group(group);
 			// path has to be set before we can load it
-			item->changePath(groups[i].mid(5));
+			item->changePath(group.mid(5));
 			item->load();
 			connect(item, SIGNAL(urlChanged(KileProjectItem*)), this, SLOT(itemRenamed(KileProjectItem*)) );
 		}
 	}
 
-    // only call this after all items are created, otherwise setLastDocument doesn't accept the url
-    generalGroup = m_config->group("General");
-    setLastDocument(KUrl(addBaseURL(generalGroup.readEntry("lastDocument", QString()))));
+	// only call this after all items are created, otherwise setLastDocument doesn't accept the url
+	KConfigGroup guiGeneralGroup = m_guiConfig->group("General");
+	setLastDocument(QUrl::fromLocalFile(addBaseURL(guiGeneralGroup.readEntry("lastDocument", QString()))));
+
+	generalGroup = m_config->group("General");
+
+	readBibliographyBackendSettings(generalGroup);
+
+	KileTool::LivePreviewManager::readLivePreviewStatusSettings(guiGeneralGroup, this);
 
 // 	dump();
 
@@ -555,22 +564,28 @@ bool KileProject::load()
 
 bool KileProject::save()
 {
-	KILE_DEBUG() << "KileProject: saving..." <<endl;
+	KILE_DEBUG_MAIN << "KileProject: saving..." <<endl;
 
 	KConfigGroup generalGroup = m_config->group("General");
+	KConfigGroup guiGeneralGroup = m_guiConfig->group("General");
+
 	generalGroup.writeEntry("name", m_name);
-	generalGroup.writeEntry("kileprversion", kilePrVersion);
+	generalGroup.writeEntry("kileprversion", KILE_PROJECTFILE_VERSION);
 	generalGroup.writeEntry("kileversion", kileFullVersion);
 	generalGroup.writeEntry("def_graphic_ext", m_defGraphicExt);
 
-	KILE_DEBUG() << "KileProject::save() masterDoc = " << removeBaseURL(m_masterDocument);
+	KILE_DEBUG_MAIN << "KileProject::save() masterDoc = " << removeBaseURL(m_masterDocument);
 	generalGroup.writeEntry("masterDocument", removeBaseURL(m_masterDocument));
-	generalGroup.writeEntry("lastDocument", removeBaseURL(m_lastDocument.toLocalFile()));
+	guiGeneralGroup.writeEntry("lastDocument", removeBaseURL(m_lastDocument.toLocalFile()));
 
+	writeBibliographyBackendSettings(generalGroup);
+
+	KileTool::LivePreviewManager::writeLivePreviewStatusSettings(guiGeneralGroup, this);
 
 	writeConfigEntry("src_extensions",m_extmanager->latexDocuments(),KileProjectItem::Source);
 	writeConfigEntry("pkg_extensions",m_extmanager->latexPackages(),KileProjectItem::Package);
 	writeConfigEntry("img_extensions",m_extmanager->images(),KileProjectItem::Image);
+	writeConfigEntry("bib_extensions", m_extmanager->bibtex(), KileProjectItem::Bibliography);
 	// only to avoid problems with older versions
 	generalGroup.writeEntry("src_extIsRegExp", false);
 	generalGroup.writeEntry("pkg_extIsRegExp", false);
@@ -593,6 +608,7 @@ bool KileProject::save()
 	}
 
 	m_config->sync();
+	m_guiConfig->sync();
 
 	// dump();
 
@@ -611,27 +627,30 @@ void KileProject::writeConfigEntry(const QString &key, const QString &standardEx
 	}
 }
 
-KConfigGroup KileProject::configGroupForItem(KileProjectItem *item) const
+KConfigGroup KileProject::configGroupForItem(KileProjectItem *item, ConfigScope scope) const
 {
-	return m_config->group("item:" + item->path());
+	KConfig* cfgObject = (scope == GUIFile ? m_guiConfig : m_config);
+	return cfgObject->group("item:" + item->path());
 }
 
 KConfigGroup KileProject::configGroupForItemDocumentSettings(KileProjectItem *item) const
 {
-	return m_config->group("document-settings,item:" + item->path());
+	return m_guiConfig->group("document-settings,item:" + item->path());
 }
 
 KConfigGroup KileProject::configGroupForItemViewSettings(KileProjectItem *item, int viewIndex) const
 {
-	return m_config->group("view-settings,view=" + QString::number(viewIndex) + ",item:" + item->path());
+	return m_guiConfig->group("view-settings,view=" + QString::number(viewIndex) + ",item:" + item->path());
 }
 
 void KileProject::removeConfigGroupsForItem(KileProjectItem *item)
 {
 	QString itemString = "item:" + item->path();
-	QStringList groupList = m_config->groupList();
-	for(QStringList::iterator i = groupList.begin(); i != groupList.end(); ++i) {
-		QString groupName = *i;
+	const QStringList groupList = m_config->groupList();
+	for(auto groupName : groupList) {
+		if(!m_config->hasGroup(groupName)) { // 'groupName' might have been deleted
+			continue;                    // work around bug 384039
+		}
 		if(groupName.indexOf(itemString) >= 0) {
 			m_config->deleteGroup(groupName);
 		}
@@ -641,7 +660,7 @@ void KileProject::removeConfigGroupsForItem(KileProjectItem *item)
 static bool isAncestorOf(KileProjectItem *toBeChecked, KileProjectItem *parent)
 {
 	KileProjectItem *item = parent;
-	while(item != NULL) {
+	while(item != Q_NULLPTR) {
 		if(item == toBeChecked) {
 			return true;
 		}
@@ -652,14 +671,14 @@ static bool isAncestorOf(KileProjectItem *toBeChecked, KileProjectItem *parent)
 
 void KileProject::buildProjectTree()
 {
-	KILE_DEBUG() << "==KileProject::buildProjectTree==========================";
+	KILE_DEBUG_MAIN << "==KileProject::buildProjectTree==========================";
 
 	//determine the parent doc for each item (TODO:an item can only have one parent, not necessarily true for LaTeX docs)
 
 	QStringList deps;
 	QString dep;
 	KileProjectItem *itm;
-	KUrl url;
+	QUrl url;
 
 	//clean first
 	for(QList<KileProjectItem*>::iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
@@ -673,10 +692,10 @@ void KileProject::buildProjectTree()
 		KileDocument::Info *docinfo = (*it)->getInfo();
 
 		if(docinfo) {
-			KUrl parentUrl = docinfo->url();
+			QUrl parentUrl = docinfo->url();
 			if(parentUrl.isLocalFile()) {
 				// strip the file name from 'parentUrl'
-				parentUrl = KUrl::fromPathOrUrl(QFileInfo(parentUrl.path()).path());
+				parentUrl = QUrl::fromUserInput(QFileInfo(parentUrl.path()).path());
 			}
 			else {
 				parentUrl = m_baseurl;
@@ -686,10 +705,10 @@ void KileProject::buildProjectTree()
 				dep = deps[i];
 
 				if(m_extmanager->isTexFile(dep)) {
-					url = KileInfo::checkOtherPaths(parentUrl, dep, KileInfo::texinputs);
+					url = QUrl::fromLocalFile(KileInfo::checkOtherPaths(parentUrl, dep, KileInfo::texinputs));
 				}
 				else if(m_extmanager->isBibFile(dep)) {
-					url = KileInfo::checkOtherPaths(parentUrl, dep, KileInfo::bibinputs);
+					url = QUrl::fromLocalFile(KileInfo::checkOtherPaths(parentUrl, dep, KileInfo::bibinputs));
 				}
 				itm = item(url);
 				if(itm && (itm->parent() == 0)
@@ -704,7 +723,7 @@ void KileProject::buildProjectTree()
 	//make a list of all the root items (items with parent == 0)
 	m_rootItems.clear();
 	for(QList<KileProjectItem*>::iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
-		if((*it)->parent() == NULL) {
+		if((*it)->parent() == Q_NULLPTR) {
 			m_rootItems.append(*it);
 		}
 	}
@@ -712,7 +731,7 @@ void KileProject::buildProjectTree()
 	emit(projectTreeChanged(this));
 }
 
-KileProjectItem* KileProject::item(const KUrl& url)
+KileProjectItem* KileProject::item(const QUrl &url)
 {
 	for(QList<KileProjectItem*>::iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
 		if((*it)->url() == url) {
@@ -720,7 +739,7 @@ KileProjectItem* KileProject::item(const KUrl& url)
 		}
 	}
 
-	return NULL;
+	return Q_NULLPTR;
 }
 
 KileProjectItem* KileProject::item(const KileDocument::Info *info)
@@ -733,12 +752,12 @@ KileProjectItem* KileProject::item(const KileDocument::Info *info)
 		}
 	}
 
-	return NULL;
+	return Q_NULLPTR;
 }
 
 void KileProject::add(KileProjectItem* item)
 {
-	KILE_DEBUG() << "KileProject::add projectitem" << item->url().toLocalFile();
+	KILE_DEBUG_MAIN << "KileProject::add projectitem" << item->url().toLocalFile();
 
 	setType(item);
 
@@ -747,22 +766,26 @@ void KileProject::add(KileProjectItem* item)
 
 	m_projectItems.append(item);
 
+	emit projectItemAdded(this, item);
+
 	// dump();
 }
 
 void KileProject::remove(KileProjectItem* item)
 {
-	KILE_DEBUG() << item->path();
+	KILE_DEBUG_MAIN << item->path();
 	removeConfigGroupsForItem(item);
 	m_projectItems.removeAll(item);
 
+	emit projectItemRemoved(this, item);
+
 	// dump();
 }
 
 void KileProject::itemRenamed(KileProjectItem *item)
 {
-	KILE_DEBUG() << "==KileProject::itemRenamed==========================";
-	KILE_DEBUG() << "\t" << item->url().fileName();
+	KILE_DEBUG_MAIN << "==KileProject::itemRenamed==========================";
+	KILE_DEBUG_MAIN << "\t" << item->url().fileName();
 	removeConfigGroupsForItem(item);
 
 	item->changePath(findRelativePath(item->url()));
@@ -770,24 +793,22 @@ void KileProject::itemRenamed(KileProjectItem *item)
 
 QString KileProject::findRelativePath(const QString &path)
 {
-	return this->findRelativePath(KUrl(path));
+	return this->findRelativePath(QUrl::fromLocalFile(path));
 }
 
-QString KileProject::findRelativePath(const KUrl &url)
+QString KileProject::findRelativePath(const QUrl &url)
 {
-	KILE_DEBUG() << "QString KileProject::findRelativePath(const KUrl " << url.path() << ")";
+	KILE_DEBUG_MAIN << "QString KileProject::findRelativePath(const QUrl " << url.path() << ")";
 
 	if ( m_baseurl.toLocalFile() == url.toLocalFile() ) {
 		return "./";
 	}
-
-	m_baseurl.adjustPath(KUrl::AddTrailingSlash);
-	QString path = KUrl::relativeUrl(m_baseurl,url);
-	KILE_DEBUG() << "relPath is " << path;
+	const QString path = QDir(m_baseurl.path()).relativeFilePath(url.path());
+	KILE_DEBUG_MAIN << "relPath is " << path;
 	return path;
 }
 
-bool KileProject::contains(const KUrl &url)
+bool KileProject::contains(const QUrl &url)
 {
 	for(QList<KileProjectItem*>::iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
 		if((*it)->url() == url) {
@@ -812,7 +833,7 @@ KileProjectItem *KileProject::rootItem(KileProjectItem *item) const
 {
 	//find the root item (i.e. the eldest parent)
 	KileProjectItem *root = item;
-	while(root->parent() != NULL) {
+	while(root->parent() != Q_NULLPTR) {
 		root = root->parent();
 	}
 
@@ -841,25 +862,23 @@ KileProjectItem *KileProject::rootItem(KileProjectItem *item) const
 
 void KileProject::dump()
 {
-	KILE_DEBUG() << "KileProject::dump() " << m_name;
+	KILE_DEBUG_MAIN << "KileProject::dump() " << m_name;
 	for(QList<KileProjectItem*>::iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
 		KileProjectItem *item = *it;
-		KILE_DEBUG() << "item " << item << " has path: "  << item->path();
-		KILE_DEBUG() << "item->type() " << item->type();
-		KILE_DEBUG() << "OpenState: " << item->isOpen();
+		KILE_DEBUG_MAIN << "item " << item << " has path: "  << item->path();
+		KILE_DEBUG_MAIN << "item->type() " << item->type();
+		KILE_DEBUG_MAIN << "OpenState: " << item->isOpen();
 	}
 }
 
 QString KileProject::archiveFileList() const
 {
-	KILE_DEBUG() << "KileProject::archiveFileList()";
+	KILE_DEBUG_MAIN << "KileProject::archiveFileList()";
 
 	QString path, list;
 	for(QList<KileProjectItem*>::const_iterator it = m_projectItems.begin(); it != m_projectItems.end(); ++it) {
 		if ((*it)->archive()) {
-			path = (*it)->path();
-			KRun::shellQuote(path);
-			list.append(path + ' ');
+			list.append(KShell::quoteArg((*it)->path()) + ' ');
 		}
 	}
 	return list;
@@ -874,7 +893,7 @@ void KileProject::setMasterDocument(const QString & master){
 			m_masterDocument = master;
 		else {
 			m_masterDocument.clear();
-			KILE_DEBUG() << "setMasterDocument: masterDoc=NULL";
+			KILE_DEBUG_MAIN << "setMasterDocument: masterDoc=Q_NULLPTR";
 		}
 
 	}
@@ -885,4 +904,106 @@ void KileProject::setMasterDocument(const QString & master){
 	emit (masterDocumentChanged(m_masterDocument));
 }
 
-#include "kileproject.moc"
+namespace {
+
+	void moveConfigGroupKeysAsStrings(KConfig *src, KConfig *dst, const QString& groupName, const QStringList &keysToMove)
+	{
+		KConfigGroup srcGroup(src, groupName);
+		KConfigGroup dstGroup(dst, groupName);
+
+		for(const QString& key : keysToMove) {
+			if(srcGroup.hasKey(key)) {
+			    QString value = srcGroup.readEntry(key, QStringLiteral(""));
+			    dstGroup.writeEntry(key, value);
+			    srcGroup.deleteEntry(key);
+			}
+		}
+	}
+
+	void deleteConfigGroupKeys(KConfig *src, const QString& groupName, const QStringList &keysToDelete)
+	{
+		KConfigGroup srcGroup(src, groupName);
+
+		for(const QString& key : keysToDelete) {
+			srcGroup.deleteEntry(key);
+		}
+	}
+}
+
+bool KileProject::migrateProjectFileToCurrentVersion()
+{
+    if(getProjectFileVersion() < KILE_PROJECTFILE_VERSION) {
+		return migrateProjectFileToVersion3();
+    }
+    return true;
+}
+
+bool KileProject::migrateProjectFileToVersion3()
+{
+	KILE_DEBUG_MAIN << "Migrating project file" << m_projecturl << "to version 3";
+
+	// (1) Every config group starting with "document-settings," or "view-settings," will be moved to the GUI config file
+	// (2) In every group named "item:..." the keys "column" and "line" are deleted
+	// (3) In every group named "item:..." the keys "open" and "order" are moved to a new group of the same name
+	//     in the GUI project file
+	// (4) In the "General" group the keys "lastDocument", "kile_livePreviewEnabled", "kile_livePreviewStatusUserSpecified",
+	//     "kile_livePreviewTool" are moved to the "General" group in the GUI project file
+
+	if(!ensurePrivateKileDirectoryExists(m_projecturl)) {
+	    return false;
+	}
+
+	KConfig projectGUIFile(getPathForGUISettingsProjectFile(m_projecturl), KConfig::SimpleConfig);
+
+	QStringList keysToMoveInItemGroups, keysToDeleteInItemGroups, keysToMoveInGeneralGroup;
+
+	keysToMoveInItemGroups
+		<< QStringLiteral("column")
+		<< QStringLiteral("line")
+		<< QStringLiteral("open")
+		<< QStringLiteral("order");
+
+	keysToDeleteInItemGroups
+		<< QStringLiteral("column")
+		<< QStringLiteral("line");
+
+	keysToMoveInGeneralGroup
+		<< QStringLiteral("lastDocument")
+		<< QStringLiteral("kile_livePreviewEnabled")
+		<< QStringLiteral("kile_livePreviewStatusUserSpecified")
+		<< QStringLiteral("kile_livePreviewTool");
+
+	const QStringList groups = m_config->groupList();
+	for(auto groupName : groups) {
+		if(!m_config->hasGroup(groupName)) { // 'groupName' might have been deleted
+			continue;                    // work around bug 384039
+		}
+
+		// these ones we move completely
+		if(groupName.startsWith(QLatin1String("document-settings,")) || groupName.startsWith(QLatin1String("view-settings,"))) {
+			KConfigGroup oldGroup(m_config, groupName);
+			KConfigGroup guiGroup(&projectGUIFile, groupName);
+			oldGroup.copyTo(&guiGroup);
+			m_config->deleteGroup(groupName);
+			continue;
+		}
+
+		if(groupName.startsWith(QLatin1String("item:"))) {
+			deleteConfigGroupKeys(m_config, groupName, keysToDeleteInItemGroups);
+			moveConfigGroupKeysAsStrings(m_config, &projectGUIFile, groupName, keysToMoveInItemGroups);
+		}
+		else if(groupName == QLatin1String("General")) {
+			moveConfigGroupKeysAsStrings(m_config, &projectGUIFile, groupName, keysToMoveInGeneralGroup);
+		}
+	}
+
+	if(!projectGUIFile.sync()) {
+		return false;
+	}
+
+	KConfigGroup configGroup = m_config->group("General");
+	configGroup.writeEntry("kileprversion", KILE_PROJECTFILE_VERSION);
+	configGroup.writeEntry("kileversion", kileFullVersion);
+
+	return m_config->sync();
+}
