@@ -1,6 +1,6 @@
 /***************************************************************************
   Copyright (C) 2003 by Jeroen Wijnhout (jeroen.wijnhout@kdemail.net)
-                2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+                2010-2014 by Michel Ludwig (michel.ludwig@kdemail.net)
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,8 +21,9 @@
 #include <QTimer>
 
 #include <KConfig>
-#include <KLocale>
-#include <KUrl>
+#include <KLocalizedString>
+#include <KShell>
+#include <QUrl>
 
 #include "kileconfig.h"
 #include "kiletool_enums.h"
@@ -37,15 +38,22 @@ namespace KileTool
 {
 	Base::Base(const QString &name, Manager *manager, bool prepare /* = true */) :
 		QObject(manager), // ensure that they are deleted whenever the tool manager gets deleted
-		m_launcher(NULL),
+		m_launcher(Q_NULLPTR),
 		m_quickie(false),
+		m_isPartOfLivePreview(false),
 		m_manager(manager),
 		m_name(name),
-		m_bPrepareToRun(prepare)
+		m_bPrepareToRun(prepare),
+		m_texInputs(KileConfig::teXPaths()),
+		m_bibInputs(KileConfig::bibInputPaths()),
+		m_bstInputs(KileConfig::bstInputPaths()),
+		m_childToolSpawned(false),
+		m_toolResult(-1)
 	{
-		m_manager->initTool(this);
-		
-		m_flags = NeedTargetDirExec | NeedTargetDirWrite | NeedActiveDoc | NeedMasterDoc | NoUntitledDoc | NeedSourceExists | NeedSourceRead;
+		// WARNING: 'NeedSaveAll' is currently needed to indicate to the tool manager that parsing has to be finished
+		//          before it launches this tool! This is important to ensure that the right master document is used
+		//          in the case of projects, for example.
+		m_flags = NeedTargetDirExec | NeedTargetDirWrite | NeedActiveDoc | NeedMasterDoc | NoUntitledDoc | NeedSourceExists | NeedSourceRead | NeedSaveAll;
 
 		setMsg(NeedTargetDirExec, ki18n("Could not change to the folder %1."));
 		setMsg(NeedTargetDirWrite, ki18n("The folder %1 is not writable, therefore %2 will not be able to save its results."));
@@ -62,7 +70,8 @@ namespace KileTool
 
 	Base::~Base()
 	{
-		KILE_DEBUG() << "DELETING TOOL: " << name() << this;
+		KILE_DEBUG_MAIN << "DELETING TOOL: " << name() << this;
+		emit(aboutToBeDestroyed(this));
 		delete m_launcher;
 	}
 
@@ -79,40 +88,49 @@ namespace KileTool
 
 		return src;
 	}
-	
+
 	void Base::setMsg(long n, const KLocalizedString& msg)
 	{
 		m_messages[n] = msg;
 	}
 
-	void Base::translate(QString &str)
+	void Base::translate(QString &str, bool quoteForShell)
 	{
 		QHashIterator<QString,QString> it(paramDict());
 		while(it.hasNext()) {
 			it.next();
-			str.replace(it.key(), it.value());
+			QString value;
+			// the file names in %AFL are quoted already
+			if(quoteForShell && it.key() != "%AFL") {
+				value = KShell::quoteArg(it.value());
+			}
+			else {
+				value = it.value();
+			}
+			str.replace(it.key(), value);
 		}
-		//Windows doesn't like single quotes on command line '*.tex'
-		#ifdef Q_WS_WIN
-			str.replace('\'', '\"');
-		#endif 
 	}
 
-	void Base::prepareToRun(const QString &cfg)
+	void Base::removeFlag(uint flag)
 	{
-		KILE_DEBUG() << "==Base::prepareToRun()=======";
-		
-		m_bPrepared = true;		
-		m_nPreparationResult = Running;
+		m_flags &= ~flag;
+	}
+
+
+	bool Base::requestSaveAll()
+	{
+		return (flags() & NeedSaveAll);
+	}
+
+	void Base::setEntry(const QString& key, const QString& value)
+	{
+		m_entryMap[key] = value;
+	}
+
+	void Base::prepareToRun()
+	{
+		KILE_DEBUG_MAIN << "==Base::prepareToRun()=======";
 
-		//configure me
-		if (!configure(cfg))
-		{
-			m_nPreparationResult = ConfigureFailed;
-			m_bPrepared = false;
-			return;
-		}
-		
 		//install a launcher
 		if (!installLauncher())
 		{
@@ -120,21 +138,21 @@ namespace KileTool
 			m_bPrepared = false;
 			return;
 		}
-		
+
 		if (!determineSource())
 		{
 			m_nPreparationResult = NoValidSource;
 			m_bPrepared = false;
 			return;
 		}
-			
+
 		if (!determineTarget())
 		{
 			m_nPreparationResult = NoValidTarget;
 			m_bPrepared = false;
 			return;
 		}
-			
+
 		if ( m_launcher == 0 )
 		{
 			m_nPreparationResult = NoLauncherInstalled;
@@ -142,53 +160,66 @@ namespace KileTool
 			return;
 		}
 
-		m_launcher->setWorkingDirectory(workingDir());
+		if(!workingDir().isEmpty()) {
+			m_launcher->setWorkingDirectory(workingDir());
+		}
+		else {
+			m_launcher->setWorkingDirectory(baseDir());
+		}
 
 		//fill in the dictionary
 		addDict("%options", m_options);
 
 		m_resolution = KileConfig::dvipngResolution() ;
 		addDict("%res",m_resolution);
+
+		m_bPrepared = true;
+		m_nPreparationResult = Running;
 	}
 
 	int Base::run()
 	{
-		KILE_DEBUG() << "==KileTool::Base::run()=================";
-	
+		KILE_DEBUG_MAIN << "==KileTool::Base::run()=================";
+
 		if(m_nPreparationResult != 0) {
+			emit(failedToRun(this, m_nPreparationResult));
 			return m_nPreparationResult;
 		}
 
 		if(!checkSource()) {
+			emit(failedToRun(this, NoValidSource));
 			return NoValidSource;
 		}
 
 		if(!checkTarget()) {
+			emit(failedToRun(this, TargetHasWrongPermissions));
 			return TargetHasWrongPermissions;
 		}
 
 		if (!checkPrereqs()) {
+			emit(failedToRun(this, NoValidPrereqs));
 			return NoValidPrereqs;
 		}
 
-		//everything ok so far
-		emit(requestSaveAll(false, true));
 		emit(start(this));
-		
+
 		if (!m_launcher || !m_launcher->launch()) {
-			KILE_DEBUG() << "\tlaunching failed";
+			KILE_DEBUG_MAIN << "\tlaunching failed";
 			if(!m_launcher) {
+				emit(failedToRun(this, CouldNotLaunch));
 				return CouldNotLaunch;
 			}
 			if(!m_launcher->selfCheck()) {
+				emit(failedToRun(this, SelfCheckFailed));
 				return SelfCheckFailed;
 			}
 			else {
+				emit(failedToRun(this, CouldNotLaunch));
 				return CouldNotLaunch;
 			}
 		}
 
-		KILE_DEBUG() << "\trunning...";
+		KILE_DEBUG_MAIN << "\trunning...";
 
 		return Running;
 
@@ -198,6 +229,11 @@ namespace KileTool
 	{
 		QString src = source();
 
+		// check whether the source has been set already
+		if(!src.isEmpty()) {
+			return true;
+		}
+
 		//the basedir is determined from the current compile target
 		//determined by getCompileName()
 		if(src.isEmpty()) {
@@ -207,21 +243,20 @@ namespace KileTool
 
 		return true;
 	}
-	
+
 	bool Base::checkSource()
 	{
 		//FIXME deal with tools that do not need a source or target (yes they exist)
 		//Is there an active document? Only check if the source file is not explicitly set.
-		if((m_source.isEmpty()) && (m_manager->info()->activeTextDocument() == NULL)) {
+		if((m_source.isEmpty()) && (m_manager->info()->activeTextDocument() == Q_NULLPTR)) {
 			sendMessage(Error, msg(NeedActiveDoc).subs(name()).toString());
 			return false;
 		}
 
-		if(m_source.isEmpty() && m_manager->info()->activeTextDocument() != NULL) {
+		if(m_source.isEmpty() && m_manager->info()->activeTextDocument() != Q_NULLPTR) {
 			if(m_manager->info()->activeTextDocument()->url().isEmpty()
 			   && (flags() & NoUntitledDoc)) {
 				sendMessage(Error, msg(NoUntitledDoc).toString());
-				emit(requestSaveAll());
 				return false;
 			}
 			else {
@@ -247,46 +282,93 @@ namespace KileTool
 		return true;
 	}
 
-	void Base::setSource(const QString &source)
+	void Base::runChildNext(Base *tool, bool block /*= false*/)
 	{
-		m_from = readEntry("from");
+		m_childToolSpawned = true;
+		if(isPartOfLivePreview()) {
+			tool->setPartOfLivePreview();
+		}
+		manager()->runChildNext(this, tool, block);
+	}
 
+	void Base::setSource(const QString &source, const QString& workingDir)
+	{
 		QFileInfo info(source);
-		
-		if(!m_from.isEmpty()) {
+
+		if(!from().isEmpty()) {
 			QString src = source;
-			if((m_from.length() > 0) && (info.suffix().length() > 0)) {
-				src.replace(QRegExp(info.suffix() + '$'), m_from);
+			if(info.suffix().length() > 0) {
+				src.replace(QRegExp(info.suffix() + '$'), from());
 			}
  			info.setFile(src);
 		}
 
+		if(!workingDir.isEmpty()) {
+			setWorkingDir(workingDir);
+		}
+
 		m_basedir = info.absolutePath();
 		m_source = info.fileName();
 		m_S = info.completeBaseName();
-		
+
 		addDict("%dir_base", m_basedir);
 		addDict("%source", m_source);
 		addDict("%S",m_S);
-		
-		KILE_DEBUG() << "===KileTool::Base::setSource()==============";
-		KILE_DEBUG() << "using " << source;
-		KILE_DEBUG() << "source="<<m_source;
-		KILE_DEBUG() << "S=" << m_S;
-		KILE_DEBUG() << "basedir=" << m_basedir;
+
+		KILE_DEBUG_MAIN << "===KileTool::Base::setSource()==============";
+		KILE_DEBUG_MAIN << "using " << source;
+		KILE_DEBUG_MAIN << "source="<<m_source;
+		KILE_DEBUG_MAIN << "S=" << m_S;
+		KILE_DEBUG_MAIN << "basedir=" << m_basedir;
+		KILE_DEBUG_MAIN << "workingDir=" << m_workingDir;
 	}
-	
+
+	void Base::setTeXInputPaths(const QString& s)
+	{
+		m_texInputs = s;
+	}
+
+	QString Base::teXInputPaths() const
+	{
+		return m_texInputs;
+	}
+
+	void Base::setBibInputPaths(const QString& s)
+	{
+		m_bibInputs = s;
+	}
+
+	QString Base::bibInputPaths() const
+	{
+		return m_bibInputs;
+	}
+
+	void Base::setBstInputPaths(const QString& s)
+	{
+		m_bstInputs = s;
+	}
+
+	QString Base::bstInputPaths() const
+	{
+		return m_bstInputs;
+	}
+
+	void Base::copyPaths(Base* tool)
+	{
+		setTeXInputPaths(tool->teXInputPaths());
+		setBibInputPaths(tool->bibInputPaths());
+		setBstInputPaths(tool->bstInputPaths());
+	}
+
 	bool Base::determineTarget()
 	{
 		QFileInfo info(source());
 
-		m_to = readEntry("to");
-		
 		//if the target is not set previously, use the source filename
 		if(m_target.isEmpty()) {
 			//test for explicit override
 			if (!readEntry("target").isEmpty()) {
-				KILE_DEBUG() << "USING target SETTING";
+				KILE_DEBUG_MAIN << "USING target SETTING";
 				m_target = readEntry("target");
 			}
 			else if ( to().length() > 0) {
@@ -301,18 +383,27 @@ namespace KileTool
 			m_relativedir = readEntry("relDir");
 		}
 
-		KUrl url = KUrl::fromPathOrUrl(m_basedir);
-		url.addPath(m_relativedir);
-		url.cleanPath();
+		QUrl url;
+		if(!m_targetdir.isEmpty()) {
+			url = QUrl::fromLocalFile(m_targetdir);
+		}
+		else if(!m_workingDir.isEmpty()) {
+			url = QUrl::fromLocalFile(m_workingDir);
+		}
+		else {
+			url = QUrl::fromLocalFile(m_basedir);
+		}
+		url = url.adjusted(QUrl::StripTrailingSlash);
+		url.setPath(QDir::cleanPath(url.path() + '/' + m_relativedir));
 		m_targetdir = url.toLocalFile();
-		
+
 		setTarget(m_target);
-		setTargetDir(m_targetdir);		
-		
-		KILE_DEBUG() << "==KileTool::Base::determineTarget()=========";
-		KILE_DEBUG() << "\tm_targetdir=" << m_targetdir;
-		KILE_DEBUG() << "\tm_target=" << m_target;
-		
+		setTargetDir(m_targetdir);
+
+		KILE_DEBUG_MAIN << "==KileTool::Base::determineTarget()=========";
+		KILE_DEBUG_MAIN << "\tm_targetdir=" << m_targetdir;
+		KILE_DEBUG_MAIN << "\tm_target=" << m_target;
+
 		return true;
 	}
 
@@ -320,7 +411,7 @@ namespace KileTool
 	{
 		//check if the target directory is accessible
 		QFileInfo info(m_targetdir);
-		
+
 		if((flags() & NeedTargetDirExec ) && (!info.isExecutable())) {
 			sendMessage(Error, msg(NeedTargetDirExec).subs(m_targetdir).toString());
 			return false;
@@ -345,13 +436,13 @@ namespace KileTool
 
 		return true;
 	}
-	
+
 	void Base::setTarget(const QString &target)
 	{
 		m_target = target;
 		addDict("%target", m_target);
 	}
-	
+
 	void Base::setTargetDir(const QString &target)
 	{
 		m_targetdir = target;
@@ -364,47 +455,62 @@ namespace KileTool
 		setTarget(fi.fileName());
 		setTargetDir(fi.absolutePath());
 	}
-	
+
 	bool Base::checkPrereqs()
 	{
 		return true;
 	}
 
-	bool Base::configure(const QString &cfg)
-	{
-		return m_manager->configure(this, cfg);
-	}
-	
 	void Base::stop()
 	{
-		if (m_launcher)
+		if (m_launcher) {
 			m_launcher->kill();
+		}
 
-		//emit(done(this, Aborted));
+		emit(done(this, Aborted, m_childToolSpawned));
 	}
 
 	bool Base::finish(int result)
 	{
-		KILE_DEBUG() << "==KileTool::Base::finish()==============";
+		KILE_DEBUG_MAIN << "==KileTool::Base::finish()==============";
 		if (sender())
 		{
-			KILE_DEBUG() << "\tcalled by " << sender()->objectName() << " " << sender()->metaObject()->className();
+			KILE_DEBUG_MAIN << "\tcalled by " << sender()->objectName() << " " << sender()->metaObject()->className();
 		}
-		
+
 		if ( result == Aborted )
 			sendMessage(Error, "Aborted");
-		
+
 		if ( result == Success )
 			sendMessage(Info,"Done!");
 
-		KILE_DEBUG() << "\temitting done(Base*, int) " << name();
-		emit(done(this, result));
-	
+		KILE_DEBUG_MAIN << "\temitting done(KileTool::Base*, int) " << name();
+		emit(done(this, result, m_childToolSpawned));
+
 		//we will only get here if the done() signal is not connected to the manager (who will destroy this object)
-		if (result == Success)
+		if (result == Success) {
 			return true;
-		else
+		}
+		else {
 			return false;
+		}
+	}
+
+	void Base::installLaTeXOutputParserResult(int nErrors, int nWarnings, int nBadBoxes, const LatexOutputInfoArray& outputList,
+                                                                                             const QString& logFile)
+	{
+		m_nErrors = nErrors;
+		m_nWarnings = nWarnings;
+		m_nBadBoxes = nBadBoxes;
+		m_latexOutputInfoList = outputList;
+		m_logFile = logFile;
+
+		latexOutputParserResultInstalled();
+	}
+
+	void Base::latexOutputParserResultInstalled()
+	{
+		finish(Success);
 	}
 
 	void Base::installLauncher(Launcher *lr)
@@ -415,7 +521,7 @@ namespace KileTool
 		m_launcher = lr;
 		//lr->setParamDict(paramDict());
 		lr->setTool(this);
-		
+
 		connect(lr, SIGNAL(message(int, const QString &)), this, SLOT(sendMessage(int, const QString &)));
 		connect(lr, SIGNAL(output(const QString &)), this, SLOT(filterOutput(const QString &)));
 		connect(lr, SIGNAL(done(int)), this, SLOT(finish(int)));
@@ -423,42 +529,39 @@ namespace KileTool
 
 	bool Base::installLauncher()
 	{
-		if (m_launcher)
+		if (m_launcher) {
 			return true;
+		}
 
 		QString type = readEntry("type");
-		KILE_DEBUG() << "installing launcher of type " << type;
-		Launcher *lr = 0;
+		KILE_DEBUG_MAIN << "installing launcher of type " << type;
+		Launcher *lr = Q_NULLPTR;
 
-		if ( type == "Process" )
-		{
+		if ( type == "Process" ) {
 			lr = new ProcessLauncher();
 		}
-		else if ( type == "Konsole" )
-		{
+		else if ( type == "Konsole" ) {
 			lr = new KonsoleLauncher();
 		}
-		else if ( type == "Part" )
-		{	
-			lr = new PartLauncher();
+		else if ( type == "DocumentViewer" ) {
+			lr = new DocumentViewerLauncher();
 		}
-		else if ( type == "DocPart" )
-		{
-			lr = new DocPartLauncher();
-		}
-		
-		if (lr) 
-		{
+
+		if (lr) {
 			installLauncher(lr);
 			return true;
 		}
-		else
-		{
-			m_launcher = 0;
+		else {
+			m_launcher = Q_NULLPTR;
 			return false;
 		}
 	}
-	
+
+	void Base::setupAsChildTool(KileTool::Base *child)
+	{
+		Q_UNUSED(child);
+	}
+
 	void Base::sendMessage(int type, const QString &msg)
 	{
 		emit(message(type, msg, name()));
@@ -484,34 +587,34 @@ namespace KileTool
 
 	bool Base::needsUpdate(const QString &target, const QString &source)
 	{
-		KILE_DEBUG() << "==Base::needsUpdate(" << target << "," << source;
+		KILE_DEBUG_MAIN << "==Base::needsUpdate(" << target << "," << source;
 		QFileInfo targetinfo(target);
 		QFileInfo sourceinfo(source);
 		QDateTime currDateTime = QDateTime::currentDateTime();
 
 		if(!(sourceinfo.exists() && sourceinfo.isReadable())) {
-			KILE_DEBUG() << "\treturning false: source does not exist";
+			KILE_DEBUG_MAIN << "\treturning false: source does not exist";
 			return false;
 		}
 
 		if(!targetinfo.exists()) {
-			KILE_DEBUG() << "\treturning true: target does not exist";
+			KILE_DEBUG_MAIN << "\treturning true: target does not exist";
 			return true;
 		}
 
-		KILE_DEBUG() << "\ttarget: " << targetinfo.lastModified().toString();
-		KILE_DEBUG() << "\tsource: " << sourceinfo.lastModified().toString();
-		
+		KILE_DEBUG_MAIN << "\ttarget: " << targetinfo.lastModified().toString();
+		KILE_DEBUG_MAIN << "\tsource: " << sourceinfo.lastModified().toString();
+
 		if(targetinfo.lastModified() > currDateTime) {
-			KILE_DEBUG() << "targetinfo.lastModifiedTime() is in the future";
+			KILE_DEBUG_MAIN << "targetinfo.lastModifiedTime() is in the future";
 			return false;
 		}
 		else if(sourceinfo.lastModified() > currDateTime) {
-			KILE_DEBUG() << "sourceinfo.lastModifiedTime() is in the future";
+			KILE_DEBUG_MAIN << "sourceinfo.lastModifiedTime() is in the future";
 			return false;
 		}
-		
-		KILE_DEBUG() << "\treturning " << (targetinfo.lastModified() < sourceinfo.lastModified());
+
+		KILE_DEBUG_MAIN << "\treturning " << (targetinfo.lastModified() < sourceinfo.lastModified());
 		return targetinfo.lastModified() < sourceinfo.lastModified();
 	}
 
@@ -523,14 +626,16 @@ namespace KileTool
 
 	Compile::~Compile()
 	{}
-	
+
 	bool Compile::checkSource()
 	{
 		if ( !Base::checkSource() ) return false;
 
 		bool isRoot = true;
 		KileDocument::TextInfo *docinfo = manager()->info()->docManager()->textInfoFor(source());
-		if (docinfo) isRoot = (readEntry("checkForRoot") == "yes") ? docinfo->isLaTeXRoot() : true;
+		if (docinfo) {
+			isRoot = (readEntry("checkForRoot") == "yes") ? docinfo->isLaTeXRoot() : true;
+		}
 
 		if (!isRoot)
 		{
@@ -539,13 +644,13 @@ namespace KileTool
 
 		return true;
 	}
-	
+
 	View::View(const QString &name, Manager * manager, bool prepare /*= true*/)
 		: Base(name, manager, prepare)
 	{
 		setFlags(NeedTargetDirExec | NeedTargetExists | NeedTargetRead);
-		
-		KILE_DEBUG() << "View: flag " << (flags() & NeedTargetExists);
+
+		KILE_DEBUG_MAIN << "View: flag " << (flags() & NeedTargetExists);
 		setMsg(NeedTargetExists, ki18n("The file %1/%2 does not exist; did you compile the source file?"));
 	}
 
@@ -559,7 +664,7 @@ namespace KileTool
 	{
 		setFlags( NeedTargetDirExec | NeedTargetDirWrite );
 	}
-	
+
 	Archive::~Archive()
 	{}
 
@@ -578,9 +683,10 @@ namespace KileTool
 		}
 	}
 
-	void Archive::setSource(const QString &source)
-	{	
-		KUrl url = KUrl::fromPathOrUrl(source);
+	void Archive::setSource(const QString &source, const QString& workingDir)
+	{
+		Q_UNUSED(workingDir);
+		QUrl url = QUrl::fromLocalFile(source);
 		m_project = manager()->info()->docManager()->projectFor(url);
 		if ( !m_project )
 			m_project = manager()->info()->docManager()->activeProject();
@@ -595,23 +701,23 @@ namespace KileTool
 		manager()->info()->docManager()->projectSave(m_project);
 		Base::setSource(m_project->url().toLocalFile());
 		m_fileList = m_project->archiveFileList();
-		
+
 		addDict("%AFL", m_fileList);
-		
-		KILE_DEBUG() << "===KileTool::Archive::setSource("<< source << ")==============";
-		KILE_DEBUG() << "m_fileList="<<m_fileList<<endl;
+
+		KILE_DEBUG_MAIN << "===KileTool::Archive::setSource("<< source << ")==============";
+		KILE_DEBUG_MAIN << "m_fileList="<<m_fileList<<endl;
 	}
-	
+
 	Convert::Convert(const QString &name, Manager * manager, bool prepare /*= true*/)
 		: Base(name, manager,prepare)
 	{
 		setFlags( flags() | NeedTargetDirExec | NeedTargetDirWrite );
 	}
-	
+
 	Convert::~Convert()
 	{
 	}
-	
+
 	bool Convert::determineSource()
 	{
 		bool  br = Base::determineSource();
@@ -619,48 +725,124 @@ namespace KileTool
 		return br;
 	}
 
-	Sequence::Sequence(const QString &name, Manager * manager, bool prepare /*= true*/) : 
-		Base(name, manager, prepare)
+	Sequence::Sequence(const QString &name, Manager *manager, bool prepare /*= true*/)
+	 : Base(name, manager, prepare), m_latexOutputHandler(Q_NULLPTR)
 	{
 	}
 
+	Sequence::~Sequence() {
+		qDeleteAll(m_tools);
+	}
+
+	LaTeXOutputHandler* Sequence::latexOutputHandler()
+	{
+		return m_latexOutputHandler;
+	}
+
+	void Sequence::setLaTeXOutputHandler(LaTeXOutputHandler *h)
+	{
+		m_latexOutputHandler = h;
+	}
+
+	bool Sequence::determineSource()
+	{
+		QString src = source();
+
+		// check whether the source has been set already
+		if(!src.isEmpty()) {
+			return true;
+		}
+
+		// the basedir is determined from the current compile target,
+		// determined by getCompileName()
+		LaTeXOutputHandler *h = Q_NULLPTR;
+		src = m_ki->getCompileName(false, &h);
+
+		setSource(src);
+		setLaTeXOutputHandler(h);
+
+		return true;
+	}
+
+	bool Sequence::requestSaveAll()
+	{
+		// if one of the tools in the sequence requests save-all, then we also
+		// request it
+		for(QLinkedList<Base*>::iterator i = m_tools.begin(); i != m_tools.end(); ++i) {
+			if((*i)->requestSaveAll()) {
+				return true;
+			}
+		}
+
+		return false;
+	}
+
+	void Sequence::setupSequenceTools()
+	{
+		QStringList toolNameList = readEntry("sequence").split(',');
+		QString tl, cfg;
+		Base *tool;
+		for(QStringList::iterator i = toolNameList.begin(); i != toolNameList.end(); ++i) {
+			QString fullToolSpec = (*i).trimmed();
+			extract(fullToolSpec, tl, cfg);
+
+			tool = manager()->createTool(tl, cfg, false); // create tool with delayed preparation
+			if (tool) {
+				KILE_DEBUG_MAIN << "===tool created with name " << tool->name();
+				if(!(manager()->info()->watchFile() && tool->isViewer())) { // FIXME: why this?
+					KILE_DEBUG_MAIN << "\tqueueing " << tl << "(" << cfg << ") with " << source();
+					m_tools << tool;
+				}
+				else {
+					delete tool;
+				}
+			}
+			else {
+				m_unknownToolSpec = fullToolSpec;
+				qDeleteAll(m_tools);
+				m_tools.clear();
+				return;
+			}
+		}
+	}
+
 	int Sequence::run()
 	{
-		KILE_DEBUG() << "==KileTool::Sequence::run()==================";
+		KILE_DEBUG_MAIN << "==KileTool::Sequence::run()==================";
 
-		configure();
 		determineSource();
 		if (!checkSource()) {
+			// tools in 'm_tools' will be deleted in the destructor
 			return NoValidSource;
 		}
 
-		QStringList tools = readEntry("sequence").split(',');
-		QString tl, cfg;
-		Base *tool;
-		for(int i=0; i < tools.count(); ++i) {
-			tools[i] = tools[i].trimmed();
-			extract(tools[i], tl, cfg);
-
-			tool = manager()->factory()->create(tl, false); //create tool with delayed preparation
-			if (tool) {
-				KILE_DEBUG() << "===tool created with name " << tool->name();
-				if(!(manager()->info()->watchFile() && tool->isViewer())) {
-					KILE_DEBUG() << "\tqueueing " << tl << "(" << cfg << ") with " << source();
-					tool->setSource(source());
-					manager()->run(tool, cfg);
-				}
-			}
-			else {
-				sendMessage(Error, i18n("Unknown tool %1.", tools[i]));
-				emit(done(this, Failed));
-				return ConfigureFailed;
-			}
+		if(!m_unknownToolSpec.isEmpty()) {
+			// 'm_tools' is empty
+			sendMessage(Error, i18n("Unknown tool %1.", m_unknownToolSpec));
+			emit(done(this, Failed, m_childToolSpawned));
+			return ConfigureFailed;
 		}
 
-		emit(done(this, Silent));
+		for(QLinkedList<Base*>::iterator i = m_tools.begin(); i != m_tools.end(); ++i) {
+			Base *tool = *i;
+			tool->setSource(source());
+
+			// if we are running a 'LaTeX' tool here, we still have to set the
+			// appropriate LaTeXOutputHandler
+			{
+				LaTeX *latex = dynamic_cast<LaTeX*>(tool);
+				if(latex && m_latexOutputHandler) {
+					latex->setLaTeXOutputHandler(m_latexOutputHandler);
+				}
+			}
+
+			manager()->run(tool);
+		}
+
+		m_tools.clear(); // the tools will be deleted by the tool manager from now on
+		emit(done(this, Silent, m_childToolSpawned));
 
 		return Success;
 	}
 }
 
-#include "kiletool.moc"
