@@ -16,17 +16,19 @@
 #include "widgets/projectview.h"
 
 #include <QHeaderView>
+#include <QIcon>
+#include <KLocalizedString>
 #include <QList>
+#include <QMenu>
+#include <QMimeData>
+#include <QMimeDatabase>
+#include <QMimeType>
 #include <QSignalMapper>
+#include <QUrl>
 
 #include <KActionMenu>
-#include <KIcon>
-#include <KLocale>
-#include <KMenu>
-#include <KMimeType>
 #include <KMimeTypeTrader>
 #include <KRun>
-#include <KUrl>
 
 #include "kileinfo.h"
 #include "documentinfo.h"
@@ -45,44 +47,44 @@ namespace KileWidget {
  * ProjectViewItem
  */
 ProjectViewItem::ProjectViewItem(QTreeWidget *parent, KileProjectItem *item, bool ar)
-: QTreeWidgetItem(parent, QStringList(item->url().fileName())), m_docinfo(NULL), m_folder(-1), m_projectItem(item)
+: QTreeWidgetItem(parent, QStringList(item->url().fileName())), m_docinfo(Q_NULLPTR), m_folder(-1), m_projectItem(item)
 {
 	setArchiveState(ar);
 }
 
 ProjectViewItem::ProjectViewItem(QTreeWidget *parent, QTreeWidgetItem *after, KileProjectItem *item, bool ar)
-: QTreeWidgetItem(parent, after), m_docinfo(NULL), m_folder(-1), m_projectItem(item)
+: QTreeWidgetItem(parent, after), m_docinfo(Q_NULLPTR), m_folder(-1), m_projectItem(item)
 {
 	setText(0, item->url().fileName());
 	setArchiveState(ar);
 }
 
 ProjectViewItem::ProjectViewItem(QTreeWidgetItem *parent, KileProjectItem *item, bool ar)
-: QTreeWidgetItem(parent, QStringList(item->url().fileName())), m_docinfo(NULL), m_folder(-1), m_projectItem(item)
+: QTreeWidgetItem(parent, QStringList(item->url().fileName())), m_docinfo(Q_NULLPTR), m_folder(-1), m_projectItem(item)
 {
 	setArchiveState(ar);
 }
 
 //use this to create folders
 ProjectViewItem::ProjectViewItem(QTreeWidgetItem *parent, const QString& name)
-: QTreeWidgetItem(parent, QStringList(name)), m_docinfo(NULL), m_folder(-1), m_projectItem(NULL)
+: QTreeWidgetItem(parent, QStringList(name)), m_docinfo(Q_NULLPTR), m_folder(-1), m_projectItem(Q_NULLPTR)
 {
 }
 
 //use this to create non-project files
 ProjectViewItem::ProjectViewItem(QTreeWidget *parent, const QString& name)
-: QTreeWidgetItem(parent, QStringList(name)), m_docinfo(NULL), m_folder(-1), m_projectItem(NULL)
+: QTreeWidgetItem(parent, QStringList(name)), m_docinfo(Q_NULLPTR), m_folder(-1), m_projectItem(Q_NULLPTR)
 {
 }
 
 ProjectViewItem::ProjectViewItem(QTreeWidget *parent, const KileProject *project)
-: QTreeWidgetItem(parent, QStringList(project->name())), m_docinfo(NULL), m_folder(-1), m_projectItem(NULL)
+: QTreeWidgetItem(parent, QStringList(project->name())), m_docinfo(Q_NULLPTR), m_folder(-1), m_projectItem(Q_NULLPTR)
 {
 }
 
 ProjectViewItem::~ProjectViewItem()
 {
-	KILE_DEBUG() << "DELETING PROJVIEWITEM " << m_url.fileName();
+	KILE_DEBUG_MAIN << "DELETING PROJVIEWITEM " << m_url.fileName();
 }
 
 KileProjectItem* ProjectViewItem::projectItem()
@@ -120,7 +122,7 @@ KileType::ProjectView ProjectViewItem::type() const
 	return m_type;
 }
 
-void ProjectViewItem::urlChanged(const KUrl &url)
+void ProjectViewItem::urlChanged(const QUrl &url)
 {
 	// don't allow empty URLs
 	if(!url.isEmpty()) {
@@ -136,24 +138,27 @@ void ProjectViewItem::nameChanged(const QString & name)
 
 void ProjectViewItem::isrootChanged(bool isroot)
 {
-	KILE_DEBUG() << "SLOT isrootChanged " << text(0) << " to " << isroot;
+	KILE_DEBUG_MAIN << "SLOT isrootChanged " << text(0) << " to " << isroot;
 	if(isroot) {
-		setIcon(0, KIcon("masteritem"));
+		setIcon(0, QIcon::fromTheme("masteritem"));
 	}
 	else {
-		if(text(0).right(7) == ".kilepr") {
-			setIcon(0, KIcon("kile"));
+		if(m_projectItem && m_projectItem->type() == KileProjectItem::ProjectFile) {
+			setIcon(0, QIcon::fromTheme("kile"));
+		}
+		else if(m_projectItem && m_projectItem->type() == KileProjectItem::Bibliography) {
+			setIcon(0, QIcon::fromTheme("viewbib"));
 		}
 		else if(type() == KileType::ProjectItem) {
-			setIcon(0, KIcon("projectitem"));
+			setIcon(0, QIcon::fromTheme("projectitem"));
 		}
 		else {
-			setIcon(0, KIcon("file"));
+			setIcon(0, QIcon::fromTheme("file"));
 		}
 	}
 }
 
-void ProjectViewItem::slotURLChanged(KileDocument::Info*, const KUrl & url)
+void ProjectViewItem::slotURLChanged(KileDocument::Info*, const QUrl &url)
 {
 	urlChanged(url);
 }
@@ -162,16 +167,34 @@ bool ProjectViewItem::operator<(const QTreeWidgetItem& other) const
 {
 	try {
 		const ProjectViewItem& otherItem = dynamic_cast<const ProjectViewItem&>(other);
-	
-		// sort:
-		//  - first:  container items in fixed order (projectfile, packages, images, other)
-		//  - second: root items without container (sorted in ascending order)
+
+		// order in the tree:
+		// - first, root items without container (sorted in ascending order)
+		// - then, container items in fixed order (images, packages, other, projectfile)
 		if(otherItem.type() == KileType::Folder) {
-			if(otherItem.type() != KileType::Folder) {
+			if(type() != KileType::Folder) {
 				return true;
 			}
 			else {
-				return (m_folder < otherItem.folder()) ? false : true;
+				// 'm_folder' is set to a type from 'KileProject::Type'
+				// we want: Image < Package < Other < ProjectFile
+				switch(m_folder) {
+				    case KileProjectItem::Image:
+				      return true;
+
+				    case KileProjectItem::Package:
+				      return (otherItem.m_folder == KileProjectItem::Image) ? false : true;
+
+				    case KileProjectItem::Other:
+				      return (otherItem.m_folder == KileProjectItem::Image
+				              || otherItem.m_folder == KileProjectItem::Package) ? false : true;
+
+				    case KileProjectItem::ProjectFile:
+				      return false;
+
+				    default: // dummy
+				      return false;
+				}
 			}
 		}
 		else if(type() == KileType::Folder) {
@@ -186,12 +209,12 @@ bool ProjectViewItem::operator<(const QTreeWidgetItem& other) const
 	}
 }
 
-void ProjectViewItem::setURL(const KUrl& url)
+void ProjectViewItem::setURL(const QUrl &url)
 {
 	m_url = url;
 }
 
-const KUrl& ProjectViewItem::url()
+const QUrl &ProjectViewItem::url()
 {
 	return m_url;
 }
@@ -224,7 +247,7 @@ ProjectView::ProjectView(QWidget *parent, KileInfo *ki) : QTreeWidget(parent), m
 
 	setFocusPolicy(Qt::ClickFocus);
 	header()->hide();
-	header()->setResizeMode(QHeaderView::ResizeToContents);
+	header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 	setRootIsDecorated(true);
 	setAllColumnsShowFocus(true);
 	setSelectionMode(QTreeWidget::SingleSelection);
@@ -251,12 +274,13 @@ void ProjectView::slotClicked(QTreeWidgetItem *item)
 			// don't open project configuration files (*.kilepr)
 			if(itm->url().toLocalFile().right(7) != ".kilepr") {
 				//determine mimeType and open file with preferred application
-				KMimeType::Ptr pMime = KMimeType::findByUrl(itm->url());
-				if(pMime->name().startsWith("text/")) {
+				QMimeDatabase db;
+				QMimeType pMime = db.mimeTypeForUrl(itm->url());
+				if(pMime.name().startsWith("text/")) {
 					emit(fileSelected(itm->url()));
 				}
 				else {
-					KRun::runUrl(itm->url(), pMime->name(), this);
+					KRun::runUrl(itm->url(), pMime.name(), this, KRun::RunFlags());
 				}
 			}
 		}
@@ -317,7 +341,7 @@ void ProjectView::slotProjectItem(int id)
 					emit(closeURL(item->url()));
 				break; //we can access "item" later as it isn't deleted
 				case KPV_ID_OPENWITH:
-					KRun::displayOpenWithDialog(item->url(), this);
+					KRun::displayOpenWithDialog(QList<QUrl>() << item->url(), this);
 				break;
 				default:
 				break;
@@ -366,10 +390,10 @@ void ProjectView::slotRun(int id)
 	}
 
 	if(id == 0) {
-		KRun::displayOpenWithDialog(itm->url(), this);
+		KRun::displayOpenWithDialog(QList<QUrl>() << itm->url(), this);
 	}
 	else {
-		KRun::run(*m_offerList[id-1], itm->url(), this);
+		KRun::runService(*m_offerList[id-1], QList<QUrl>() << itm->url(), this);
 	}
 
 	itm->setSelected(false);
@@ -377,12 +401,12 @@ void ProjectView::slotRun(int id)
 
 void ProjectView::makeTheConnection(ProjectViewItem *item, KileDocument::TextInfo *textInfo)
 {
-	KILE_DEBUG() << "\tmakeTheConnection " << item->text(0);
+	KILE_DEBUG_MAIN << "\tmakeTheConnection " << item->text(0);
 
 	if (item->type() == KileType::Project) {
 		KileProject *project = m_ki->docManager()->projectFor(item->url());
 		if (!project) {
-			kWarning() << "makeTheConnection COULD NOT FIND AN PROJECT OBJECT FOR " << item->url().toLocalFile();
+			qWarning() << "makeTheConnection COULD NOT FIND AN PROJECT OBJECT FOR " << item->url().toLocalFile();
 		}
 		else {
 			connect(project, SIGNAL(nameChanged(const QString &)), item, SLOT(nameChanged(const QString &)));
@@ -392,12 +416,12 @@ void ProjectView::makeTheConnection(ProjectViewItem *item, KileDocument::TextInf
 		if(!textInfo) {
 			textInfo = m_ki->docManager()->textInfoFor(item->url().toLocalFile());
 			if(!textInfo) {
-				KILE_DEBUG() << "\tmakeTheConnection COULD NOT FIND A DOCINFO";
+				KILE_DEBUG_MAIN << "\tmakeTheConnection COULD NOT FIND A DOCINFO";
 				return;
 			}
 		}
 		item->setInfo(textInfo);
-		connect(textInfo, SIGNAL(urlChanged(KileDocument::Info*, const KUrl&)),  item, SLOT(slotURLChanged(KileDocument::Info*, const KUrl&)));
+		connect(textInfo, SIGNAL(urlChanged(KileDocument::Info*, const QUrl&)),  item, SLOT(slotURLChanged(KileDocument::Info*, const QUrl&)));
 		connect(textInfo, SIGNAL(isrootChanged(bool)), item, SLOT(isrootChanged(bool)));
 		//set the pixmap
 		item->isrootChanged(textInfo->isLaTeXRoot());
@@ -409,8 +433,8 @@ ProjectViewItem* ProjectView::folder(const KileProjectItem *pi, ProjectViewItem
 	ProjectViewItem *parent = parentFor(pi, item);
 
 	if(!parent) {
-		kError() << "no parent for " << pi->url().toLocalFile();
-		return NULL;
+		qCritical() << "no parent for " << pi->url().toLocalFile();
+		return Q_NULLPTR;
 	}
 
 	// we have already found the parent folder
@@ -425,17 +449,20 @@ ProjectViewItem* ProjectView::folder(const KileProjectItem *pi, ProjectViewItem
 	QString foldername;
 	switch(pi->type()) {
 		case (KileProjectItem::ProjectFile):
-			foldername = i18n("projectfile");
+			foldername = i18n("Project File");
 		break;
 		case (KileProjectItem::Package):
-			foldername = i18n("packages");
+			foldername = i18n("Packages");
 		break;
 		case (KileProjectItem::Image):
-			foldername = i18n("images");
+			foldername = i18n("Images");
+		break;
+		case (KileProjectItem::Bibliography):
+			foldername = i18n("Bibliography");
 		break;
 		case (KileProjectItem::Other):
 		default :
-			foldername = i18n("other");
+			foldername = i18n("Other");
 		break;
 	}
 
@@ -455,7 +482,7 @@ ProjectViewItem* ProjectView::folder(const KileProjectItem *pi, ProjectViewItem
 	// if no folder was found, we must create a new one
 	if(!found) {
 		folder = new ProjectViewItem(parent, foldername);
-		KILE_DEBUG() << "new folder: parent=" << parent->url().url()
+		KILE_DEBUG_MAIN << "new folder: parent=" << parent->url().url()
 		             << ", foldername=" << foldername;
 
 		folder->setFolder(pi->type());
@@ -472,7 +499,7 @@ void ProjectView::add(const KileProject *project)
 	parent->setType(KileType::Project);
 	parent->setURL(project->url());
 	parent->setExpanded(true);
-	parent->setIcon(0, KIcon("relation"));
+	parent->setIcon(0, QIcon::fromTheme("relation"));
 	makeTheConnection(parent);
 
 	//ProjectViewItem *nonsrc = new ProjectViewItem(parent, i18n("non-source"));
@@ -483,9 +510,9 @@ void ProjectView::add(const KileProject *project)
 	++m_nProjects;
 }
 
-ProjectViewItem* ProjectView::projectViewItemFor(const KUrl& url)
+ProjectViewItem* ProjectView::projectViewItemFor(const QUrl &url)
 {
-	ProjectViewItem *item = NULL;
+	ProjectViewItem *item = Q_NULLPTR;
 
 	//find project view item
 	QTreeWidgetItemIterator it(this);
@@ -500,9 +527,9 @@ ProjectViewItem* ProjectView::projectViewItemFor(const KUrl& url)
 	return item;
 }
 
-ProjectViewItem* ProjectView::itemFor(const KUrl & url)
+ProjectViewItem* ProjectView::itemFor(const QUrl &url)
 {
-	ProjectViewItem *item = NULL;
+	ProjectViewItem *item = Q_NULLPTR;
 
 	QTreeWidgetItemIterator it(this);
 	while(*it) {
@@ -525,28 +552,28 @@ ProjectViewItem* ProjectView::parentFor(const KileProjectItem *projitem, Project
 	if (parpi) {
 		//find parent viewitem that has an URL parpi->url()
 		QTreeWidgetItemIterator it(projvi);
-		KILE_DEBUG() << "\tlooking for " << parpi->url().toLocalFile();
+		KILE_DEBUG_MAIN << "\tlooking for " << parpi->url().toLocalFile();
 		while(*it) {
 			vi = static_cast<ProjectViewItem*>(*it);
-			KILE_DEBUG() << "\t\t" << vi->url().toLocalFile();
+			KILE_DEBUG_MAIN << "\t\t" << vi->url().toLocalFile();
 			if (vi->url() == parpi->url()) {
 				parpvi = vi;
-				KILE_DEBUG() << "\t\tfound" <<endl;
+				KILE_DEBUG_MAIN << "\t\tfound" <<endl;
 				break;
 			}
 			++it;
 		}
 
-		KILE_DEBUG() << "\t\tnot found";
+		KILE_DEBUG_MAIN << "\t\tnot found";
 	}
 	else {
-		KILE_DEBUG() << "\tlooking for folder type " << projitem->type();
+		KILE_DEBUG_MAIN << "\tlooking for folder type " << projitem->type();
 		QTreeWidgetItemIterator it(projvi);
 		++it; // skip projvi
 		while(*it) {
 			ProjectViewItem *child = dynamic_cast<ProjectViewItem*>(*it);
 			if(child && (child->type() == KileType::Folder) && (child->folder() == projitem->type())) {
-				KILE_DEBUG() << "\t\tfound";
+				KILE_DEBUG_MAIN << "\t\tfound";
 				parpvi = child;
 				break;
 			}
@@ -557,9 +584,9 @@ ProjectViewItem* ProjectView::parentFor(const KileProjectItem *projitem, Project
 	return (!parpvi) ? projvi : parpvi;
 }
 
-ProjectViewItem* ProjectView::add(KileProjectItem *projitem, ProjectViewItem *projvi /* = NULL */)
+ProjectViewItem* ProjectView::add(KileProjectItem *projitem, ProjectViewItem *projvi /* = Q_NULLPTR */)
 {
-	KILE_DEBUG() << "\tprojectitem=" << projitem->path()
+	KILE_DEBUG_MAIN << "\tprojectitem=" << projitem->path()
 	             << " projvi=" << projvi;
 	const KileProject *project = projitem->project();
 
@@ -567,28 +594,35 @@ ProjectViewItem* ProjectView::add(KileProjectItem *projitem, ProjectViewItem *pr
 		projvi = projectViewItemFor(project->url());
 	}
 
-	KILE_DEBUG() << "\tparent projectviewitem " << projvi->url().fileName();
+	KILE_DEBUG_MAIN << "\tparent projectviewitem " << projvi->url().fileName();
 
-	ProjectViewItem *item = NULL, *parent = NULL;
+	ProjectViewItem *item = Q_NULLPTR, *parent = Q_NULLPTR;
 
 	switch (projitem->type()) {
 	case (KileProjectItem::Source):
 		item = new ProjectViewItem(projvi, projitem);
 		item->setType(KileType::ProjectItem);
-		item->setIcon(0, KIcon("projectitem"));
+		item->setIcon(0, QIcon::fromTheme("projectitem"));
 	break;
 	case (KileProjectItem::Package):
 		parent = folder(projitem, projvi);
 		item = new ProjectViewItem(parent, projitem);
 		item->setType(KileType::ProjectItem);
-		item->setIcon(0, KIcon("projectitem"));
+		item->setIcon(0, QIcon::fromTheme("projectitem"));
 	break;
-	case (KileProjectItem::ProjectFile):
 	default:
 		parent = folder(projitem, projvi);
 		item = new ProjectViewItem(parent, projitem);
 		item->setType(KileType::ProjectExtra);
-		item->setIcon(0, KIcon((projitem->type()==KileProjectItem::ProjectFile) ? "kile" : "file"));
+		if(projitem->type() == KileProjectItem::ProjectFile) {
+			item->setIcon(0, QIcon::fromTheme("kile"));
+		}
+		else if(projitem->type() == KileProjectItem::Bibliography) {
+			item->setIcon(0, QIcon::fromTheme("viewbib"));
+		}
+		else {
+			item->setIcon(0, QIcon::fromTheme("file"));
+		}
 	break;
 	}
 	
@@ -607,7 +641,7 @@ ProjectViewItem* ProjectView::add(KileProjectItem *projitem, ProjectViewItem *pr
 
 void ProjectView::addTree(KileProjectItem *projitem, ProjectViewItem *projvi)
 {
-	KILE_DEBUG() << "projitem=" << projitem
+	KILE_DEBUG_MAIN << "projitem=" << projitem
 	             << "projvi=" << projvi;
 	ProjectViewItem * item = add(projitem, projvi);
 
@@ -622,12 +656,12 @@ void ProjectView::addTree(KileProjectItem *projitem, ProjectViewItem *projvi)
 
 void ProjectView::refreshProjectTree(const KileProject *project)
 {
-	KILE_DEBUG() << "\tProjectView::refreshProjectTree(" << project->name() << ")";
+	KILE_DEBUG_MAIN << "\tProjectView::refreshProjectTree(" << project->name() << ")";
 	ProjectViewItem *parent= projectViewItemFor(project->url());
 
 	//clean the tree
 	if(parent) {
-		KILE_DEBUG() << "\tusing parent projectviewitem " << parent->url().fileName();
+		KILE_DEBUG_MAIN << "\tusing parent projectviewitem " << parent->url().fileName();
 		parent->setFolder(-1);
 		QList<QTreeWidgetItem*> children = parent->takeChildren();
 		for(QList<QTreeWidgetItem*>::iterator it = children.begin();
@@ -655,9 +689,9 @@ void ProjectView::refreshProjectTree(const KileProject *project)
 	parent->setExpanded(expanded);
 }
 
-void ProjectView::add(const KUrl& url)
+void ProjectView::add(const QUrl &url)
 {
-	KILE_DEBUG() << "\tProjectView::adding item " << url.toLocalFile();
+	KILE_DEBUG_MAIN << "\tProjectView::adding item " << url.toLocalFile();
 	//check if file is already present
 	QTreeWidgetItemIterator it(this);
 	ProjectViewItem *item;
@@ -681,7 +715,7 @@ void ProjectView::remove(const KileProject *project)
 		ProjectViewItem *item = static_cast<ProjectViewItem*>(topLevelItem(i));
 
 		if(item->url() == project->url()) {
-			item->setParent(NULL);
+			item->setParent(Q_NULLPTR);
 			delete item;
 			--m_nProjects;
 			break;
@@ -692,13 +726,13 @@ void ProjectView::remove(const KileProject *project)
 /**
  * Removes a file from the projectview, does not remove project-items. Only files without a project.
  **/
-void ProjectView::remove(const KUrl &url)
+void ProjectView::remove(const QUrl &url)
 {
 	for(int i = 0; i < topLevelItemCount(); ++i) {
 		ProjectViewItem *item = dynamic_cast<ProjectViewItem*>(topLevelItem(i));
 
 		if(item && (item->type() == KileType::File) && (item->url() == url)) {
-			item->setParent(NULL);
+			item->setParent(Q_NULLPTR);
 			delete item;
 			break;
 		}
@@ -712,7 +746,7 @@ void ProjectView::removeItem(const KileProjectItem *projitem, bool open)
 	while(*it) {
 		item = dynamic_cast<ProjectViewItem*>(*it);
 		if(item && (item->type() == KileType::ProjectItem) && (item->projectItem() == projitem)) {
-			KILE_DEBUG() << "removing projectviewitem";
+			KILE_DEBUG_MAIN << "removing projectviewitem";
 			static_cast<QTreeWidgetItem*>(item->parent())->removeChild(item);
 			delete item;
 		}
@@ -731,8 +765,8 @@ void ProjectView::removeItem(const KileProjectItem *projitem, bool open)
 void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 {
 	QSignalMapper signalMapper, serviceSignalMapper;
-	KMenu popup;
-	QAction *action = NULL;
+	QMenu popup;
+	QAction *action = Q_NULLPTR;
 
 	QTreeWidgetItem* treeWidgetItem = itemAt(event->pos());
 	if(!treeWidgetItem) {
@@ -756,12 +790,13 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 	}
 
 	if(projectViewItem->type() == KileType::ProjectExtra && !isKilePrFile) {
-		QMenu *servicesMenu = popup.addMenu(KIcon("fork"), i18n("&Open With"));
+		QMenu *servicesMenu = popup.addMenu(QIcon::fromTheme("fork"), i18n("&Open With"));
 		connect(&serviceSignalMapper, SIGNAL(mapped(int)), this, SLOT(slotRun(int)));
-		m_offerList = KMimeTypeTrader::self()->query(KMimeType::findByUrl(projectViewItem->url())->name(), "Application");
+QMimeDatabase db;
+		m_offerList = KMimeTypeTrader::self()->query(db.mimeTypeForUrl(projectViewItem->url()).name(), "Application");
 		for (int i = 0; i < m_offerList.count(); ++i) {
-			action = new KAction(servicesMenu);
-			action->setIcon(KIcon(m_offerList[i]->icon()));
+			action = new QAction(servicesMenu);
+			action->setIcon(QIcon::fromTheme(m_offerList[i]->icon()));
 			action->setText(m_offerList[i]->name());
 			connect(action, SIGNAL(triggered()), &serviceSignalMapper, SLOT(map()));
 			serviceSignalMapper.setMapping(action, i + 1);
@@ -776,11 +811,11 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 
 	if (projectViewItem->type() == KileType::File || projectViewItem->type() == KileType::ProjectItem) {
 		if(!m_ki->isOpen(projectViewItem->url())) {
-			action = popup.addAction(KIcon("document-open"), i18n("&Open"), &signalMapper, SLOT(map()));
+			action = popup.addAction(QIcon::fromTheme("document-open"), i18n("&Open"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, KPV_ID_OPEN);
 		}
 		else {
-			action = popup.addAction(KIcon("document-save"), i18n("&Save"), &signalMapper, SLOT(map()));
+			action = popup.addAction(QIcon::fromTheme("document-save"), i18n("&Save"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, KPV_ID_SAVE);
 		}
 		insertsep = true;
@@ -791,7 +826,7 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 			if(insertsep) {
 				popup.addSeparator();
 			}
-			action = popup.addAction(KIcon("project_add"), i18n("&Add to Project"), &signalMapper, SLOT(map()));
+			action = popup.addAction(QIcon::fromTheme("project_add"), i18n("&Add to Project"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, KPV_ID_ADD);
 			insertsep = true;
 		}
@@ -813,7 +848,7 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 			if(insertsep) {
 				popup.addSeparator();
 			}
-			action = popup.addAction(KIcon("project_remove"),i18n("&Remove From Project"), &signalMapper, SLOT(map()));
+			action = popup.addAction(QIcon::fromTheme("project_remove"),i18n("&Remove From Project"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, KPV_ID_REMOVE);
 			insertsep = true;
 		}
@@ -829,9 +864,9 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 		action = popup.addAction(i18n("Open All &Project Files"), &signalMapper, SLOT(map()));
 		signalMapper.setMapping(action, KPV_ID_OPENALLFILES);
 		popup.addSeparator();
-		action = popup.addAction(KIcon("view-refresh"),i18n("Refresh Project &Tree"), &signalMapper, SLOT(map()));
+		action = popup.addAction(QIcon::fromTheme("view-refresh"),i18n("Refresh Project &Tree"), &signalMapper, SLOT(map()));
 		signalMapper.setMapping(action, KPV_ID_BUILDTREE);
-		action = popup.addAction(KIcon("configure"), i18n("Project &Options"), &signalMapper, SLOT(map()));
+		action = popup.addAction(QIcon::fromTheme("configure"), i18n("Project &Options"), &signalMapper, SLOT(map()));
 		signalMapper.setMapping(action, KPV_ID_OPTIONS);
 		action = popup.addAction(i18n("&Archive"), &signalMapper, SLOT(map()));
 		signalMapper.setMapping(action, KPV_ID_ARCHIVE);
@@ -844,7 +879,7 @@ void ProjectView::contextMenuEvent(QContextMenuEvent *event)
 		if(insertsep) {
 			popup.addSeparator();
 		}
-		action = popup.addAction(KIcon("view-close"), i18n("&Close"), &signalMapper, SLOT(map()));
+		action = popup.addAction(QIcon::fromTheme("view-close"), i18n("&Close"), &signalMapper, SLOT(map()));
 		signalMapper.setMapping(action, KPV_ID_CLOSE);
 	}
 
@@ -873,4 +908,3 @@ void ProjectView::dropEvent(QDropEvent *event)
 
 }
 
-#include "projectview.moc"
