@@ -1,8 +1,7 @@
 /*************************************************************************************************
-    begin                : Sun Dec 28 2003
-    copyright            : (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net
-                               2005-2007 by Holger Danielsson (holger.danielsson@versanet.de)
-                               2008-2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+   Copyright (C) 2003 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net
+                 2005-2007 by Holger Danielsson (holger.danielsson@versanet.de)
+                 2008-2016 by Michel Ludwig (michel.ludwig@kdemail.net)
  *************************************************************************************************/
 
 /***************************************************************************
@@ -60,31 +59,35 @@
 
 #include <QClipboard>
 #include <QFileInfo>
+#include <QIcon>
 #include <QHeaderView>
+#include <QMimeDatabase>
+#include <QMimeType>
 #include <QRegExp>
 #include <QScrollBar>
 #include <QSignalMapper>
+#include <QUrl>
 
-#include <KIcon>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KMimeType>
 #include <KRun>
-#include <KUrl>
 
+#include "documentinfo.h"
+#include "errorhandler.h"
 #include "kileconfig.h"
 #include "kiledebug.h"
 #include "kiledocmanager.h"
 #include "kileinfo.h"
-#include "documentinfo.h"
 #include "kileproject.h"
 #include "kiletool_enums.h"
+#include "parser/parsermanager.h"
+#include "widgets/logwidget.h"
 
 namespace KileWidget
 {
 ////////////////////// StructureViewItem with all info //////////////////////
 
-StructureViewItem::StructureViewItem(QTreeWidgetItem* parent, const QString &title, const KUrl &url, uint line, uint column, int type, int level, uint startline, uint startcol) :
+StructureViewItem::StructureViewItem(QTreeWidgetItem* parent, const QString &title, const QUrl &url, uint line, uint column, int type, int level, uint startline, uint startcol) :
 	QTreeWidgetItem(parent),
 	m_title(title), m_url(url), m_line(line), m_column(column), m_type(type), m_level(level),
 	m_startline(startline), m_startcol(startcol)
@@ -94,14 +97,14 @@ StructureViewItem::StructureViewItem(QTreeWidgetItem* parent, const QString &tit
 
 StructureViewItem::StructureViewItem(QTreeWidget* parent, const QString& label) :
 	QTreeWidgetItem(parent, QStringList(label)),
-	m_title(label), m_url(KUrl()), m_line(0),  m_column(0), m_type(KileStruct::None), m_level(0)
+	m_title(label), m_url(QUrl()), m_line(0),  m_column(0), m_type(KileStruct::None), m_level(0)
 {
 	setToolTip(0, i18n("Click left to jump to the line. A double click will open\n a text file or a graphics file. When a label is assigned\nto this item, it will be shown when the mouse is over\nthis item. Items for a graphics file or an assigned label\nalso offer a context menu (right mouse button)."));
 }
 
 StructureViewItem::StructureViewItem(const QString& label, QTreeWidgetItem* parent) :
 	QTreeWidgetItem(parent, QStringList(label)),
-	m_title(label), m_url(KUrl()), m_line(0),  m_column(0), m_type(KileStruct::None), m_level(0)
+	m_title(label), m_url(QUrl()), m_line(0),  m_column(0), m_type(KileStruct::None), m_level(0)
 {}
 
 void StructureViewItem::setTitle(const QString &title)
@@ -137,7 +140,7 @@ void StructureViewItem::setLabel(const QString &label)
 		setHeaderLabels(labelList);
 
 		header()->hide();
-		header()->setResizeMode(QHeaderView::ResizeToContents);
+		header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 		setAllColumnsShowFocus(true);
 		setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
 
@@ -159,18 +162,17 @@ void StructureViewItem::setLabel(const QString &label)
 		if(m_docinfo) {
 			m_root->setURL(m_docinfo->url());
 			m_root->setExpanded(true);
-			m_root->setIcon(0, KIcon("contents"));
+			m_root->setIcon(0, QIcon::fromTheme("contents"));
 			connect(m_docinfo, SIGNAL(foundItem(const QString&, uint, uint, int, int, uint, uint, const QString &, const QString &)),
 			        this, SLOT(addItem(const QString&, uint, uint, int, int, uint, uint, const QString &, const QString &)));
-// 			connect(m_docinfo, SIGNAL(doneUpdating()), this, SLOT(insertInMasterList()));
 		}
 
 		m_parent[0]=m_parent[1]=m_parent[2]=m_parent[3]=m_parent[4]=m_parent[5]=m_parent[6]=m_root;
 		m_lastType = KileStruct::None;
-		m_lastSectioning = NULL;
-		m_lastFloat = NULL;
-		m_lastFrame = NULL;
-		m_lastFrameEnv = NULL;
+		m_lastSectioning = Q_NULLPTR;
+		m_lastFloat = Q_NULLPTR;
+		m_lastFrame = Q_NULLPTR;
+		m_lastFrameEnv = Q_NULLPTR;
 		m_stop = false;
 
 		m_folders.clear();
@@ -200,7 +202,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 	void StructureView::cleanUp(bool preserveState/* = true */)
 	{
-        	KILE_DEBUG() << "==void StructureView::cleanUp()========";
+        	KILE_DEBUG_MAIN << "==void StructureView::cleanUp()========";
 		if(preserveState) {
 			saveState();
 		}
@@ -217,7 +219,7 @@ void StructureViewItem::setLabel(const QString &label)
 			return;
 		}
 		cleanUp(false);
- 		m_stack->update(m_docinfo, true, true);
+		m_stack->update(m_docinfo, true);
 	}
 
 	void StructureView::contextMenuEvent(QContextMenuEvent *event)
@@ -227,13 +229,13 @@ void StructureViewItem::setLabel(const QString &label)
 
 	void StructureView::saveState()
 	{
-		KILE_DEBUG() << "===void StructureView::saveState()";
+		KILE_DEBUG_MAIN << "===void StructureView::saveState()";
 		m_openByTitle.clear();
 		m_openByLine.clear();
 		m_openByFolders.clear();
 
 		QTreeWidgetItemIterator it(this);
-		StructureViewItem *item = NULL;
+		StructureViewItem *item = Q_NULLPTR;
 		while(*it) {
 			item = dynamic_cast<StructureViewItem*>(*it);
 			if(item && item->child(0)) {
@@ -325,23 +327,23 @@ void StructureViewItem::setLabel(const QString &label)
 		fldr->setExpanded(false);
 		if(folder == "labels") {
 			fldr->setText(0, i18n("Labels"));
-			fldr->setIcon(0, KIcon("label"));
+			fldr->setIcon(0, QIcon::fromTheme("label"));
 		}
 		else if(folder == "bibs") {
 			fldr->setText(0, i18n("BibTeX References"));
-			fldr->setIcon(0, KIcon("viewbib"));
+			fldr->setIcon(0, QIcon::fromTheme("viewbib"));
 		}
 		else if(folder == "refs") {
 			fldr->setText(0, i18n("Undefined References"));
-			fldr->setIcon(0, KIcon("dialog-error"));
+			fldr->setIcon(0, QIcon::fromTheme("dialog-error"));
 		}
 		else if(folder == "todo") {
 			fldr->setText(0, i18n("TODO"));
-			fldr->setIcon(0, KIcon("bookmarks"));
+			fldr->setIcon(0, QIcon::fromTheme("bookmarks"));
 		}
 		else if(folder == "fixme") {
 			fldr->setText(0, i18n("FIXME"));
-			fldr->setIcon(0, KIcon("bookmarks"));
+			fldr->setIcon(0, QIcon::fromTheme("bookmarks"));
 		}
 
 		m_folders[folder] = fldr;
@@ -367,7 +369,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 	StructureViewItem *StructureView::parentFor(int lev, const QString & fldr)
 	{
-		StructureViewItem *par = NULL;
+		StructureViewItem *par = Q_NULLPTR;
 
 		if(fldr == "root") {
 			switch(lev) {
@@ -407,7 +409,7 @@ void StructureViewItem::setLabel(const QString &label)
 		      the floating environment is closed, it is inserted into the title of this item.
 		      If a \label command follows, it is assigned to this float item.
 		- KileStruct::EndFloat
-		      Reset m_lastFloat to NULL to close this environment. No more \caption or \label
+		      Reset m_lastFloat to Q_NULLPTR to close this environment. No more \caption or \label
 		      commands are assigned to this float after this.
 		- KileStruct::Caption
 		      If a float environment is opened, the caption is assigned to the float item.
@@ -423,7 +425,7 @@ void StructureViewItem::setLabel(const QString &label)
 		      the frame environment is closed, it is inserted into the title of this item.
 		      If a \label command follows, it is assigned to this float item.
 		- KileStruct::BeamerEndFrame
-		      Reset m_lastFloatEnv to NULL to close this environment. No more \frametitle
+		      Reset m_lastFloatEnv to Q_NULLPTR to close this environment. No more \frametitle
 		      or \label commands are assigned to this frame after this.
 		- KileStruct::BeamerBeginBlock
 		      Inside a beamer frame this environment is taken as child of this frame
@@ -436,7 +438,7 @@ void StructureViewItem::setLabel(const QString &label)
 	                            uint startline, uint startcol,
 	                            const QString &pix, const QString &fldr /* = "root" */)
 	{
-//  		KILE_DEBUG() << "\t\taddItem: " << title << ", with type " <<  type;
+//  		KILE_DEBUG_MAIN << "\t\taddItem: " << title << ", with type " <<  type;
 		if(m_stop) {
 			return;
 		}
@@ -452,7 +454,7 @@ void StructureViewItem::setLabel(const QString &label)
 			}
 		}
 		else if(type == KileStruct::EndFloat) {
-			m_lastFloat = NULL;
+			m_lastFloat = Q_NULLPTR;
 		}
 		else if(type == KileStruct::BeamerFrametitle) {
 			if(m_lastFrameEnv) {
@@ -463,17 +465,17 @@ void StructureViewItem::setLabel(const QString &label)
 			}
 		}
 		else if(type == KileStruct::BeamerEndFrame) {
-			m_lastFrameEnv = NULL;
+			m_lastFrameEnv = Q_NULLPTR;
 		}
-		m_lastFrame = NULL;
+		m_lastFrame = Q_NULLPTR;
 
 		// that's all for hidden types: we must immediately return
 		if(lev == KileStruct::Hidden) {
-			//KILE_DEBUG() << "\t\thidden item: not created";
+			//KILE_DEBUG_MAIN << "\t\thidden item: not created";
 			return;
 		}
 
-		//KILE_DEBUG() << "\t\tcreate new item";
+		//KILE_DEBUG_MAIN << "\t\tcreate new item";
 		// check if we have to update a label before loosing this item
 		if(type==KileStruct::Label) {
 			if(m_lastFloat) {
@@ -508,7 +510,7 @@ void StructureViewItem::setLabel(const QString &label)
 		// create a new item
 		StructureViewItem *newChild = new StructureViewItem(parentItem, title, m_docinfo->url(), line, column, type, lev, startline, startcol);
 		if(!pix.isEmpty()) {
-			newChild->setIcon(0, KIcon(pix));
+			newChild->setIcon(0, QIcon::fromTheme(pix));
 		}
 		//m_stop = true;
 
@@ -525,7 +527,7 @@ void StructureViewItem::setLabel(const QString &label)
 			}
 		}
 		else if(lev == 0) {
-			m_lastSectioning = NULL;
+			m_lastSectioning = Q_NULLPTR;
 			for(int l = 0; l < 7; ++l) {
 				m_parent[l] = m_root;
 			}
@@ -557,15 +559,15 @@ void StructureViewItem::setLabel(const QString &label)
 			m_folders.remove("refs");
 		}
 
-		//KILE_DEBUG() << "==void StructureView::showReferences()========";
-		//KILE_DEBUG() << "\tfound " << m_references.count() << " references";
+		//KILE_DEBUG_MAIN << "==void StructureView::showReferences()========";
+		//KILE_DEBUG_MAIN << "\tfound " << m_references.count() << " references";
 		if(m_references.count() == 0) {
 			return;
 		}
 
 		// read list with all labels
 		QStringList list = ki->allLabels();
-		//KILE_DEBUG() << "\tfound " << list.count() << " labels";
+		//KILE_DEBUG_MAIN << "\tfound " << list.count() << " labels";
 		QMap<QString,bool> labelmap;
 		for (QStringList::const_iterator itmap = list.constBegin(); itmap != list.constEnd(); ++itmap) {
 			labelmap[(*itmap)] = true;
@@ -586,17 +588,21 @@ void StructureViewItem::setLabel(const QString &label)
 	StructureWidget::StructureWidget(KileInfo *ki, QWidget * parent, const char* name) :
 		QStackedWidget(parent),
 		m_ki(ki),
-		m_docinfo(NULL)
+		m_docinfo(Q_NULLPTR),
+		m_showingContextMenu(Q_NULLPTR)
 	{
 		setObjectName(name);
-		KILE_DEBUG() << "==KileWidget::StructureWidget::StructureWidget()===========";
+		KILE_DEBUG_MAIN << "==KileWidget::StructureWidget::StructureWidget()===========";
 		setLineWidth(0);
 		setMidLineWidth(0);
 		setContentsMargins(0, 0, 0, 0);
 		setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
 
-		m_default = new StructureView(this, NULL);
+		m_default = new StructureView(this, Q_NULLPTR);
 		m_default->activate();
+
+		connect(m_ki->parserManager(), SIGNAL(documentParsingStarted()), this, SLOT(handleDocumentParsingStarted()));
+		connect(m_ki->parserManager(), SIGNAL(documentParsingComplete()), this, SLOT(handleDocumentParsingCompleted()));
 	}
 
 	StructureWidget::~StructureWidget()
@@ -617,7 +623,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 	void StructureWidget::slotClicked(QTreeWidgetItem * itm)
 	{
-		KILE_DEBUG() << "\tStructureWidget::slotClicked";
+		KILE_DEBUG_MAIN << "\tStructureWidget::slotClicked";
 
 		StructureViewItem *item = dynamic_cast<StructureViewItem*>(itm);
 		//return if user didn't click on an item
@@ -635,7 +641,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 	void StructureWidget::slotDoubleClicked(QTreeWidgetItem * itm)
 	{
-		KILE_DEBUG() << "\tStructureWidget::slotDoubleClicked";
+		KILE_DEBUG_MAIN << "\tStructureWidget::slotDoubleClicked";
 		StructureViewItem *item = dynamic_cast<StructureViewItem*>(itm);
 		static QRegExp suffix("\\.[\\d\\w]*$");
 
@@ -643,14 +649,14 @@ void StructureViewItem::setLabel(const QString &label)
 			return;
 		}
 
-		KILE_DEBUG() <<"item->url() is " << item->url() << ", item->title() is " << item->title();
+		KILE_DEBUG_MAIN <<"item->url() is " << item->url() << ", item->title() is " << item->title();
 
 		if(item->type() & (KileStruct::Input | KileStruct::Bibliography | KileStruct::Graphics)) {
 			QString fname = item->title();
 
 
 			if(fname.indexOf(suffix) != -1) { // check if we have a suffix, if not add standard suffixes
-				KILE_DEBUG() << "Suffix found: " << suffix.cap(0);
+				KILE_DEBUG_MAIN << "Suffix found: " << suffix.cap(0);
 			}
 			else {
 				// filename in structureview entry has no extension: this shouldn't happen anymore,
@@ -676,16 +682,17 @@ void StructureViewItem::setLabel(const QString &label)
 						fromProject = false;
 					}
 
-					m_ki->logWidget()->printMessage(KileTool::Info,
-						i18n("No extension specified for graphic file.  Using .") + extToAdd +
-							(fromProject ? i18n(" from Project settings") : i18n(" from global Structure View settings.")),
-						i18n("File extension not specified") );
+					m_ki->errorHandler()->printMessage(KileTool::Info,
+						(fromProject ?
+						i18n("No extension specified for graphic file.  Using .%1 from Project settings.", extToAdd) :
+						i18n("No extension specified for graphic file.  Using .%1 from global Structure View settings.", extToAdd)),
+						i18n("File extension not specified"));
 
 					fname += '.' + extToAdd;
 
 				}
 				else{
-					KILE_DEBUG() << "Suffixless item with unknown type found";
+					KILE_DEBUG_MAIN << "Suffixless item with unknown type found";
 				}
 
 			}
@@ -696,19 +703,19 @@ void StructureViewItem::setLabel(const QString &label)
 			}
 
 			QFileInfo fi(fname);
-			KUrl url;
-			url.setPath(fname);
 
-			if (fi.isReadable()) {
-				if( item->type() == KileStruct::Graphics) {
-					KMimeType::Ptr pMime = KMimeType::findByUrl(url);
-					KRun::runUrl(url, pMime->name(), this);
+			if(fi.isReadable()) {
+				QUrl url = QUrl::fromLocalFile(fname);
+				if(item->type() == KileStruct::Graphics) {
+					QMimeDatabase db;
+					QMimeType pMime = db.mimeTypeForUrl(url);
+					KRun::runUrl(url, pMime.name(), this, KRun::RunFlags());
 				}
 				else {
 					emit(fileOpen(url, QString()));
 				}
 			}
-			else{
+			else {
 				QString otherFilename;
 
 				if(item->type() == KileStruct::Bibliography) {
@@ -721,14 +728,12 @@ void StructureViewItem::setLabel(const QString &label)
 				fi.setFile(otherFilename);
 
 				if(fi.isReadable()) {
-					url.setPath(otherFilename);
-					emit(fileOpen(url, QString()));
+					emit(fileOpen(QUrl::fromLocalFile(otherFilename), QString()));
 				}
 				else {
 					if(KMessageBox::warningYesNo(this, i18n("Cannot find the included file. The file does not exist, is not readable or Kile is unable to determine the correct path to it. The filename causing this error was: %1.\nDo you want to create this file?", fname), i18n("Cannot Find File"))
 					   == KMessageBox::Yes) {
-						url.setPath(fname);
-						emit(fileNew(url));
+						emit(fileNew(QUrl::fromLocalFile(fname)));
 					}
 				}
 			}
@@ -741,16 +746,17 @@ void StructureViewItem::setLabel(const QString &label)
 	//  - graphics:   100ff
 	void StructureWidget::viewContextMenuEvent(StructureView *view, QContextMenuEvent *event)
 	{
-		KILE_DEBUG() << "\tcalled";
+		KILE_DEBUG_MAIN << "\tcalled";
 
 		QSignalMapper signalMapper;
 		connect(&signalMapper, SIGNAL(mapped(int)), this, SLOT(slotPopupActivated(int)));
-		KMenu popup;
-		QAction *action = NULL;
+		QMenu popup;
+		QAction *action = Q_NULLPTR;
+		m_showingContextMenu = Q_NULLPTR;
 
 		m_popupItem = dynamic_cast<StructureViewItem*>(view->itemAt(event->pos()));
 		if(!m_popupItem) {
-			KILE_DEBUG() << "not a pointer to a StructureViewItem object.";
+			KILE_DEBUG_MAIN << "not a pointer to a StructureViewItem object.";
 			return;
 		}
 
@@ -758,7 +764,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 		if(m_popupItem->type() == KileStruct::Sect) {
 			if(hasLabel) {
-				popup.addTitle(i18n("Sectioning"));
+				popup.addSection(i18n("Sectioning"));
 			}
 			action = popup.addAction(i18n("Cu&t"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, SectioningCut);
@@ -788,12 +794,13 @@ void StructureViewItem::setLabel(const QString &label)
 
 			QFileInfo fi(m_popupInfo);
 			if(fi.isReadable()) {
-				KUrl url;
+				QUrl url;
 				url.setPath(m_popupInfo);
 
-				m_offerList = KMimeTypeTrader::self()->query(KMimeType::findByUrl(url)->name(), "Application");
+				QMimeDatabase db;
+				m_offerList = KMimeTypeTrader::self()->query(db.mimeTypeForUrl(url).name(), "Application");
 				for(int i = 0; i < m_offerList.count(); ++i) {
-					action = popup.addAction(SmallIcon(m_offerList[i]->icon()), m_offerList[i]->name(),
+					action = popup.addAction(QIcon::fromTheme(m_offerList[i]->icon()), m_offerList[i]->name(),
 					                         &signalMapper, SLOT(map()));
 					signalMapper.setMapping(action, i + SectioningGraphicsOfferlist);
 				}
@@ -804,7 +811,7 @@ void StructureViewItem::setLabel(const QString &label)
 		}
 
 		if(hasLabel) {
-			popup.addTitle(i18n("Insert Label"));
+			popup.addSection(i18n("Insert Label"));
 			action = popup.addAction(i18n("As &reference"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, 1);
 			action = popup.addAction(i18n("As &page reference"), &signalMapper, SLOT(map()));
@@ -812,7 +819,7 @@ void StructureViewItem::setLabel(const QString &label)
 			action = popup.addAction(i18n("Only the &label"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, 3);
 			popup.addSeparator();
-			popup.addTitle(i18n("Copy Label to Clipboard"));
+			popup.addSection(i18n("Copy Label to Clipboard"));
 			action = popup.addAction(i18n("As reference"), &signalMapper, SLOT(map()));
 			signalMapper.setMapping(action, 4);
 			action = popup.addAction(i18n("As page reference"), &signalMapper, SLOT(map()));
@@ -822,13 +829,15 @@ void StructureViewItem::setLabel(const QString &label)
 		}
 
 		if(!popup.isEmpty()) {
+			m_showingContextMenu = &popup;
 			popup.exec(event->globalPos());
+			m_showingContextMenu = Q_NULLPTR;
 		}
 	}
 
 	void StructureWidget::slotPopupActivated(int id)
 	{
-		KILE_DEBUG() << "id: " << id;
+		KILE_DEBUG_MAIN << "id: " << id;
 		if(id >= 1 && id <= 6) {
 			slotPopupLabel(id);
 		}
@@ -843,7 +852,7 @@ void StructureViewItem::setLabel(const QString &label)
 	// id's 1..6 (already checked)
 	void StructureWidget::slotPopupLabel(int id)
 	{
-		KILE_DEBUG() << "\tStructureWidget::slotPopupLabel (" << id << ")"<< endl;
+		KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupLabel (" << id << ")"<< endl;
 
 		QString s = m_popupItem->label();
 		if(id == 1 || id == 4) {
@@ -864,7 +873,7 @@ void StructureViewItem::setLabel(const QString &label)
 	// id's 10..16 (already checked)
 	void StructureWidget::slotPopupSectioning(int id)
 	{
-		KILE_DEBUG() << "\tStructureWidget::slotPopupSectioning (" << id << ")"<< endl;
+		KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupSectioning (" << id << ")"<< endl;
 		if(m_popupItem->level() >= 1 && m_popupItem->level() <= 7) {
 			emit(sectioningPopup(m_popupItem, id));
 		}
@@ -873,23 +882,23 @@ void StructureViewItem::setLabel(const QString &label)
 	// id's 100ff (already checked)
 	void StructureWidget::slotPopupGraphics(int id)
 	{
-		KILE_DEBUG() << "\tStructureWidget::slotPopupGraphics (" << id << ")"<< endl;
+		KILE_DEBUG_MAIN << "\tStructureWidget::slotPopupGraphics (" << id << ")"<< endl;
 
-		KUrl url;
+		QUrl url;
 		url.setPath(m_popupInfo);
 
 		if(id == SectioningGraphicsOther) {
-			KRun::displayOpenWithDialog(url, this);
+			KRun::displayOpenWithDialog(QList<QUrl>() << url, this);
 		}
 		else {
-			KRun::run(*m_offerList[id-SectioningGraphicsOfferlist], url, this);
+			KRun::runService(*m_offerList[id-SectioningGraphicsOfferlist], QList<QUrl>() << url, this);
 		}
 	}
 
 	StructureView* StructureWidget::viewFor(KileDocument::Info *info)
 	{
 		if(!info) {
-			return NULL;
+			return Q_NULLPTR;
 		}
 
 		if(!viewExistsFor(info)) {
@@ -911,7 +920,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 	void StructureWidget::closeDocumentInfo(KileDocument::Info *docinfo)
 	{
-		m_docinfo = NULL;
+		m_docinfo = Q_NULLPTR;
 		if(m_map.contains(docinfo)) {
 			StructureView *data = m_map[docinfo];
 			m_map.remove(docinfo);
@@ -934,7 +943,7 @@ void StructureViewItem::setLabel(const QString &label)
 		}
 
 		m_map.clear();
-		m_docinfo = NULL;
+		m_docinfo = Q_NULLPTR;
 
 		m_default->activate();
 	}
@@ -952,9 +961,9 @@ void StructureViewItem::setLabel(const QString &label)
 		update(docinfo, false);
 	}
 
-	void StructureWidget::update(KileDocument::Info *docinfo, bool forceParsing, bool activate /* =true */)
+	void StructureWidget::update(KileDocument::Info *docinfo, bool forceParsing)
 	{
-		KILE_DEBUG() << "==KileWidget::StructureWidget::update(" << docinfo << ")=============";
+		KILE_DEBUG_MAIN << "==KileWidget::StructureWidget::update(" << docinfo << ")=============";
 
 		if(!docinfo) {
 			m_default->activate();
@@ -972,28 +981,39 @@ void StructureViewItem::setLabel(const QString &label)
 		}
 
 		if(needParsing) { //need to reparse the doc
-			int xtop = view->horizontalScrollBar()->value();
-			int ytop = view->verticalScrollBar()->value();
-			//KILE_DEBUG() << "\tStructure::update parsing doc";
-			// avoid flickering when parsing
-			view->setUpdatesEnabled(false);
-			view->cleanUp();
 			m_docinfo->updateStruct();
-			view->setUpdatesEnabled(true);
-			view->showReferences(m_ki);
-			view->horizontalScrollBar()->setValue(xtop);
-			view->verticalScrollBar()->setValue(ytop);
 		}
 
-		if(activate) {
-			KILE_DEBUG() << "===StructureWidget::update() activating view";
-			view->activate();
+		KILE_DEBUG_MAIN << "activating view";
+		view->activate();
+	}
+
+	void StructureWidget::updateAfterParsing(KileDocument::Info *info, const QLinkedList<KileParser::StructureViewItem*>& items)
+	{
+		KILE_DEBUG_MAIN;
+		StructureView *view = viewFor(info);
+		if(!view) {
+			m_default->activate();
+			return;
 		}
+
+		int xtop = view->horizontalScrollBar()->value();
+		int ytop = view->verticalScrollBar()->value();
+		// avoid flickering when parsing
+		view->setUpdatesEnabled(false);
+		view->cleanUp();
+		Q_FOREACH( KileParser::StructureViewItem *item, items) {
+			view->addItem(item->title, item->line, item->column, item->type, item->level, item->startline, item->startcol, item->pix, item->folder);
+		}
+		view->setUpdatesEnabled(true);
+		view->showReferences(m_ki);
+		view->horizontalScrollBar()->setValue(xtop);
+		view->verticalScrollBar()->setValue(ytop);
 	}
 
 	void StructureWidget::clean(KileDocument::Info *docinfo)
 	{
-		KILE_DEBUG() << "==void StructureWidget::clean()========";
+		KILE_DEBUG_MAIN << "==void StructureWidget::clean()========";
 		StructureView *view = viewFor(docinfo);
 		if(view) {
 			view->cleanUp();
@@ -1002,7 +1022,7 @@ void StructureViewItem::setLabel(const QString &label)
 
 	void StructureWidget::updateReferences(KileDocument::Info *docinfo)
 	{
-		KILE_DEBUG() << "==void StructureView::updateReferences()========";
+		KILE_DEBUG_MAIN << "==void StructureView::updateReferences()========";
 		StructureView *view = viewFor(docinfo);
 		if(view) {
 			view->showReferences(m_ki);
@@ -1018,7 +1038,7 @@ void StructureViewItem::setLabel(const QString &label)
 			return false;
 		}
 
-		if( checkLevel && !refItem ){ // only allow a refItem == NULL if checkLevel is false
+		if( checkLevel && !refItem ){ // only allow a refItem == Q_NULLPTR if checkLevel is false
 			return false;
 		}
 
@@ -1054,6 +1074,19 @@ void StructureViewItem::setLabel(const QString &label)
 		return found;
 	}
 
+	void StructureWidget::handleDocumentParsingStarted()
+	{
+		setEnabled(false);
+		// if a context menu is showing, we better close it
+		// as the StructureViewItems it operates on will be deleted
+		if(m_showingContextMenu) {
+			m_showingContextMenu->close();
+		}
+	}
+
+	void StructureWidget::handleDocumentParsingCompleted()
+	{
+		setEnabled(true);
+	}
 }
 
-#include "structurewidget.moc"
