@@ -1,7 +1,7 @@
 /******************************************************************************************
     begin                : Sat 3-1 20:40:00 CEST 2004
     copyright            : (C) 2004 by Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)
-                               2007-2010 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2017 by Michel Ludwig (michel.ludwig@kdemail.net)
  ******************************************************************************************/
 
 /***************************************************************************
@@ -16,6 +16,7 @@
 #include "widgets/toolconfigwidget.h"
 
 #include <QCheckBox>
+#include <QInputDialog>
 #include <QLabel>
 #include <QLayout>
 #include <QRegExp>
@@ -25,22 +26,20 @@
 #include <QVBoxLayout>
 
 #include "kiledebug.h"
-#include <keditlistbox.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kicondialog.h>
 #include <kiconloader.h>
 #include <kcombobox.h>
-#include <kpushbutton.h>
+#include <QPushButton>
 #include <kconfig.h>
-#include <klineedit.h>
 #include <kmessagebox.h>
-#include <kinputdialog.h>
+#include <KConfigGroup>
 
+#include "kiletool_enums.h"
 #include "kiletoolmanager.h"
 #include "kilestdtools.h"
 #include "widgets/maintoolconfigwidget.h"
 #include "widgets/processtoolconfigwidget.h"
-#include "widgets/librarytoolconfigwidget.h"
 #include "widgets/quicktoolconfigwidget.h"
 #include "widgets/latextoolconfigwidget.h"
 #include "dialogs/newtoolwizard.h"
@@ -55,7 +54,7 @@ namespace KileWidget
 		m_config = m_manager->config();
 		QVBoxLayout *layout = new QVBoxLayout();
 		layout->setMargin(0);
-		layout->setSpacing(KDialog::spacingHint());
+//TODO PORT QT5 		layout->setSpacing(QDialog::spacingHint());
 		setLayout(layout);
 		m_configWidget = new ToolConfigWidget(this);
 		layout->addWidget(m_configWidget);
@@ -110,13 +109,12 @@ namespace KileWidget
 	{
 		m_configWidget->m_cbType->addItem(i18n("Run Outside of Kile"));
 		m_configWidget->m_cbType->addItem(i18n("Run in Konsole"));
-		m_configWidget->m_cbType->addItem(i18n("Run Embedded in Kile"));
-		m_configWidget->m_cbType->addItem(i18n("Use HTML Viewer"));
+		m_configWidget->m_cbType->addItem(i18n("Use Document Viewer"));
 		m_configWidget->m_cbType->addItem(i18n("Run Sequence of Tools"));
 		connect(m_configWidget->m_cbType, SIGNAL(activated(int)), this, SLOT(switchType(int)));
 		connect(m_configWidget->m_ckClose, SIGNAL(toggled(bool)), this, SLOT(setClose(bool)));
 
-		m_classes << "Compile" << "Convert" << "Archive" << "View" <<  "Sequence" << "LaTeX" << "ViewHTML" << "ViewBib" << "ForwardDVI" << "Base";
+		m_classes << "Compile" << "Convert" << "Archive" << KileTool::BibliographyCompile::ToolClass << "View" <<  "Sequence" << "LaTeX" << "ViewHTML" << "ViewBib" << "ForwardDVI" << "Base";
 		m_configWidget->m_cbClass->addItems(m_classes);
 		connect(m_configWidget->m_cbClass, SIGNAL(activated(const QString &)), this, SLOT(switchClass(const QString &)));
 
@@ -124,11 +122,6 @@ namespace KileWidget
 		connect(m_configWidget->m_leTarget, SIGNAL(textChanged(const QString &)), this, SLOT(setTo(const QString &)));
 		connect(m_configWidget->m_leFile, SIGNAL(textChanged(const QString &)), this, SLOT(setTarget(const QString &)));
 		connect(m_configWidget->m_leRelDir, SIGNAL(textChanged(const QString &)), this, SLOT(setRelDir(const QString &)));
-
-		m_configWidget->m_cbState->addItem("Editor");
-		m_configWidget->m_cbState->addItem("Viewer");
-		m_configWidget->m_cbState->addItem("HTMLpreview");
-		connect(m_configWidget->m_cbState, SIGNAL(activated(const QString &)), this, SLOT(setState(const QString &)));
 	}
 
 	void ToolConfig::updateAdvanced()
@@ -142,30 +135,14 @@ namespace KileWidget
 			m_configWidget->m_cbType->setCurrentIndex(1);
 			enablekonsoleclose = true;
 		}
-		else if(type == "Part") {
+		else if(type == "DocumentViewer") {
 			m_configWidget->m_cbType->setCurrentIndex(2);
 		}
-		else if(type == "DocPart") {
+		else if(type == "Sequence") {
 			m_configWidget->m_cbType->setCurrentIndex(3);
 		}
-		else if(type == "Sequence") {
-			m_configWidget->m_cbType->setCurrentIndex(4);
-		}
 		m_configWidget->m_ckClose->setEnabled(enablekonsoleclose);
 
-		QString state = m_map["state"];
-		if(state.isEmpty()) {
-			state = "Editor";
-		}
-		int i = m_configWidget->m_cbState->findText(state);
-		if(i >= 0) {
-			m_configWidget->m_cbState->setCurrentIndex(i);
-		}
-		else {
-			m_configWidget->m_cbState->setItemText(m_configWidget->m_cbState->currentIndex(),
-			                                       state);
-		}
-
 		int index = m_classes.indexOf(m_map["class"]);
 		if(index == -1) {
 			index = m_classes.count() - 1;
@@ -187,12 +164,6 @@ namespace KileWidget
 		connect(m_ptcw->m_command, SIGNAL(textChanged(const QString &)), this, SLOT(setCommand(const QString &)));
 		connect(m_ptcw->m_options, SIGNAL(textChanged()), this, SLOT(setOptions()));
 
-		m_ltcw = new LibraryToolConfigWidget(m_configWidget->m_stackBasic);
-		m_configWidget->m_stackBasic->insertWidget(GBS_Library, m_ltcw);
-		connect(m_ltcw->m_library, SIGNAL(textChanged(const QString &)), this, SLOT(setLibrary(const QString &)));
-		connect(m_ltcw->m_class, SIGNAL(textChanged(const QString &)), this, SLOT(setClassName(const QString &)));
-		connect(m_ltcw->m_options, SIGNAL(textChanged(const QString &)), this, SLOT(setLibOptions(const QString &)));
-
 		m_qtcw = new QuickToolConfigWidget(m_configWidget->m_stackBasic);
 		m_configWidget->m_stackBasic->insertWidget(GBS_Sequence, m_qtcw);
 		connect(m_qtcw, SIGNAL(sequenceChanged(const QString &)), this, SLOT(setSequence(const QString &)));
@@ -216,32 +187,33 @@ namespace KileWidget
 		int basicPage = GBS_None;
 		int extraPage = GES_None;
 
-		if ( type == "Process" || type == "Konsole" ) basicPage = GBS_Process;
-		else if ( type == "Part" ) basicPage = GBS_Library;
-		else if ( type == "DocPart" ) basicPage = GBS_None;
-		else if ( type == "Sequence" )
-		{
+		if(type == "Process" || type == "Konsole") {
+			basicPage = GBS_Process;
+		}
+		else if(type == "DocumentViewer") {
+			basicPage = GBS_None;
+		}
+		else if(type == "Sequence") {
 			basicPage = GBS_Sequence;
 			m_qtcw->updateSequence(m_map["sequence"]);
 		}
-		else basicPage = GBS_Error;
+		else {
+			basicPage = GBS_Error;
+		}
 
 		QString cls = m_map["class"];
-		if ( cls == "LaTeX" )
+		if(cls == "LaTeX") {
 			extraPage = GES_LaTeX;
+		}
 
 		m_ptcw->m_command->setText(m_map["command"]);
 		m_ptcw->m_options->setText(m_map["options"]);
 
-		m_ltcw->m_library->setText(m_map["libName"]);
-		m_ltcw->m_class->setText(m_map["className"]);
-		m_ltcw->m_options->setText(m_map["libOptions"]);
-
 		m_LaTeXtcw->m_ckRootDoc->setChecked(m_map["checkForRoot"] == "yes");
 		m_LaTeXtcw->m_ckJump->setChecked(m_map["jumpToFirstError"] == "yes");
 		m_LaTeXtcw->m_ckAutoRun->setChecked(m_map["autoRun"] == "yes");
 
-		KILE_DEBUG() << "showing pages " << basicPage << " " << extraPage;
+		KILE_DEBUG_MAIN << "showing pages " << basicPage << " " << extraPage;
 		m_configWidget->m_stackBasic->setCurrentIndex(basicPage);
 		m_configWidget->m_stackExtra->setCurrentIndex(extraPage);
 
@@ -249,25 +221,14 @@ namespace KileWidget
 
 	void ToolConfig::writeDefaults()
 	{
-		if (KMessageBox::warningContinueCancel(this, i18n("All your tool settings will be overwritten with the default settings, are you sure you want to continue?")) == KMessageBox::Continue) {
-			QStringList groups = m_config->groupList();
-			QRegExp re = QRegExp("Tool/(.+)/.+");
-			for(int i = 0; i < groups.count(); ++i) {
-				if (re.exactMatch(groups[i])) {
-					m_config->deleteGroup(groups[i]);
-				}
-			}
-			// magic names, defined in kilestdtools.rc
-			m_config->deleteGroup("ToolsGUI");
-			m_config->deleteGroup("Tools");
-
-			m_manager->factory()->readStandardToolConfig();
+		if (KMessageBox::warningContinueCancel(this, i18n("All your tool settings will be overwritten with the default settings.\nAre you sure you want to continue?")) == KMessageBox::Continue) {
+			m_manager->factory()->resetToolConfigurations();
 			m_config->sync();
 			updateToollist();
   			QStringList tools = KileTool::toolList(m_config, true);
 			for (int i = 0; i < tools.count(); ++i) {
 				switchTo(tools[i], false);// needed to retrieve the new map
- 				switchTo(tools[i],true); // this writes the newly retrieved entry map (and not an perhaps changed old one)
+ 				switchTo(tools[i], true); // this writes the newly retrieved entry map (and not an perhaps changed old one)
 			}
 			int index = indexQuickBuild();
 			if(!tools.empty()) {
@@ -279,7 +240,7 @@ namespace KileWidget
 
 	void ToolConfig::updateToollist()
 	{
-		//KILE_DEBUG() << "==ToolConfig::updateToollist()====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::updateToollist()====================";
 		m_configWidget->m_lstbTools->clear();
 		m_configWidget->m_lstbTools->addItems(KileTool::toolList(m_config, true));
 		m_configWidget->m_lstbTools->sortItems();
@@ -293,7 +254,7 @@ namespace KileWidget
 
 	void ToolConfig::writeConfig()
 	{
-		//KILE_DEBUG() << "==ToolConfig::writeConfig()====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::writeConfig()====================";
 		//save config
 		m_manager->saveEntryMap(m_current, m_map, false, false);
 		// internally, menu names are stored in English
@@ -315,13 +276,13 @@ namespace KileWidget
 	
 	void ToolConfig::switchConfig(int /*index*/)
 	{
-		//KILE_DEBUG() << "==ToolConfig::switchConfig(int /*index*/)====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::switchConfig(int /*index*/)====================";
 		switchTo(m_current);
 	}
 
 	void ToolConfig::switchConfig(const QString & cfg)
 	{
-		//KILE_DEBUG() << "==ToolConfig::switchConfig(const QString & cfg)==========";
+		//KILE_DEBUG_MAIN << "==ToolConfig::switchConfig(const QString & cfg)==========";
 		for(int i = 0; i < m_configWidget->m_cbConfig->count(); ++i) {
 			if (m_configWidget->m_cbConfig->itemText(i) == cfg) {
 				m_configWidget->m_cbConfig->setCurrentIndex(i);
@@ -331,7 +292,7 @@ namespace KileWidget
 
 	void ToolConfig::switchTo(const QString & tool, bool save /* = true */)
 	{
-		//KILE_DEBUG() << "==ToolConfig::switchTo(const QString & tool, bool save /* = true */)====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::switchTo(const QString & tool, bool save /* = true */)====================";
 		//save config
 		if(save) {
 			writeConfig();
@@ -345,7 +306,7 @@ namespace KileWidget
 
 		m_map.clear();
 		if (!m_manager->retrieveEntryMap(m_current, m_map, false, false)) {
-			kWarning() << "no entrymap";
+			qWarning() << "no entrymap";
 		}
 
 		updateConfiglist();
@@ -364,16 +325,16 @@ namespace KileWidget
 		}
 		m_icon = KileTool::iconFor(m_current, m_config);
 		if(m_icon.isEmpty()) {
-			m_configWidget->m_pshbIcon->setIcon(KIcon(QString()));
+			m_configWidget->m_pshbIcon->setIcon(QIcon::fromTheme(QString()));
 		}
 		else {
-			m_configWidget->m_pshbIcon->setIcon(KIcon(m_icon));
+			m_configWidget->m_pshbIcon->setIcon(QIcon::fromTheme(m_icon));
 		}
 	}
 
 	void ToolConfig::updateConfiglist()
 	{
-		//KILE_DEBUG() << "==ToolConfig::updateConfiglist()=====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::updateConfiglist()=====================";
 		m_configWidget->m_groupBox->setTitle(i18n("Choose a configuration for the tool %1",m_current));
 		m_configWidget->m_cbConfig->clear();
 		m_configWidget->m_cbConfig->addItems(KileTool::configNames(m_current, m_config));
@@ -384,8 +345,8 @@ namespace KileWidget
 
 	void ToolConfig::selectIcon()
 	{
-		KILE_DEBUG() << "icon ---> " << m_icon;
-		//KILE_DEBUG() << "==ToolConfig::selectIcon()=====================";
+		KILE_DEBUG_MAIN << "icon ---> " << m_icon;
+		//KILE_DEBUG_MAIN << "==ToolConfig::selectIcon()=====================";
 		KIconDialog *dlg = new KIconDialog(this);
 		QString res = dlg->openDialog();
 		if(m_icon != res) {
@@ -396,17 +357,17 @@ namespace KileWidget
 			m_icon = res;
 			writeConfig();
 			if (m_icon.isEmpty()) {
-				m_configWidget->m_pshbIcon->setIcon(KIcon(QString()));
+				m_configWidget->m_pshbIcon->setIcon(QIcon::fromTheme(QString()));
 			}
 			else {
-				m_configWidget->m_pshbIcon->setIcon(KIcon(m_icon));
+				m_configWidget->m_pshbIcon->setIcon(QIcon::fromTheme(m_icon));
 			}
 		}
 	}
 
 	void ToolConfig::newTool()
 	{
-		//KILE_DEBUG() << "==ToolConfig::newTool()=====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::newTool()=====================";
 		NewToolWizard *ntw = new NewToolWizard(this);
 		if (ntw->exec()) {
 			QString toolName = ntw->toolName();
@@ -420,7 +381,6 @@ namespace KileWidget
 				KConfigGroup toolGroup = m_config->group(KileTool::groupFor(toolName, "Default"));
 				toolGroup.writeEntry("class", tempMap["class"]);
 				toolGroup.writeEntry("type", tempMap["type"]);
-				toolGroup.writeEntry("state", tempMap["state"]);
 				toolGroup.writeEntry("close", tempMap["close"]);
 				toolGroup.writeEntry("checkForRoot", tempMap["checkForRoot"]);
 				toolGroup.writeEntry("autoRun", tempMap["autoRun"]);
@@ -442,10 +402,10 @@ namespace KileWidget
 
 	void ToolConfig::newConfig()
 	{
-		//KILE_DEBUG() << "==ToolConfig::newConfig()=====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::newConfig()=====================";
 		writeConfig();
 		bool ok;
-		QString cfg = KInputDialog::getText(i18n("New Configuration"), i18n("Enter new configuration name:"), "", &ok, this);
+		QString cfg = QInputDialog::getText(this, i18n("New Configuration"), i18n("Enter new configuration name:"), QLineEdit::Normal, "", &ok);
 		if (ok && (!cfg.isEmpty())) {
 			//copy config
 			KConfigGroup toolGroup = m_config->group(KileTool::groupFor(m_current, cfg));
@@ -464,7 +424,6 @@ namespace KileWidget
 		toolGroup.writeEntry("class", "Compile");
 		toolGroup.writeEntry("type", "Process");
 		toolGroup.writeEntry("menu", "Compile");
-		toolGroup.writeEntry("state", "Editor");
 		toolGroup.writeEntry("close", "no");
 
 		m_config->group("Tools").writeEntry(tool, cfg);
@@ -472,12 +431,12 @@ namespace KileWidget
 
 	void ToolConfig::removeTool()
 	{
-// 		KILE_DEBUG() << "==ToolConfig::removeTool()=====================";
+// 		KILE_DEBUG_MAIN << "==ToolConfig::removeTool()=====================";
 		if(KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to remove the tool %1?", m_current)) == KMessageBox::Continue) {
 			QStringList cfgs = KileTool::configNames(m_current, m_config);
-// 			KILE_DEBUG() << "cfgs " <<  cfgs.join(", ");
+// 			KILE_DEBUG_MAIN << "cfgs " <<  cfgs.join(", ");
 			for(int i = 0; i < cfgs.count(); ++i) {
-// 				KILE_DEBUG() << "group " << KileTool::groupFor(m_current, cfgs[i]);
+// 				KILE_DEBUG_MAIN << "group " << KileTool::groupFor(m_current, cfgs[i]);
 				m_config->deleteGroup(KileTool::groupFor(m_current, cfgs[i]));
 			}
 			m_config->group("Tools").deleteEntry(m_current);
@@ -489,7 +448,7 @@ namespace KileWidget
 				index = 0;
 			}
 			QString tool = m_configWidget->m_lstbTools->item(index)->text();
-// 			KILE_DEBUG() << "tool is " << tool;
+// 			KILE_DEBUG_MAIN << "tool is " << tool;
 			m_configWidget->m_lstbTools->blockSignals(true);
 			updateToollist();
 			m_configWidget->m_lstbTools->setCurrentRow(index);
@@ -500,7 +459,7 @@ namespace KileWidget
 
 	void ToolConfig::removeConfig()
 	{
-		//KILE_DEBUG() << "==ToolConfig::removeConfig()=====================";
+		//KILE_DEBUG_MAIN << "==ToolConfig::removeConfig()=====================";
 		writeConfig();
 		if ( m_configWidget->m_cbConfig->count() > 1) {
 			if(KMessageBox::warningContinueCancel(this, i18n("Are you sure that you want to remove this configuration?") )
@@ -534,9 +493,8 @@ namespace KileWidget
 		switch (index) {
 			case 0 : m_map["type"] = "Process"; break;
 			case 1 : m_map["type"] = "Konsole"; break;
-			case 2 : m_map["type"] = "Part"; break;
-			case 3 : m_map["type"] = "DocPart"; break;
-			case 4 : m_map["type"] = "Sequence"; break;
+			case 2 : m_map["type"] = "DocumentViewer"; break;
+			case 3 : m_map["type"] = "Sequence"; break;
 			default : m_map["type"] = "Process"; break;
 		}
 		emit(changed());
@@ -544,15 +502,6 @@ namespace KileWidget
 
 	void ToolConfig::setCommand(const QString & command) { m_map["command"] = command.trimmed(); }
 	void ToolConfig::setOptions() { m_map["options"] = m_ptcw->m_options->toPlainText().trimmed(); }
-	void ToolConfig::setLibrary(const QString & lib) { m_map["libName"] = lib.trimmed(); }
-	void ToolConfig::setLibOptions(const QString & options) { m_map["libOptions"] = options.trimmed(); }
-	void ToolConfig::setClassName(const QString & name) { m_map["className"] = name.trimmed(); }
-	void ToolConfig::setState(const QString & state)
-	{
-		QString str = state.trimmed();
-		if(str.isEmpty()) str = "Editor";
-		m_map["state"] = str;
-	}
 	void ToolConfig::setSequence(const QString & sequence) { m_map["sequence"] = sequence.trimmed(); }
 	void ToolConfig::setClose(bool on) { m_map["close"] = on ? "yes" : "no"; }
 	void ToolConfig::setTarget(const QString & trg) { m_map["target"] = trg.trimmed(); }
@@ -562,7 +511,7 @@ namespace KileWidget
 	void ToolConfig::setLaTeXAuto(bool ck) { m_map["autoRun"] = ck ? "yes" : "no"; }
 	void ToolConfig::setRunLyxServer(bool ck)
 	{
-		//KILE_DEBUG() << "setRunLyxServer";
+		//KILE_DEBUG_MAIN << "setRunLyxServer";
 		m_config->group("Tools").writeEntry("RunLyxServer", ck);
 	}
 	void ToolConfig::setFrom(const QString & from) { m_map["from"] = from.trimmed(); }
@@ -570,4 +519,3 @@ namespace KileWidget
 	void ToolConfig::setClass(const QString & cls) { m_map["class"] = cls.trimmed(); }
 }
 
-#include "toolconfigwidget.moc"
